@@ -18,9 +18,6 @@
  * happen and don't have logic to gracefully recover from. The most useful
  * thing you can do in that situation is abort to get a clean core file and
  * stack trace to maximize the chances of it being readable.
- *
- * Author: Daniel van Vugt <daniel.van.vugt@canonical.com>
- *         Alan Griffiths <alan@octopull.co.uk>
  */
 
 #ifndef MIR_FATAL_H_
@@ -51,6 +48,7 @@ void fatal_error_except(char const* reason, ...);
  * as cleanly as possible.
  *   \param [in] reason  A printf-style format string.
  */
+[[noreturn]]
 void fatal_error_abort(char const* reason, ...);
 
 // Utility class to override & restore existing error handler
