@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #ifndef MIRAL_APPEND_EVENT_FILTER_H
@@ -31,7 +29,11 @@ namespace miral
 class AppendEventFilter
 {
 public:
-    AppendEventFilter(std::function<int(MirEvent const* event)> const& filter);
+    /// Append an event filter (after any existing filters, including the window manager).
+    /// The supplied filter should return true if and only if it handles the event as filters
+    /// later in the list will not be called.
+    /// \remark the filter return type changed to bool in MirAL 3.6
+    explicit AppendEventFilter(std::function<bool(MirEvent const* event)> const& filter);
 
     void operator()(mir::Server& server);
 
