@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #ifndef MIRAL_WAYLAND_EXTENSIONS_H
@@ -153,7 +151,6 @@ public:
     /// \remark Since MirAL 3.4
     static char const* const zwp_virtual_keyboard_manager_v1;
 
-
     /// Allows clients (such as on-screen keyboards) to intercept physical key events and act as a
     /// source of text input for other clients. Input methods are not required to display anything
     /// to use this extension, so malicious clients could use it to intercept keys events or take
@@ -161,6 +158,17 @@ public:
     /// \remark Since MirAL 3.4
     static char const* const zwp_input_method_manager_v2;
 
+    /// Allows clients to take screenshots and record the screen. Only enable for clients that are
+    /// trusted to view all displayed content, including windows of other apps.
+    /// \remark Since MirAL 3.5
+    static char const* const zwlr_screencopy_manager_v1;
+
+    /// Allows clients to act as a virtual pointer, useful for remote control and automation.
+    /// Clients are not required to display anything to send pointer events using this extension,
+    /// so malicious clients could use it to take actions without user input.
+    /// \remark Since MirAL 3.6
+    static char const* const zwlr_virtual_pointer_manager_v1;
+
     /**
      * \remark Since MirAL 3.3
      * \deprecated Use the *_manager_* versions instead
