@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
 #ifndef MIR_GRAPHICS_BUFFER_ID_H_
@@ -21,6 +19,8 @@
 
 #include "mir/int_wrapper.h"
 
+#include <stdint.h>
+
 namespace mir
 {
 namespace graphics
