@@ -1,5 +1,5 @@
 /*
- * Copyright © 2012 Canonical Ltd.
+ * Copyright © 2012-2022 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -12,46 +12,19 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Thomas Voß <thomas.voss@canonical.com>
  */
 
 #include "mir/logging/dumb_console_logger.h"
 
 #include <iostream>
-#include <ctime>
-#include <cstdio>
 
 namespace ml = mir::logging;
 
-void ml::DumbConsoleLogger::log(ml::Severity severity,
+void ml::DumbConsoleLogger::log(Severity severity,
                                 const std::string& message,
                                 const std::string& component)
 {
+    std::ostream& out = severity <Severity::informational ? std::cerr : std::cout;
 
-    static const char* lut[5] =
-    {
-        "< CRITICAL! > ",
-        "< - ERROR - > ",
-        "< -warning- > ",
-        "<information> ",
-        "< - debug - > "
-    };
-
-    std::ostream& out = severity < ml::Severity::informational ? std::cerr : std::cout;
-
-    struct timespec ts;
-    clock_gettime(CLOCK_REALTIME, &ts);
-    char now[32];
-    auto offset = strftime(now, sizeof(now), "%F %T", localtime(&ts.tv_sec));
-    snprintf(now+offset, sizeof(now)-offset, ".%06ld", ts.tv_nsec / 1000);
-
-    out << "["
-        << now
-        << "] "
-        << lut[static_cast<int>(severity)]
-        << component
-        << ": "
-        << message
-        << std::endl;
+    format_message(out, severity, message, component);
 }
