@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #ifndef MIR_UDEV_WRAPPER_H_
@@ -40,7 +38,8 @@ public:
     Context(Context const&) = delete;
     Context& operator=(Context const&) = delete;
 
-    std::shared_ptr<Device> device_from_syspath(std::string const& syspath);
+    auto device_from_syspath(std::string const& syspath) -> std::unique_ptr<Device>;
+    auto char_device_from_devnum(dev_t devnum) -> std::unique_ptr<Device>;
 
     ::udev* ctx() const;
 
@@ -73,6 +72,12 @@ public:
      * \note    udev devices may be parentless. This returns an empty unique_ptr on parentless udev devices.
      */
     virtual auto parent() const -> std::unique_ptr<Device> = 0;
+    /**
+     * Copy this Device handle
+     *
+     * \return A copy of this Device
+     */
+    virtual auto clone() const -> std::unique_ptr<Device> = 0;
 protected:
     Device() = default;
 };
