@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.   If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored By: Robert Carr <racarr@canonical.com>
  */
 
 #ifndef MIR_SCENE_SESSION_H_
@@ -33,12 +31,19 @@
 namespace mir
 {
 class ClientVisibleError;
+class Executor;
 namespace compositor
 {
 class BufferStream;
 }
+namespace wayland
+{
+template<typename>
+class Weak;
+}
 namespace frontend
 {
+class WlSurface;
 class EventSink;
 class Surface;
 class BufferStream;
@@ -90,8 +95,10 @@ public:
     /// \return a newly created surface
     virtual auto create_surface(
         std::shared_ptr<Session> const& session,
+        wayland::Weak<frontend::WlSurface> const& wayland_surface,
         shell::SurfaceSpecification const& params,
-        std::shared_ptr<scene::SurfaceObserver> const& observer) -> std::shared_ptr<Surface> = 0;
+        std::shared_ptr<scene::SurfaceObserver> const& observer,
+        Executor* observer_executor) -> std::shared_ptr<Surface> = 0;
     virtual void destroy_surface(std::shared_ptr<Surface> const& surface) = 0;
     virtual auto surface_after(std::shared_ptr<Surface> const& surface) const -> std::shared_ptr<Surface> = 0;
 
