@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #ifndef MIR_SCENE_SURFACE_H_
@@ -24,6 +22,7 @@
 #include "mir/frontend/surface.h"
 #include "mir/compositor/compositor_id.h"
 #include "mir/optional_value.h"
+#include "mir/observer_registrar.h"
 #include "surface_state_tracker.h"
 
 #include <vector>
@@ -32,7 +31,6 @@
 namespace mir
 {
 namespace shell { class InputTargeter; }
-namespace geometry { struct Rectangle; }
 namespace graphics { class CursorImage; }
 namespace compositor { class BufferStream; }
 namespace scene
@@ -49,7 +47,8 @@ class Session;
 
 class Surface :
     public input::Surface,
-    public frontend::Surface
+    public frontend::Surface,
+    public ObserverRegistrar<SurfaceObserver>
 {
 public:
     // resolve ambiguous member function names
@@ -98,9 +97,6 @@ public:
     virtual void set_cursor_image(std::shared_ptr<graphics::CursorImage> const& image) override = 0;
     virtual std::shared_ptr<graphics::CursorImage> cursor_image() const override = 0;
 
-    virtual void add_observer(std::shared_ptr<SurfaceObserver> const& observer) = 0;
-    virtual void remove_observer(std::weak_ptr<SurfaceObserver> const& observer) = 0;
-
     virtual void set_reception_mode(input::InputReceptionMode mode) = 0;
 
     virtual void request_client_surface_close() = 0;
@@ -126,8 +122,8 @@ public:
     /// When the depth layer is changed, the surface becomes the top surface on that layer
     virtual void set_depth_layer(MirDepthLayer depth_layer) = 0;
 
-    virtual std::experimental::optional<geometry::Rectangle> clip_area() const = 0;
-    virtual void set_clip_area(std::experimental::optional<geometry::Rectangle> const& area) = 0;
+    virtual std::optional<geometry::Rectangle> clip_area() const = 0;
+    virtual void set_clip_area(std::optional<geometry::Rectangle> const& area) = 0;
 
     virtual auto focus_state() const -> MirWindowFocusState = 0;
     virtual void set_focus_state(MirWindowFocusState focus_state) = 0;
