@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored By: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #ifndef MIR_SERVER_H_
@@ -83,7 +81,8 @@ enum class OptionType
     null,
     integer,
     string,
-    boolean
+    boolean,
+    strings
 };
 
 /// Customise and run a Mir server.
