@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored By: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #ifndef MIR_SHELL_ABSTRACT_SHELL_H_
@@ -66,8 +64,12 @@ public:
 
     auto create_surface(
         std::shared_ptr<scene::Session> const& session,
+        wayland::Weak<frontend::WlSurface> const& wayland_surface,
         SurfaceSpecification const& params,
-        std::shared_ptr<scene::SurfaceObserver> const& observer) -> std::shared_ptr<scene::Surface> override;
+        std::shared_ptr<scene::SurfaceObserver> const& observer,
+        Executor* observer_executor) -> std::shared_ptr<scene::Surface> override;
+
+    void surface_ready(std::shared_ptr<scene::Surface> const& surface) override;
 
     void modify_surface(
         std::shared_ptr<scene::Session> const& session,
@@ -150,8 +152,6 @@ public:
 
     bool handle(MirEvent const& event) override;
 
-    void update_focused_surface_confined_region();
-
     void set_drag_and_drop_handle(std::vector<uint8_t> const& handle) override;
     void clear_drag_and_drop_handle() override;
 
@@ -164,6 +164,8 @@ protected:
     std::shared_ptr<input::Seat> const seat;
 
 private:
+    class SurfaceConfinementUpdater;
+
     std::shared_ptr<ShellReport> const report;
 
     std::mutex mutable focus_mutex;
@@ -172,7 +174,7 @@ private:
     std::vector<std::weak_ptr<scene::Surface>> notified_active_surfaces;
     std::weak_ptr<scene::Surface> last_requested_focus_surface;
     std::weak_ptr<scene::Surface> notified_keyboard_focus_surface;
-    std::shared_ptr<scene::SurfaceObserver> const focus_surface_observer;
+    std::shared_ptr<SurfaceConfinementUpdater> const surface_confinement_updater;
 
     void notify_active_surfaces(
         std::unique_lock<std::mutex> const&,
