@@ -12,20 +12,19 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 
 #ifndef MIR_SHELL_SURFACE_COORDINATOR_H_
 #define MIR_SHELL_SURFACE_COORDINATOR_H_
 
+#include "mir/geometry/forward.h"
+
 #include <memory>
 #include <set>
 
 namespace mir
 {
-namespace geometry { class Point; }
 namespace input { enum class InputReceptionMode; }
 namespace scene
 {
