@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "miral/append_event_filter.h"
@@ -25,7 +23,7 @@
 class miral::AppendEventFilter::Filter : public mir::input::EventFilter
 {
 public:
-    Filter(std::function<int(MirEvent const* event)> const& filter) :
+    Filter(std::function<bool(MirEvent const* event)> const& filter) :
         filter{filter} {}
 
     bool handle(MirEvent const& event) override
@@ -34,10 +32,10 @@ public:
     }
 
 private:
-    std::function<int(MirEvent const* event)> const filter;
+    std::function<bool(MirEvent const* event)> const filter;
 };
 
-miral::AppendEventFilter::AppendEventFilter(std::function<int(MirEvent const* event)> const& filter) :
+miral::AppendEventFilter::AppendEventFilter(std::function<bool(MirEvent const* event)> const& filter) :
     filter{std::make_shared<Filter>(filter)}
 {
 }
