@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "basic_window_manager.h"
@@ -26,7 +24,6 @@
 #include <mir/scene/surface.h>
 #include <mir/shell/display_layout.h>
 #include <mir/shell/persistent_surface_store.h>
-#include <mir/shell/surface_ready_observer.h>
 #include <mir/shell/surface_specification.h>
 
 #include <boost/throw_exception.hpp>
@@ -71,7 +68,7 @@ miral::BasicWindowManager::Locker::Locker(BasicWindowManager* self) :
     policy->advise_begin();
     std::vector<std::weak_ptr<Workspace>> workspaces;
     {
-        std::lock_guard<std::mutex> const lock{self->dead_workspaces->dead_workspaces_mutex};
+        std::lock_guard const lock{self->dead_workspaces->dead_workspaces_mutex};
         workspaces.swap(self->dead_workspaces->workspaces);
     }
 
@@ -165,20 +162,6 @@ auto miral::BasicWindowManager::add_surface(
 
     policy->advise_new_window(window_info);
 
-    std::shared_ptr<scene::Surface> const scene_surface = window_info.window();
-    if (scene_surface->visible())
-    {
-        policy->handle_window_ready(window_info);
-    }
-    else
-    {
-        scene_surface->add_observer(std::make_shared<shell::SurfaceReadyObserver>(
-            [this, &window_info](std::shared_ptr<scene::Session> const&, std::shared_ptr<scene::Surface> const&)
-                { Locker lock{this}; policy->handle_window_ready(window_info); },
-            session,
-            scene_surface));
-    }
-
     if (parent && spec.aux_rect().is_set() && spec.placement_hints().is_set())
     {
         Rectangle relative_placement{window.top_left() - (parent.top_left()-Point{}), window.size()};
@@ -189,6 +172,12 @@ auto miral::BasicWindowManager::add_surface(
     return surface;
 }
 
+void miral::BasicWindowManager::surface_ready(std::shared_ptr<scene::Surface> const& surface)
+{
+    Locker lock{this};
+    policy->handle_window_ready(info_for(surface));
+}
+
 void miral::BasicWindowManager::modify_surface(
     std::shared_ptr<scene::Session> const& /*application*/,
     std::shared_ptr<scene::Surface> const& surface,
@@ -408,7 +397,7 @@ void miral::BasicWindowManager::handle_request_move(
     std::shared_ptr<mir::scene::Surface> const& surface,
     uint64_t timestamp)
 {
-    std::lock_guard<decltype(mutex)> lock(mutex);
+    std::lock_guard lock(mutex);
 
     if (!surface_known(surface, "move"))
         return;
@@ -425,7 +414,7 @@ void miral::BasicWindowManager::handle_request_resize(
     uint64_t timestamp,
     MirResizeEdge edge)
 {
-    std::lock_guard<decltype(mutex)> lock(mutex);
+    std::lock_guard lock(mutex);
 
     if (!surface_known(surface, "resize"))
         return;
@@ -754,7 +743,7 @@ auto miral::BasicWindowManager::display_area_for(Rectangle const& rect) const
     std::optional<std::shared_ptr<DisplayArea>> best_area;
     for (auto& area : display_areas)
     {
-        auto const intersection = rect.intersection_with(area->area).size;
+        auto const intersection = intersection_of(rect, area->area).size;
         auto const intersection_area = intersection.width.as_int() * intersection.height.as_int();
         if (intersection_area > max_overlap_area)
         {
@@ -1319,7 +1308,7 @@ void miral::BasicWindowManager::place_and_size_for_state(
         if (modifications.output_id().is_set() &&
            (!window_info.has_output_id() || modifications.output_id().value() != window_info.output_id()))
                 break;
-        // Falls through.
+        [[fallthrough]];
     default:
         if (new_state == window_info.state())
             return;
@@ -2348,7 +2337,7 @@ public:
 
     ~Workspace()
     {
-        std::lock_guard<std::mutex> lock {dead_workspaces->dead_workspaces_mutex};
+        std::lock_guard lock {dead_workspaces->dead_workspaces_mutex};
         dead_workspaces->workspaces.push_back(self);
     }
 
