@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored By: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #ifndef MIR_ABSTRACTION_BASIC_WINDOW_MANAGER_H_
@@ -83,6 +81,8 @@ public:
             mir::shell::SurfaceSpecification const& params)> const& build)
     -> std::shared_ptr<mir::scene::Surface> override;
 
+    void surface_ready(std::shared_ptr<mir::scene::Surface> const& surface) override;
+
     void modify_surface(
         std::shared_ptr<mir::scene::Session> const& session,
         std::shared_ptr<mir::scene::Surface> const& surface,
