@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "launch_app.h"
@@ -22,6 +20,7 @@
 #include <boost/throw_exception.hpp>
 
 #include <unistd.h>
+#include <signal.h>
 
 #include <cstring>
 #include <stdexcept>
@@ -113,6 +112,11 @@ auto miral::launch_app_env(
 
         exec_args.push_back(nullptr);
 
+        mir::log_debug("Restoring sigmask");
+        sigset_t all_signals;
+        sigfillset(&all_signals);
+        pthread_sigmask(SIG_UNBLOCK, &all_signals, nullptr);
+
         execvp(exec_args[0], const_cast<char*const*>(exec_args.data()));
 
         mir::log_warning("Failed to execute client (\"%s\") error: %s", exec_args[0], strerror(errno));
