@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #ifndef MIRAL_LAUNCH_APP_H
@@ -23,7 +21,7 @@
 
 #include <sys/types.h>
 
-#include <experimental/optional>
+#include <optional>
 
 #include <map>
 #include <string>
@@ -31,7 +29,7 @@
 
 namespace miral
 {
-using AppEnvironment = std::map<std::string, std::experimental::optional<std::string>>;
+using AppEnvironment = std::map<std::string, std::optional<std::string>>;
 
 auto launch_app_env(std::vector<std::string> const& app,
     mir::optional_value<std::string> const& wayland_display,
