@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #include "mir/graphics/display_configuration.h"
@@ -140,7 +138,6 @@ std::ostream& mg::operator<<(std::ostream& out, mg::DisplayConfigurationOutput c
 
 std::ostream& mg::operator<<(std::ostream& out, mg::DisplayConfiguration const& val)
 {
-    val.for_each_card([&out](auto card) { out << card << std::endl; });
     val.for_each_output([&out](DisplayConfigurationOutput const& output) { out << output << std::endl; });
 
     return out;
@@ -191,13 +188,9 @@ bool mg::operator==(mg::DisplayConfigurationOutput const& val1,
                (val1.scale == val2.scale) &&
                (val1.form_factor == val2.form_factor)};
 
-    if (equal)
+    for (auto i = begin(val1.modes), j = begin(val2.modes); i != end(val1.modes) && equal; ++i, ++j)
     {
-        for (size_t i = 0; i < val1.modes.size(); i++)
-        {
-            equal = equal && (val1.modes[i] == val2.modes[i]);
-            if (!equal) break;
-        }
+        equal = *i == *j;
     }
 
     return equal;
@@ -214,13 +207,11 @@ bool mg::operator==(DisplayConfiguration const& lhs, DisplayConfiguration const&
     std::vector<DisplayConfigurationCard> lhs_cards;
     std::vector<DisplayConfigurationOutput> lhs_outputs;
 
-    lhs.for_each_card([&lhs_cards](DisplayConfigurationCard const& card) { lhs_cards.emplace_back(card); });
     lhs.for_each_output([&lhs_outputs](DisplayConfigurationOutput const& output) { lhs_outputs.emplace_back(output); });
 
     std::vector<DisplayConfigurationCard> rhs_cards;
     std::vector<DisplayConfigurationOutput> rhs_outputs;
 
-    rhs.for_each_card([&rhs_cards](DisplayConfigurationCard const& card) { rhs_cards.emplace_back(card); });
     rhs.for_each_output([&rhs_outputs](DisplayConfigurationOutput const& output) { rhs_outputs.emplace_back(output); });
 
     return lhs_cards == rhs_cards && lhs_outputs == rhs_outputs;
