@@ -12,9 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by:
- *   Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #include <epoxy/egl.h>
@@ -36,6 +33,7 @@
 #include "mir/renderer/gl/context_source.h"
 #include "mir/renderer/gl/context.h"
 #include "mir/raii.h"
+#include "mir/wayland/wayland_base.h"
 
 #define MIR_LOG_COMPONENT "platform-eglstream-kms"
 #include "mir/log.h"
@@ -261,7 +259,7 @@ struct BoundEGLStream
              * render thread will bind the new texture (ie: there's some implicit syncpoint
              * action happening)
              */
-            std::lock_guard<std::mutex> lock{sync->sync_mutex};
+            std::lock_guard lock{sync->sync_mutex};
             if (sync->sync)
             {
                 glWaitSync(sync->sync, 0, GL_TIMEOUT_IGNORED);
@@ -310,10 +308,11 @@ private:
 }
 
 void mge::BufferAllocator::create_buffer_eglstream_resource(
-    wl_client* /*client*/,
+    wl_client* client,
     wl_resource* eglstream_controller_resource,
     wl_resource* /*surface*/,
     wl_resource* buffer)
+try
 {
     auto const allocator = static_cast<mge::BufferAllocator*>(
         wl_resource_get_user_data(eglstream_controller_resource));
@@ -337,6 +336,10 @@ void mge::BufferAllocator::create_buffer_eglstream_resource(
 
     allocator->wayland_ctx->release_current();
 }
+catch (std::exception const& err)
+{
+    mir::wayland::internal_error_processing_request(client,  "create_buffer_eglstream_resource");
+}
 
 struct wl_eglstream_controller_interface const mge::BufferAllocator::impl{
     create_buffer_eglstream_resource
