@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #include <epoxy/egl.h>
@@ -28,7 +26,6 @@
 #include "mir/graphics/display_configuration_policy.h"
 #include "mir/graphics/overlapping_output_grouping.h"
 #include "mir/graphics/gl_config.h"
-#include "mir/graphics/virtual_output.h"
 #include "mir/graphics/egl_error.h"
 #include "mir/graphics/display_buffer.h"
 #include "mir/graphics/transformation.h"
@@ -353,7 +350,7 @@ void mge::Display::for_each_display_sync_group(const std::function<void(DisplayS
 
 std::unique_ptr<mg::DisplayConfiguration> mge::Display::configuration() const
 {
-    std::lock_guard<std::mutex> lock{configuration_mutex};
+    std::lock_guard lock{configuration_mutex};
     return display_configuration.clone();
 }
 
@@ -405,7 +402,7 @@ void mge::Display::register_configuration_change_handler(
                 monitor->process_events(
                     [conf_change_handler, this](mir::udev::Monitor::EventType, mir::udev::Device const&)
                     {
-                        std::lock_guard<std::mutex> lock{configuration_mutex};
+                        std::lock_guard lock{configuration_mutex};
                         display_configuration.update();
                         conf_change_handler();
                     });
@@ -435,11 +432,6 @@ std::shared_ptr<mg::Cursor> mge::Display::create_hardware_cursor()
     return nullptr;
 }
 
-std::unique_ptr<mg::VirtualOutput> mge::Display::create_virtual_output(int /*width*/, int /*height*/)
-{
-    return nullptr;
-}
-
 std::unique_ptr<mir::renderer::gl::Context> mge::Display::create_gl_context() const
 {
     class GLContext : public renderer::gl::Context
