@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #ifndef MIR_PLATFORM_EGLSTREAM_KMS_UTILS_H_
@@ -21,7 +19,7 @@
 
 #include <epoxy/egl.h>
 #include <sys/types.h>
-#include <experimental/optional>
+#include <optional>
 
 namespace mir
 {
@@ -37,7 +35,7 @@ struct VersionInfo
     int minor;
 };
 
-std::experimental::optional<VersionInfo> parse_nvidia_version(char const* gl_version);
+std::optional<VersionInfo> parse_nvidia_version(char const* gl_version);
 }
 }
 }
