@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Andreas Pokorny <andreas.pokorny@canonical.com>
  */
 
 #include "libinput_device.h"
@@ -48,6 +46,8 @@
 namespace md = mir::dispatch;
 namespace mi = mir::input;
 namespace mie = mi::evdev;
+namespace mev = mir::events;
+namespace geom = mir::geometry;
 using namespace std::literals::chrono_literals;
 
 namespace
@@ -83,6 +83,69 @@ template<typename T> auto load_function(char const* sym)
 
     return result;
 }
+
+template<typename Tag>
+auto get_scroll_axis(
+    libinput_event_pointer* event,
+    libinput_pointer_axis axis,
+    geom::generic::Value<int, Tag>& accumulator,
+    geom::generic::Value<float, Tag> scale) -> mev::ScrollAxis<Tag>
+{
+    if (!libinput_event_pointer_has_axis(event, axis))
+    {
+        return {};
+    }
+
+#ifdef MIR_LIBINPUT_HAS_VALUE120
+    auto const libinput_event_type = libinput_event_get_type(libinput_event_pointer_get_base_event(event));
+
+    mir::geometry::generic::Value<float, Tag> const precise{
+        libinput_event_pointer_get_scroll_value(event, axis) * scale};
+    auto const stop = precise.as_value() == 0;
+    mir::geometry::generic::Value<int, Tag> const value120{
+        libinput_event_type == LIBINPUT_EVENT_POINTER_SCROLL_WHEEL ?
+        libinput_event_pointer_get_scroll_value_v120(event, axis) :
+        0
+    };
+    accumulator += value120;
+    mir::geometry::generic::Value<int, Tag> const discrete{accumulator / 120};
+    accumulator = geom::generic::Value<int, Tag>{accumulator.as_value() % 120};
+#else
+    (void)accumulator;
+    mir::geometry::generic::Value<float, Tag> const precise{
+        libinput_event_pointer_get_axis_value(event, axis) * scale};
+    auto const stop = precise.as_value() == 0;
+    mir::geometry::generic::Value<int, Tag> const discrete{
+        libinput_event_pointer_get_axis_source(event) == LIBINPUT_POINTER_AXIS_SOURCE_WHEEL ?
+        libinput_event_pointer_get_axis_value_discrete(event, axis) :
+        0};
+    mir::geometry::generic::Value<int, Tag> const value120{discrete * 120};
+#endif
+
+    return {precise, discrete, value120, stop};
+}
+
+auto get_axis_source(libinput_event_pointer* pointer) -> MirPointerAxisSource
+{
+#ifdef MIR_LIBINPUT_HAS_VALUE120
+    switch (libinput_event_get_type(libinput_event_pointer_get_base_event(pointer)))
+    {
+    case LIBINPUT_EVENT_POINTER_SCROLL_WHEEL:       return mir_pointer_axis_source_wheel;
+    case LIBINPUT_EVENT_POINTER_SCROLL_FINGER:      return mir_pointer_axis_source_finger;
+    case LIBINPUT_EVENT_POINTER_SCROLL_CONTINUOUS:  return mir_pointer_axis_source_continuous;
+    default:                                        return mir_pointer_axis_source_none;
+    }
+#else
+    switch (libinput_event_pointer_get_axis_source(pointer))
+    {
+    case LIBINPUT_POINTER_AXIS_SOURCE_WHEEL:        return mir_pointer_axis_source_wheel;
+    case LIBINPUT_POINTER_AXIS_SOURCE_FINGER:       return mir_pointer_axis_source_finger;
+    case LIBINPUT_POINTER_AXIS_SOURCE_CONTINUOUS:   return mir_pointer_axis_source_continuous;
+    case LIBINPUT_POINTER_AXIS_SOURCE_WHEEL_TILT:   return mir_pointer_axis_source_wheel_tilt;
+    default:                                        return mir_pointer_axis_source_none;
+    }
+#endif
+}
 }
 
 struct mie::LibInputDevice::ContactExtension
@@ -157,7 +220,19 @@ void mie::LibInputDevice::process_event(libinput_event* event)
         case LIBINPUT_EVENT_POINTER_BUTTON:
             sink->handle_input(convert_button_event(libinput_event_get_pointer_event(event)));
             break;
+#ifdef MIR_LIBINPUT_HAS_VALUE120
+        case LIBINPUT_EVENT_POINTER_SCROLL_WHEEL:
+        case LIBINPUT_EVENT_POINTER_SCROLL_FINGER:
+        case LIBINPUT_EVENT_POINTER_SCROLL_CONTINUOUS:
+#else
+        /*
+        * This event is deprecated as of libinput 1.19. Use
+        * @ref LIBINPUT_EVENT_POINTER_SCROLL_WHEEL,
+        * @ref LIBINPUT_EVENT_POINTER_SCROLL_FINGER, and
+        * @ref LIBINPUT_EVENT_POINTER_SCROLL_CONTINUOUS instead.
+        */
         case LIBINPUT_EVENT_POINTER_AXIS:
+#endif
             sink->handle_input(convert_axis_event(libinput_event_get_pointer_event(event)));
             break;
         // touch events are processed as a batch of changes over all touch pointts
@@ -176,7 +251,10 @@ void mie::LibInputDevice::process_event(libinput_event* event)
         case LIBINPUT_EVENT_TOUCH_FRAME:
             if (is_output_active())
             {
-                sink->handle_input(convert_touch_frame(libinput_event_get_touch_event(event)));
+                if (auto input = convert_touch_frame(libinput_event_get_touch_event(event)))
+                {
+                    sink->handle_input(std::move(input));
+                }
             }
             break;
         default:
@@ -210,10 +288,6 @@ mir::EventUPtr mie::LibInputDevice::convert_button_event(libinput_event_pointer*
 
     auto const do_not_swap_buttons = mir_pointer_handedness_right;
     auto const pointer_button = mie::to_pointer_button(button, do_not_swap_buttons);
-    auto const relative_x_value = 0.0f;
-    auto const relative_y_value = 0.0f;
-    auto const hscroll_value = 0.0f;
-    auto const vscroll_value = 0.0f;
 
     report->received_event_from_kernel(time.count(), EV_KEY, pointer_button, action);
 
@@ -222,22 +296,33 @@ mir::EventUPtr mie::LibInputDevice::convert_button_event(libinput_event_pointer*
     else
         button_state = MirPointerButton(button_state & ~uint32_t(pointer_button));
 
-    return builder->pointer_event(time, action, button_state, hscroll_value, vscroll_value, relative_x_value, relative_y_value);
+    return builder->pointer_event(
+        time,
+        action,
+        button_state,
+        std::nullopt,
+        {},
+        mir_pointer_axis_source_none,
+        {},
+        {});
 }
 
 mir::EventUPtr mie::LibInputDevice::convert_motion_event(libinput_event_pointer* pointer)
 {
     std::chrono::nanoseconds const time = std::chrono::microseconds(libinput_event_pointer_get_time_usec(pointer));
     auto const action = mir_pointer_action_motion;
-    auto const hscroll_value = 0.0f;
-    auto const vscroll_value = 0.0f;
 
     report->received_event_from_kernel(time.count(), EV_REL, 0, 0);
 
-    return builder->pointer_event(time, action, button_state,
-                                  hscroll_value, vscroll_value,
-                                  libinput_event_pointer_get_dx(pointer),
-                                  libinput_event_pointer_get_dy(pointer));
+    return builder->pointer_event(
+        time,
+        action,
+        button_state,
+        std::nullopt,
+        geom::DisplacementF{libinput_event_pointer_get_dx(pointer), libinput_event_pointer_get_dy(pointer)},
+        mir_pointer_axis_source_none,
+        {},
+        {});
 }
 
 mir::EventUPtr mie::LibInputDevice::convert_absolute_motion_event(libinput_event_pointer* pointer)
@@ -245,89 +330,59 @@ mir::EventUPtr mie::LibInputDevice::convert_absolute_motion_event(libinput_event
     // a pointing device that emits absolute coordinates
     std::chrono::nanoseconds const time = std::chrono::microseconds(libinput_event_pointer_get_time_usec(pointer));
     auto const action = mir_pointer_action_motion;
-    auto const hscroll_value = 0.0f;
-    auto const vscroll_value = 0.0f;
     // either the bounding box .. or the specific output ..
     auto const screen = sink->bounding_rectangle();
     uint32_t const width = screen.size.width.as_int();
     uint32_t const height = screen.size.height.as_int();
-    auto abs_x = libinput_event_pointer_get_absolute_x_transformed(pointer, width);
-    auto abs_y = libinput_event_pointer_get_absolute_y_transformed(pointer, height);
 
     report->received_event_from_kernel(time.count(), EV_ABS, 0, 0);
+
     auto const old_pointer_pos = pointer_pos;
-    pointer_pos = mir::geometry::Point{abs_x, abs_y};
+    pointer_pos = {
+        libinput_event_pointer_get_absolute_x_transformed(pointer, width),
+        libinput_event_pointer_get_absolute_y_transformed(pointer, height),
+    };
     auto const movement = pointer_pos - old_pointer_pos;
 
-    return builder->pointer_event(time, action, button_state, abs_x, abs_y, hscroll_value, vscroll_value,
-                                  movement.dx.as_int(), movement.dy.as_int());
+    return builder->pointer_event(
+        time,
+        action,
+        button_state,
+        pointer_pos,
+        movement,
+        mir_pointer_axis_source_none,
+        {},
+        {});
 }
 
 mir::EventUPtr mie::LibInputDevice::convert_axis_event(libinput_event_pointer* pointer)
 {
     std::chrono::nanoseconds const time = std::chrono::microseconds(libinput_event_pointer_get_time_usec(pointer));
     auto const action = mir_pointer_action_motion;
-    auto const relative_x_value = 0.0f;
-    auto const relative_y_value = 0.0f;
 
-    auto hscroll_value = 0.0f;
-    auto vscroll_value = 0.0f;
-    auto hscroll_stop = false;
-    auto vscroll_stop = false;
-    if (libinput_event_pointer_has_axis(pointer, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
-    {
-        hscroll_value = horizontal_scroll_scale *
-                        libinput_event_pointer_get_axis_value(pointer, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL);
-        hscroll_stop = hscroll_value == 0;
-    }
-
-    if (libinput_event_pointer_has_axis(pointer, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
-    {
-        vscroll_value = vertical_scroll_scale *
-                        libinput_event_pointer_get_axis_value(pointer, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL);
-        vscroll_stop = vscroll_value == 0;
-    }
+    auto const h_scroll = get_scroll_axis(
+        pointer,
+        LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL,
+        horizontal_scroll_value120_accum /* passed as non-const ref */,
+        horizontal_scroll_scale);
+    auto const v_scroll = get_scroll_axis(
+        pointer,
+        LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL,
+        vertical_scroll_value120_accum /* passed as non-const ref */,
+        vertical_scroll_scale);
+    auto const axis_source = get_axis_source(pointer);
 
     report->received_event_from_kernel(time.count(), EV_REL, 0, 0);
 
-    auto builder_pointer_axis_event = [&, this](MirPointerAxisSource axis_source)
-        {
-            return builder->pointer_axis_with_stop_event(
-                axis_source, time, action, button_state, 0, 0, hscroll_value, vscroll_value,
-                hscroll_stop, vscroll_stop, relative_x_value, relative_y_value);
-        };
-
-    switch (libinput_event_pointer_get_axis_source(pointer))
-    {
-    case LIBINPUT_POINTER_AXIS_SOURCE_WHEEL:
-    {
-        auto const hscroll_discrete =
-            libinput_event_pointer_has_axis(pointer, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL) ?
-            libinput_event_pointer_get_axis_value_discrete(pointer, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL) :
-            0.0;
-        auto const vscroll_discrete =
-            libinput_event_pointer_has_axis(pointer, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL) ?
-            libinput_event_pointer_get_axis_value_discrete(pointer, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL) :
-            0.0;
-
-        return builder->pointer_axis_discrete_scroll_event(
-            mir_pointer_axis_source_wheel, time, action, button_state, hscroll_value, vscroll_value,
-            hscroll_discrete, vscroll_discrete);
-    }
-
-    case LIBINPUT_POINTER_AXIS_SOURCE_FINGER:
-        return builder_pointer_axis_event(mir_pointer_axis_source_finger);
-
-    case LIBINPUT_POINTER_AXIS_SOURCE_CONTINUOUS:
-        return builder_pointer_axis_event(mir_pointer_axis_source_continuous);
-
-    case LIBINPUT_POINTER_AXIS_SOURCE_WHEEL_TILT:
-        return builder_pointer_axis_event(mir_pointer_axis_source_wheel_tilt);
-
-    default:
-        return builder->pointer_event(time, action, button_state, hscroll_value, vscroll_value, relative_x_value,
-                                      relative_y_value);
-    }
+    return builder->pointer_event(
+        time,
+        action,
+        button_state,
+        std::nullopt,
+        {},
+        axis_source,
+        h_scroll,
+        v_scroll);
 }
 
 mir::EventUPtr mie::LibInputDevice::convert_touch_frame(libinput_event_touch* touch)
@@ -356,7 +411,10 @@ mir::EventUPtr mie::LibInputDevice::convert_touch_frame(libinput_event_touch* to
                            data.orientation});
 
         if (data.action == mir_touch_action_down)
+        {
             data.action = mir_touch_action_change;
+            data.down_notified = true;
+        }
 
         if (data.action == mir_touch_action_up)
             it = last_seen_properties.erase(it);
@@ -364,19 +422,55 @@ mir::EventUPtr mie::LibInputDevice::convert_touch_frame(libinput_event_touch* to
             ++it;
     }
 
+    // Sanity check: Bogus panels are sending sometimes empty events that all point
+    // to (0, 0) coordinates. Detect those and drop the whole frame in this case.
+    // Also drop touch frames with no contacts inside
+    int emptyTouches = 0;
+    for (const auto &contact: contacts)
+    {
+        if (contact.x == 0 && contact.y == 0)
+            emptyTouches++;
+    }
+    if (contacts.empty() || emptyTouches > 1)
+        return {nullptr, [](auto){}};
+
     return builder->touch_event(time, contacts);
 }
 
 void mie::LibInputDevice::handle_touch_down(libinput_event_touch* touch)
 {
     MirTouchId const id = libinput_event_touch_get_slot(touch);
-    update_contact_data(last_seen_properties[id], mir_touch_action_down, touch);
+    auto const it = last_seen_properties.find(id);
+
+    if (it == end(last_seen_properties) || !it->second.down_notified)
+    {
+        update_contact_data(last_seen_properties[id], mir_touch_action_down, touch);
+    }
+    else
+    {
+        update_contact_data(it->second, mir_touch_action_change, touch);
+    }
 }
 
 void mie::LibInputDevice::handle_touch_up(libinput_event_touch* touch)
 {
     MirTouchId const id = libinput_event_touch_get_slot(touch);
-    last_seen_properties[id].action = mir_touch_action_up;
+
+    //Only update last_seen_properties[].action if there is a valid record in the map
+    //for this ID. Otherwise, an invalid "up" event from a bogus panel will
+    //create a fake action.
+    auto const it = last_seen_properties.find(id);
+    if (it != end(last_seen_properties))
+    {
+        if (it->second.down_notified)
+        {
+            it->second.action = mir_touch_action_up;
+        }
+        else
+        {
+            last_seen_properties.erase(it);
+        }
+    }
 }
 
 void mie::LibInputDevice::update_contact_data(ContactData & data, MirTouchAction action, libinput_event_touch* touch)
@@ -511,17 +605,13 @@ mir::optional_value<mi::PointerSettings> mie::LibInputDevice::get_pointer_settin
     auto dev = device();
     auto const left_handed = (libinput_device_config_left_handed_get(dev) == 1);
     settings.handedness = left_handed? mir_pointer_handedness_left : mir_pointer_handedness_right;
-#if MIR_LIBINPUT_HAS_ACCEL_PROFILE
     if (libinput_device_config_accel_get_profile(dev) == LIBINPUT_CONFIG_ACCEL_PROFILE_FLAT)
-#endif
         settings.acceleration = mir_pointer_acceleration_none;
-#if MIR_LIBINPUT_HAS_ACCEL_PROFILE
     else
         settings.acceleration = mir_pointer_acceleration_adaptive;
-#endif
     settings.cursor_acceleration_bias = libinput_device_config_accel_get_speed(dev);
-    settings.vertical_scroll_scale = vertical_scroll_scale;
-    settings.horizontal_scroll_scale = horizontal_scroll_scale;
+    settings.vertical_scroll_scale = vertical_scroll_scale.as_value();
+    settings.horizontal_scroll_scale = horizontal_scroll_scale.as_value();
     return settings;
 }
 
@@ -532,18 +622,16 @@ void mie::LibInputDevice::apply_settings(mir::input::PointerSettings const& sett
 
     auto dev = device();
 
-#if MIR_LIBINPUT_HAS_ACCEL_PROFILE
     auto accel_profile = settings.acceleration == mir_pointer_acceleration_adaptive ?
         LIBINPUT_CONFIG_ACCEL_PROFILE_ADAPTIVE :
         LIBINPUT_CONFIG_ACCEL_PROFILE_FLAT;
-#endif
+
     libinput_device_config_accel_set_speed(dev, settings.cursor_acceleration_bias);
     libinput_device_config_left_handed_set(dev, mir_pointer_handedness_left == settings.handedness);
-    vertical_scroll_scale = settings.vertical_scroll_scale;
-    horizontal_scroll_scale = settings.horizontal_scroll_scale;
-#if MIR_LIBINPUT_HAS_ACCEL_PROFILE
+    vertical_scroll_scale = geom::DeltaYF{settings.vertical_scroll_scale};
+    horizontal_scroll_scale = geom::DeltaXF{settings.horizontal_scroll_scale};
+
     libinput_device_config_accel_set_profile(dev, accel_profile);
-#endif
 }
 
 mir::optional_value<mi::TouchpadSettings> mie::LibInputDevice::get_touchpad_settings() const
