@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Andreas Pokorny <andreas.pokorny@canonical.com>
  */
 
 #ifndef MIR_INPUT_EVDEV_LIBINPUT_DEVICE_H_
@@ -88,10 +86,12 @@ private:
     EventBuilder* builder{nullptr};
 
     InputDeviceInfo info;
-    mir::geometry::Point pointer_pos;
+    mir::geometry::PointF pointer_pos;
     MirPointerButtons button_state;
-    double vertical_scroll_scale{1.0};
-    double horizontal_scroll_scale{1.0};
+    mir::geometry::DeltaYF vertical_scroll_scale{1.0};
+    mir::geometry::DeltaXF horizontal_scroll_scale{1.0};
+    mir::geometry::DeltaY vertical_scroll_value120_accum;
+    mir::geometry::DeltaX horizontal_scroll_value120_accum;
     mir::optional_value<TouchscreenSettings> touchscreen;
 
     struct ContactData
@@ -99,6 +99,7 @@ private:
         ContactData() {}
         MirTouchAction action{mir_touch_action_change};
         float x{0}, y{0}, major{0}, minor{0}, pressure{0}, orientation{0};
+        bool down_notified = false;
     };
     std::map<MirTouchId,ContactData> last_seen_properties;
 
