@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Andreas Pokorny <andreas.pokorny@canonical.com>
  */
 
 #include "platform.h"
@@ -26,7 +24,6 @@
 #include "mir/dispatch/readable_fd.h"
 #include "mir/dispatch/multiplexing_dispatchable.h"
 #include "mir/dispatch/action_queue.h"
-#include "mir/module_properties.h"
 #include "mir/console_services.h"
 
 #include "mir/input/input_device_registry.h"
@@ -429,14 +426,14 @@ void mie::Platform::device_added(libinput_device* dev)
     auto device_it = find_device(device_ptr.get());
     if (end(devices) != device_it)
     {
-        (*device_it)->add_device_of_group(move(device_ptr));
+        (*device_it)->add_device_of_group(std::move(device_ptr));
         log_debug("Device %s is part of an already opened device group", libinput_device_get_sysname(dev));
         return;
     }
 
     try
     {
-        devices.emplace_back(std::make_shared<mie::LibInputDevice>(report, move(device_ptr)));
+        devices.emplace_back(std::make_shared<mie::LibInputDevice>(report, std::move(device_ptr)));
 
         input_device_registry->add_device(devices.back());
 
