@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #include "display.h"
@@ -28,12 +26,12 @@
 #include "mir/graphics/overlapping_output_grouping.h"
 #include "mir/graphics/event_handler_register.h"
 
-#include "mir/graphics/virtual_output.h"
 #include "mir/graphics/display_report.h"
 #include "mir/graphics/display_configuration_policy.h"
 #include "mir/graphics/transformation.h"
 #include "mir/geometry/rectangle.h"
 #include "mir/renderer/gl/context.h"
+#include "mir/graphics/drm_formats.h"
 
 #include <boost/throw_exception.hpp>
 #include <boost/exception/get_error_info.hpp>
@@ -228,7 +226,7 @@ mgg::Display::~Display()
 void mgg::Display::for_each_display_sync_group(
     std::function<void(graphics::DisplaySyncGroup&)> const& f)
 {
-    std::lock_guard<std::mutex> lg{configuration_mutex};
+    std::lock_guard lg{configuration_mutex};
 
     for (auto& db_ptr : display_buffers)
         f(*db_ptr);
@@ -236,7 +234,7 @@ void mgg::Display::for_each_display_sync_group(
 
 std::unique_ptr<mg::DisplayConfiguration> mgg::Display::configuration() const
 {
-    std::lock_guard<std::mutex> lg{configuration_mutex};
+    std::lock_guard lg{configuration_mutex};
 
     if (dirty_configuration)
     {
@@ -258,7 +256,7 @@ void mgg::Display::configure(mg::DisplayConfiguration const& conf)
     }
 
     {
-        std::lock_guard<decltype(configuration_mutex)> lock{configuration_mutex};
+        std::lock_guard lock{configuration_mutex};
         configure_locked(dynamic_cast<RealKMSDisplayConfiguration const&>(conf), lock);
     }
 
@@ -300,7 +298,7 @@ void mgg::Display::pause()
 void mgg::Display::resume()
 {
     {
-        std::lock_guard<std::mutex> lg{configuration_mutex};
+        std::lock_guard lg{configuration_mutex};
 
         /*
          * After resuming (e.g. because we switched back to the display server VT)
@@ -335,7 +333,7 @@ auto mgg::Display::create_hardware_cursor() -> std::shared_ptr<graphics::Cursor>
             void with_current_configuration_do(
                 std::function<void(KMSDisplayConfiguration const&)> const& exec)
             {
-                std::lock_guard<std::mutex> lg{display.configuration_mutex};
+                std::lock_guard lg{display.configuration_mutex};
                 exec(display.current_display_configuration);
             }
 
@@ -381,11 +379,6 @@ void mgg::Display::clear_connected_unused_outputs()
     });
 }
 
-std::unique_ptr<mg::VirtualOutput> mgg::Display::create_virtual_output(int /*width*/, int /*height*/)
-{
-    return nullptr;
-}
-
 std::unique_ptr<mir::renderer::gl::Context> mgg::Display::create_gl_context() const
 {
     return std::make_unique<GBMGLContext>(*gbm, *gl_config, shared_egl.context());
@@ -398,7 +391,7 @@ bool mgg::Display::apply_if_configuration_preserves_display_buffers(
     auto const& new_kms_conf = dynamic_cast<RealKMSDisplayConfiguration const&>(conf);
 
     {
-        std::lock_guard<decltype(configuration_mutex)> lock{configuration_mutex};
+        std::lock_guard lock{configuration_mutex};
         if (compatible(current_display_configuration, new_kms_conf))
         {
             configure_locked(new_kms_conf, lock);
@@ -445,16 +438,28 @@ void add_to_drm_device_group(
     }
 }
 
+auto get_equivalent_other_alphaness_format(mg::DRMFormat const format) -> std::optional<mg::DRMFormat>
+{
+    if (format.has_alpha())
+    {
+        return format.opaque_equivalent();
+    }
+    else
+    {
+        return format.alpha_equivalent();
+    }
+}
+
 auto make_surface_with_egl_context(
     geom::Size size,
-    uint32_t gbm_format,
+    mg::DRMFormat format,
     mgg::helpers::GBMHelper const& gbm,
     mg::GLConfig const& config,
     EGLContext shared_context,    
     bool cross_gpu)
      -> std::tuple<mgg::GBMSurfaceUPtr, mgg::helpers::EGLHelper>
 {
-    auto surface = gbm.create_scanout_surface(size.width.as_uint32_t(), size.height.as_uint32_t(), gbm_format, cross_gpu);
+    auto surface = gbm.create_scanout_surface(size.width.as_uint32_t(), size.height.as_uint32_t(), format, cross_gpu);
     auto raw_surface = surface.get();
 
     try
@@ -465,23 +470,34 @@ auto make_surface_with_egl_context(
                 config,
                 gbm,
                 raw_surface,
-                gbm_format,
+                format,
                 shared_context
         });
     }
     catch (mgg::helpers::EGLHelper::NoMatchingEGLConfig const&)
     {
-         // TODO: Make a generic "other-alphaness" helper
-        gbm_format = GBM_FORMAT_ARGB8888;
-        surface = gbm.create_scanout_surface(size.width.as_uint32_t(), size.height.as_uint32_t(), gbm_format, cross_gpu);
+        // If the format has an opaque/alpha equivalent, try that
+        auto equivalent_format = get_equivalent_other_alphaness_format(format);
+        if (!equivalent_format)
+        {
+            // No equivalent format to try, so bail
+            throw;
+        }
+
+        surface = gbm.create_scanout_surface(
+            size.width.as_uint32_t(),
+            size.height.as_uint32_t(),
+            *equivalent_format,
+            cross_gpu);
         raw_surface = surface.get();
         return std::make_tuple(
             std::move(surface),
+
             mgg::helpers::EGLHelper{
                 config,
                 gbm,
                 raw_surface,
-                gbm_format,
+                *equivalent_format,
                 shared_context
         });
     }
@@ -574,7 +590,7 @@ void mgg::Display::configure_locked(
                 {
                     // TODO: Pull this out of the configuration
                     // TODO: Actually query available formats!
-                    uint32_t gbm_format = GBM_FORMAT_XRGB8888;
+                    mg::DRMFormat format{GBM_FORMAT_XRGB8888};
                     /*
                      * In a hybrid setup a scanout surface needs to be allocated differently if it
                      * needs to be able to be shared across GPUs. This likely reduces performance.
@@ -584,7 +600,7 @@ void mgg::Display::configure_locked(
                      */
                     auto [surface, egl] = make_surface_with_egl_context(
                         current_mode_resolution,
-                        gbm_format,
+                        format,
                         *gbm,
                         *gl_config,
                         shared_egl.context(),
