@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #include "platform.h"
@@ -50,6 +48,12 @@ mgg::Platform::Platform(std::shared_ptr<DisplayReport> const& listener,
 {
 }
 
+mgg::RenderingPlatform::RenderingPlatform(
+    mir::udev::Device const&,
+    std::vector<std::shared_ptr<mg::DisplayPlatform>> const&)
+{
+}
+
 mir::UniqueModulePtr<mg::GraphicBufferAllocator> mgg::RenderingPlatform::create_buffer_allocator(
     mg::Display const& output)
 {
