@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #ifndef MIR_GRAPHICS_GBM_PLATFORM_H_
@@ -63,6 +61,9 @@ private:
 
 class RenderingPlatform : public graphics::RenderingPlatform
 {
+public:
+    RenderingPlatform(udev::Device const& device, std::vector<std::shared_ptr<graphics::DisplayPlatform>> const& displays);
+
     auto create_buffer_allocator(
         graphics::Display const& output) -> UniqueModulePtr<graphics::GraphicBufferAllocator> override;
 };
