@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #include "quirks.h"
@@ -60,52 +58,45 @@ public:
 
         for (auto const& quirk : options.get<std::vector<std::string>>(quirks_option_name))
         {
-            // Quirk format is skip:(devnode|driver):value
+            auto const disable_kms_probe = "disable-kms-probe:";
+            auto const skip_devnode = "skip:devnode:";
+            auto const skip_driver = "skip:driver:";
+            auto const allow_devnode = "allow:devnode:";
+            auto const allow_driver = "allow:driver:";
 
-            if (quirk.size() < 5)
+            if (quirk.starts_with(skip_devnode))
             {
-                mir::log_warning(
-                    "Ignoring unexpected value for %s option: %s (expects value of the form “skip:<type>:<value>”)",
-                    quirks_option_name,
-                    quirk.c_str());
+                devnodes_to_skip.insert(quirk.substr(strlen(skip_devnode)));
                 continue;
             }
-            if (strncmp(quirk.c_str(), "skip:", strlen("skip:")) != 0)
+            else if (quirk.starts_with(skip_driver))
             {
-                mir::log_warning(
-                    "Ignoring unexpected value for %s option: %s (expects value of the form “skip:<type>:<value>”)",
-                    quirks_option_name,
-                    quirk.c_str());
+                drivers_to_skip.insert(quirk.substr(strlen(skip_driver)));
+                continue;
+            }
+            else if (quirk.starts_with(allow_devnode))
+            {
+                devnodes_to_skip.erase(quirk.substr(strlen(allow_devnode)));
+                continue;
+            }
+            else if (quirk.starts_with(allow_driver))
+            {
+                drivers_to_skip.erase(quirk.substr(strlen(allow_driver)));
+                continue;
+            }
+            else if (quirk.starts_with(disable_kms_probe))
+            {
+                // Quirk format is disable-kms-probe:value
+                skip_modesetting_support.emplace(quirk.substr(strlen(disable_kms_probe)));
                 continue;
             }
 
-            auto type_delimeter_pos = quirk.find(':', 5);
-            if (type_delimeter_pos == std::string::npos)
-            {
-                mir::log_warning(
-                    "Ignoring unexpected value for %s option: %s (expects value of the form “skip:<type>:<value>”)",
-                    quirks_option_name,
-                    quirk.c_str());
-                continue;
-            }
-            auto const type = quirk.substr(5, type_delimeter_pos - 5);
-            auto const value = quirk.substr(type_delimeter_pos + 1);
-            if (type == "devnode")
-            {
-                devnodes_to_skip.insert(value);
-            }
-            else if (type == "driver")
-            {
-                drivers_to_skip.insert(value);
-            }
-            else
-            {
-                mir::log_warning(
-                    "Ignoring unexpected value for %s option: %s (valid types are “devnode” and “driver”)",
-                    quirks_option_name,
-                    type.c_str());
-                continue;
-            }
+            // If we didn't `continue` above, we're ignoring...
+            mir::log_warning(
+                "Ignoring unexpected value for %s option: %s "
+                "(expects value of the form “skip:<type>:<value>”, “allow:<type>:<value>” or ”disable-kms-probe:<value>”)",
+                quirks_option_name,
+                quirk.c_str());
         }
     }
 
@@ -137,9 +128,37 @@ public:
         return should_skip_driver || should_skip_devnode;
     }
 
+    auto require_modesetting_support(mir::udev::Device const& device) const -> bool
+    {
+        auto const devnode = value_or(device.devnode(), "");
+        auto const parent_device = device.parent();
+        auto const driver =
+            [&]()
+            {
+                if (parent_device)
+                {
+                    return value_or(parent_device->driver(), "");
+                }
+                mir::log_warning("udev device has no parent! Unable to determine driver for quirks.");
+                return "<UNKNOWN>";
+            }();
+        mir::log_debug("Quirks: checking device with devnode: %s, driver %s", device.devnode(), driver);
+
+        bool const should_skip_modesetting_support = skip_modesetting_support.count(driver);
+        if (should_skip_modesetting_support)
+        {
+            mir::log_info("Quirks: skipping modesetting check %s (matches driver quirk %s)", devnode, driver);
+        }
+        return !should_skip_modesetting_support;
+    }
+
 private:
-    std::unordered_set<std::string> drivers_to_skip;
+    // Mir's gbm-kms support isn't (yet) working with nvidia
+    // Mir's gbm-kms support isn't (yet) working with evdi
+    std::unordered_set<std::string> drivers_to_skip = { "nvidia", "evdi" };
     std::unordered_set<std::string> devnodes_to_skip;
+    // We know this is currently useful for virtio_gpu, vc4-drm and v3d
+    std::unordered_set<std::string> skip_modesetting_support = { "virtio_gpu", "vc4-drm", "v3d" };
 };
 
 mgg::Quirks::Quirks(const options::Option& options)
@@ -161,3 +180,21 @@ void mgg::Quirks::add_quirks_option(boost::program_options::options_description&
          boost::program_options::value<std::vector<std::string>>(),
          "[platform-specific] Driver quirks to apply (may be specified multiple times; multiple quirks are combined)");
 }
+
+auto mir::graphics::gbm::Quirks::require_modesetting_support(mir::udev::Device const& device) const -> bool
+{
+    if (getenv("MIR_MESA_KMS_DISABLE_MODESET_PROBE") != nullptr)
+    {
+        mir::log_debug("MIR_MESA_KMS_DISABLE_MODESET_PROBE is set");
+        return false;
+    }
+    else if (getenv("MIR_GBM_KMS_DISABLE_MODESET_PROBE")  != nullptr)
+    {
+        mir::log_debug("MIR_GBM_KMS_DISABLE_MODESET_PROBE is set");
+        return false;
+    }
+    else
+    {
+        return impl->require_modesetting_support(device);
+    }
+}
