@@ -12,9 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by:
- *   Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #include <boost/throw_exception.hpp>
@@ -35,7 +32,7 @@
 #include "mir/renderer/gl/context.h"
 #include "mir/graphics/program_factory.h"
 #include "mir/graphics/program.h"
-#include "egl_context_executor.h"
+#include "mir/graphics/egl_context_executor.h"
 #include "mir/executor.h"
 #include "shm_buffer.h"
 #include "buffer_allocator.h"
@@ -471,7 +468,7 @@ public:
     {
         ShmBuffer::bind();
 
-        std::lock_guard<std::mutex> lock{consumption_mutex};
+        std::lock_guard lock{consumption_mutex};
         if (on_consumed)
         {
             auto const pixels = std::make_unique<unsigned char[]>(stride().as_uint32_t() * size().height.as_uint32_t());
