@@ -12,9 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by:
- *   Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #include <bcm_host.h>
@@ -33,7 +30,6 @@
 #include "mir/graphics/display_configuration.h"
 #include "mir/graphics/egl_error.h"
 #include "mir/graphics/gl_config.h"
-#include "mir/graphics/virtual_output.h"
 #include "mir/renderer/gl/context.h"
 #include "mir/signal_blocker.h"
 
@@ -49,12 +45,6 @@ public:
     {
     }
 
-    void for_each_card(std::function<void(mg::DisplayConfigurationCard const&)> f) const override
-    {
-        mg::DisplayConfigurationCard const the_card{mg::DisplayConfigurationCardId{1}, 1};
-        f(the_card);
-    }
-
     void for_each_output(std::function<void(mg::DisplayConfigurationOutput const&)> f) const override
     {
         f(the_output);
@@ -274,13 +264,6 @@ auto mg::rpi::Display::create_hardware_cursor() -> std::shared_ptr<Cursor>
     return {};
 }
 
-auto mg::rpi::Display::create_virtual_output(int /*width*/, int /*height*/) -> std::unique_ptr<VirtualOutput>
-{
-    // TODO: Is this an interface we need
-    // TODO: Implement this; dispmanx is perfectly happy to do offscreen rendering
-    return {nullptr};
-}
-
 auto mg::rpi::Display::last_frame_on(unsigned /*output_id*/) const -> Frame
 {
     return {};
