@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #ifndef MIR_DISPLAY_H
@@ -56,7 +54,6 @@ public:
     void pause() override;
     void resume() override;
     std::shared_ptr<Cursor> create_hardware_cursor() override;
-    std::unique_ptr<VirtualOutput> create_virtual_output(int width, int height) override;
     Frame last_frame_on(unsigned output_id) const override;
 
     auto create_gl_context() const -> std::unique_ptr<renderer::gl::Context> override;
