@@ -24,12 +24,11 @@
 #include <mir/graphics/display.h>
 #include <mir/graphics/display_report.h>
 #include <mir/renderer/gl/context_source.h>
-#include <mir/geometry/point_f.h>
-#include <mir/geometry/displacement_f.h>
 
 #include <xkbcommon/xkbcommon.h>
 
 #include <thread>
+#include <deque>
 
 namespace mir
 {
@@ -90,8 +89,6 @@ public:
 
     auto create_hardware_cursor() -> std::shared_ptr<Cursor>override;
 
-    auto create_virtual_output(int width, int height) -> std::unique_ptr<VirtualOutput> override;
-
     auto last_frame_on(unsigned output_id) const -> Frame override;
 
     auto create_gl_context() const -> std::unique_ptr<mir::renderer::gl::Context> override;
@@ -148,10 +145,14 @@ private:
     std::chrono::nanoseconds touch_time;
 
     std::thread runner;
-    void run() const;
+    void run();
     void stop();
     auto get_touch_contact(int32_t id) -> decltype(touch_contacts)::iterator;
     void flush_wl() const;
+
+    std::mutex workqueue_mutex;
+    std::deque<std::function<void()>> workqueue;
+    void spawn(std::function<void()>&& work) override;
 };
 
 }
