@@ -46,8 +46,7 @@ public:
     Output(
         wl_output* output,
         DisplayClient* owner,
-        std::function<void(Output const&)> on_constructed,
-        std::function<void(Output const&)> on_change);
+        std::function<void()> on_change);
 
     ~Output();
 
@@ -58,11 +57,23 @@ public:
 
     DisplayConfigurationOutput dcout;
 
-    static void done(void* data, wl_output* output);
+    wl_output* const output;
+    DisplayClient* const owner;
 
-    static void geometry(
-        void* data,
-        wl_output* wl_output,
+    wl_surface* const surface;
+    xdg_surface* shell_surface{nullptr};
+    xdg_toplevel* shell_toplevel{nullptr};
+
+    EGLContext eglctx{EGL_NO_CONTEXT};
+    wl_egl_window* egl_window{nullptr};
+    EGLSurface eglsurface{EGL_NO_SURFACE};
+
+    std::optional<geometry::Size> pending_toplevel_size;
+    bool has_initialized{false};
+    std::function<void()> on_change;
+
+    // wl_output events
+    void geometry(
         int32_t x,
         int32_t y,
         int32_t physical_width,
@@ -71,32 +82,16 @@ public:
         const char* make,
         const char* model,
         int32_t transform);
+    void mode(uint32_t flags, int32_t width, int32_t height, int32_t refresh);
+    void scale(int32_t factor);
+    void done();
 
-    static void mode(
-        void* data,
-        wl_output* wl_output,
-        uint32_t flags,
-        int32_t width,
-        int32_t height,
-        int32_t refresh);
-
-    static void scale(void* data, wl_output* wl_output, int32_t factor);
-
-    static wl_output_listener const output_listener;
-
-    wl_output* const output;
-    DisplayClient const* const owner;
-
-    wl_surface* const surface;
-    wl_shell_surface* window{nullptr};
-
-    EGLContext eglctx{EGL_NO_CONTEXT};
-    EGLSurface eglsurface{EGL_NO_SURFACE};
-
-    std::function<void(Output const&)> on_done;
+    // XDG shell events
+    void toplevel_configure(int32_t width, int32_t height, wl_array* states);
+    void surface_configure(uint32_t serial);
 
     // DisplaySyncGroup implementation
-    void for_each_display_buffer(std::function<void(DisplayBuffer&)> const& /*f*/) override;
+    void for_each_display_buffer(std::function<void(DisplayBuffer&)> const& f) override;
     void post() override;
     std::chrono::milliseconds recommended_sleep() const override;
 
@@ -122,9 +117,77 @@ static EGLint const ctxattribs[] =
     };
 }
 
+mgw::DisplayClient::Output::Output(
+    wl_output* output,
+    DisplayClient* owner,
+    std::function<void()> on_change) :
+    output{output},
+    owner{owner},
+    surface{wl_compositor_create_surface(owner->compositor)},
+    on_change{std::move(on_change)}
+{
+    // If building against newer Wayland protocol definitions we may miss trailing fields
+    #pragma GCC diagnostic push
+    #pragma GCC diagnostic ignored "-Wmissing-field-initializers"
+    static wl_output_listener const output_listener{
+        [](void* self, auto, auto... args) { static_cast<Output*>(self)->geometry(args...); },
+        [](void* self, auto, auto... args) { static_cast<Output*>(self)->mode(args...); },
+        [](void* self, auto, auto... args) { static_cast<Output*>(self)->done(args...); },
+        [](void* self, auto, auto... args) { static_cast<Output*>(self)->scale(args...); },
+    };
+    #pragma GCC diagnostic pop
+    wl_output_add_listener(output, &output_listener, this);
+
+    dcout.id = (DisplayConfigurationOutputId)owner->bound_outputs.size();
+    dcout.card_id = DisplayConfigurationCardId{1};
+    dcout.type = DisplayConfigurationOutputType::unknown;
+    dcout.pixel_formats = {mir_pixel_format_argb_8888,mir_pixel_format_xrgb_8888};
+    dcout.current_format = mir_pixel_format_xrgb_8888;
+    dcout.connected = true;
+    dcout.used = true;
+    dcout.power_mode = mir_power_mode_on;
+    dcout.orientation = MirOrientation::mir_orientation_normal;
+    dcout.scale = 1.0;
+    dcout.form_factor = MirFormFactor::mir_form_factor_monitor;
+    dcout.gamma_supported = MirOutputGammaSupported::mir_output_gamma_unsupported;
+}
+
+mgw::DisplayClient::Output::~Output()
+{
+    if (output)
+    {
+        wl_output_destroy(output);
+    }
+
+    if (shell_toplevel)
+    {
+        xdg_toplevel_destroy(shell_toplevel);
+    }
+
+    if (shell_surface)
+    {
+        xdg_surface_destroy(shell_surface);
+    }
+
+    wl_surface_destroy(surface);
+
+    if (eglsurface != EGL_NO_SURFACE)
+    {
+        eglDestroySurface(owner->egldisplay, eglsurface);
+    }
+
+    if (egl_window != nullptr)
+    {
+        wl_egl_window_destroy(egl_window);
+    }
+
+    if (eglctx != EGL_NO_CONTEXT)
+    {
+        eglDestroyContext(owner->egldisplay, eglctx);
+    }
+}
+
 void mgw::DisplayClient::Output::geometry(
-    void* data,
-    struct wl_output* /*wl_output*/,
     int32_t x,
     int32_t y,
     int32_t physical_width,
@@ -134,9 +197,6 @@ void mgw::DisplayClient::Output::geometry(
     const char */*model*/,
     int32_t transform)
 {
-    auto output = static_cast<Output*>(data);
-
-    auto& dcout = output->dcout;
     dcout.top_left = {x, y};
     dcout.physical_size_mm = {physical_width, physical_height};
 
@@ -191,16 +251,8 @@ void mgw::DisplayClient::Output::geometry(
     }
 }
 
-void mgw::DisplayClient::Output::mode(
-    void *data,
-    struct wl_output* /*wl_output*/,
-    uint32_t flags,
-    int32_t width,
-    int32_t height,
-    int32_t refresh)
+void mgw::DisplayClient::Output::mode(uint32_t flags, int32_t width, int32_t height, int32_t refresh)
 {
-    auto const output = static_cast<Output*>(data);
-    auto& dcout = output->dcout;
     auto& modes = dcout.modes;
 
     auto const mode = DisplayConfigurationMode{{width, height}, refresh/1000.0};
@@ -223,99 +275,78 @@ void mgw::DisplayClient::Output::mode(
     }
 }
 
-void mgw::DisplayClient::Output::scale(void* data, wl_output* /*wl_output*/, int32_t factor)
+void mgw::DisplayClient::Output::scale(int32_t factor)
 {
-    auto const output = static_cast<Output*>(data);
-    auto& dcout = output->dcout;
     dcout.scale = factor;
 }
 
-mgw::DisplayClient::Output::Output(
-    wl_output* output,
-    DisplayClient* owner,
-    std::function<void(Output const&)> on_constructed,
-    std::function<void(Output const&)> on_change) :
-    output{output},
-    owner{owner},
-    surface{wl_compositor_create_surface(owner->compositor)},
-    on_done{[this, on_constructed = std::move(on_constructed), on_change=std::move(on_change)]
-        (Output const& o) mutable { on_constructed(o), on_done = std::move(on_change); }}
+void mgw::DisplayClient::Output::done()
 {
-    wl_output_add_listener(output, &output_listener, this);
+    if (!shell_surface)
+    {
+        static xdg_surface_listener const shell_surface_listener{
+            [](void* self, auto, auto... args) { static_cast<Output*>(self)->surface_configure(args...); },
+        };
+        shell_surface = xdg_wm_base_get_xdg_surface(owner->shell, surface);
+        xdg_surface_add_listener(shell_surface, &shell_surface_listener, this);
 
-    dcout.id = (DisplayConfigurationOutputId)owner->bound_outputs.size();
-    dcout.card_id = DisplayConfigurationCardId{1};
-    dcout.type = DisplayConfigurationOutputType::unknown;
-    dcout.pixel_formats = {mir_pixel_format_argb_8888,mir_pixel_format_xrgb_8888};
-    dcout.current_format = mir_pixel_format_xrgb_8888;
-    dcout.connected = true;
-    dcout.used = true;
-    dcout.power_mode = mir_power_mode_on;
-    dcout.orientation = MirOrientation::mir_orientation_normal;
-    dcout.scale = 1.0;
-    dcout.form_factor = MirFormFactor::mir_form_factor_monitor;
-    dcout.gamma_supported = MirOutputGammaSupported::mir_output_gamma_unsupported;
+        static xdg_toplevel_listener const shell_toplevel_listener{
+            [](void* self, auto, auto... args) { static_cast<Output*>(self)->toplevel_configure(args...); },
+            [](auto...){},
+        };
+        shell_toplevel = xdg_surface_get_toplevel(shell_surface);
+        xdg_toplevel_add_listener(shell_toplevel, &shell_toplevel_listener, this);
+
+        xdg_toplevel_set_fullscreen(shell_toplevel, output);
+        wl_surface_set_buffer_scale(surface, round(dcout.scale));
+        wl_surface_commit(surface);
+
+        // After the next roundtrip the surface should be configured
+    }
+    else
+    {
+        on_change();
+    }
 }
 
-mgw::DisplayClient::Output::~Output()
+void mgw::DisplayClient::Output::toplevel_configure(int32_t width, int32_t height, wl_array* states)
 {
-    if (output)
-        wl_output_destroy(output);
-
-    if (window)
-        wl_shell_surface_destroy(window);
-
-    wl_surface_destroy(surface);
-
-    if (eglsurface != EGL_NO_SURFACE)
-        eglDestroySurface(owner->egldisplay, eglsurface);
-
-    if (eglctx != EGL_NO_CONTEXT)
-        eglDestroyContext(owner->egldisplay, eglctx);
+    (void)states;
+    pending_toplevel_size = geometry::Size{
+        width ? width : 1280,
+        height ? height : 1024};
 }
 
-
-// If building against newer Wayland protocol definitions we may miss trailing fields
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
-wl_output_listener const mgw::DisplayClient::Output::output_listener = {
-    &geometry,
-    &mode,
-    &done,
-    &scale,
-};
-#pragma GCC diagnostic pop
-
-void mgw::DisplayClient::Output::done(void* data, struct wl_output* /*wl_output*/)
+void mgw::DisplayClient::Output::surface_configure(uint32_t serial)
 {
-    auto output = static_cast<Output*>(data);
-    output->on_done(*output);
+    xdg_surface_ack_configure(shell_surface, serial);
+    bool const size_is_changed = pending_toplevel_size && (
+        !dcout.custom_logical_size || dcout.custom_logical_size.value() != pending_toplevel_size.value());
+    dcout.custom_logical_size = pending_toplevel_size.value();
+    pending_toplevel_size.reset();
+    auto const size = dcout.extents().size * dcout.scale;
+    if (!has_initialized)
+    {
+        egl_window = wl_egl_window_create(surface, size.width.as_int(), size.height.as_int());
+        eglsurface = eglCreateWindowSurface(
+            owner->egldisplay,
+            owner->eglconfig,
+            reinterpret_cast<EGLNativeWindowType>(egl_window),
+            nullptr);
+        has_initialized = true;
+    }
+    else if (size_is_changed)
+    {
+        if (egl_window)
+        {
+            wl_egl_window_resize(egl_window, size.width.as_int(), size.height.as_int(), 0, 0);
+        }
+        on_change();
+    }
 }
 
 void mgw::DisplayClient::Output::for_each_display_buffer(std::function<void(DisplayBuffer & )> const& f)
 {
-    if (!window)
-    {
-        static wl_shell_surface_listener const shell_surface_listener{
-            [](void*, wl_shell_surface* shell_surface, uint32_t serial){ wl_shell_surface_pong(shell_surface, serial); },
-            [](void*, wl_shell_surface*, uint32_t, int32_t, int32_t){},
-            [](void*, wl_shell_surface*){}
-        };
-
-        window = wl_shell_get_shell_surface(owner->shell, surface);
-        wl_shell_surface_add_listener(window, &shell_surface_listener, this);
-        wl_shell_surface_set_fullscreen(window, WL_SHELL_SURFACE_FULLSCREEN_METHOD_SCALE, 0, output);
-        wl_surface_set_buffer_scale(surface, round(dcout.scale));
-        wl_display_dispatch(owner->display);
-
-        auto const& size = dcout.modes[dcout.current_mode_index].size;
-
-        eglsurface = eglCreatePlatformWindowSurface(
-            owner->egldisplay,
-            owner->eglconfig,
-            wl_egl_window_create(surface, size.width.as_int(), size.height.as_int()), nullptr);
-    }
-
     f(*this);
 }
 
@@ -366,15 +397,19 @@ void mgw::DisplayClient::Output::swap_buffers()
 {
     struct FrameSync
     {
-        explicit FrameSync(wl_surface* surface) :
-            callback{wl_surface_frame(surface)}
+        explicit FrameSync(wl_surface* surface):
+            surface{surface}
         {
+        }
+
+        void init()
+        {
+            callback = wl_surface_frame(surface);
             static struct wl_callback_listener const frame_listener =
                 {
                     [](void* data, auto... args)
                         { static_cast<FrameSync*>(data)->frame_done(args...); },
                 };
-
             wl_callback_add_listener(callback, &frame_listener, this);
         }
 
@@ -385,23 +420,32 @@ void mgw::DisplayClient::Output::swap_buffers()
 
         void frame_done(wl_callback*, uint32_t)
         {
-            std::lock_guard<decltype(mutex)> lock{mutex};
-            posted = true;
-            cv.notify_all();
+            {
+                std::lock_guard lock{mutex};
+                posted = true;
+            }
+            cv.notify_one();
         }
 
         void wait_for_done()
         {
-            std::unique_lock<decltype(mutex)> lock{mutex};
+            std::unique_lock lock{mutex};
             cv.wait_for(lock, std::chrono::milliseconds{100}, [this]{ return posted; });
         }
 
+        wl_surface* const surface;
+
+        wl_callback* callback;
         std::mutex mutex;
         bool posted = false;
         std::condition_variable cv;
+    };
 
-        wl_callback* const callback;
-    } frame_sync{surface};
+    auto const frame_sync = std::make_shared<FrameSync>(surface);
+    owner->spawn([frame_sync]()
+        {
+            frame_sync->init();
+        });
 
     // Avoid throttling compositing by blocking in eglSwapBuffers().
     // Instead we use the frame "done" notification.
@@ -410,7 +454,7 @@ void mgw::DisplayClient::Output::swap_buffers()
     if (eglSwapBuffers(owner->egldisplay, eglsurface) != EGL_TRUE)
         BOOST_THROW_EXCEPTION(egl_error("Failed to perform buffer swap"));
 
-    frame_sync.wait_for_done();
+    frame_sync->wait_for_done();
 }
 
 void mgw::DisplayClient::Output::bind()
@@ -464,7 +508,7 @@ mgw::DisplayClient::DisplayClient(
     if (!eglInitialize(egldisplay, &major, &minor))
         BOOST_THROW_EXCEPTION(egl_error("Can't eglInitialize"));
 
-    if (major != 1 || minor < 4)
+    if (std::tuple{major, minor} < std::tuple{1, 4})
         BOOST_THROW_EXCEPTION(egl_error("EGL version is not at least 1.4"));
 
     EGLint neglconfigs;
@@ -478,19 +522,41 @@ mgw::DisplayClient::DisplayClient(
     if (eglctx == EGL_NO_CONTEXT)
         BOOST_THROW_EXCEPTION(egl_error("eglCreateContext failed"));
 
-    wl_display_roundtrip(display);
+    auto const has_uninitialized_output = [&]()
+        {
+            for (auto const& pair : bound_outputs)
+            {
+                if (!pair.second->has_initialized)
+                {
+                    return true;
+                }
+            }
+            return false;
+        };
+
+    // Roundtrip once to bind to all output globals, then keep roundtripping until surfaces for all outputs are
+    // initialized
+    do
+    {
+        wl_display_roundtrip(display);
+    } while (has_uninitialized_output());
 }
 
-void mgw::DisplayClient::on_output_changed(Output const* /*output*/)
+void mgw::DisplayClient::on_display_config_changed()
 {
+    std::unique_lock lock{config_change_handlers_mutex};
+    auto const handlers = config_change_handlers;
+    lock.unlock();
+    for (auto const& handler : handlers)
+    {
+        handler();
+    }
 }
 
-void mgw::DisplayClient::on_output_gone(Output const* /*output*/)
-{
-}
-
-void mgw::DisplayClient::on_new_output(Output const* /*output*/)
+void mgw::DisplayClient::delete_outputs_to_be_deleted()
 {
+    std::lock_guard{outputs_mutex};
+    outputs_to_be_deleted.clear();
 }
 
 mgw::DisplayClient::~DisplayClient()
@@ -498,7 +564,7 @@ mgw::DisplayClient::~DisplayClient()
     eglMakeCurrent(egldisplay, EGL_NO_SURFACE, EGL_NO_SURFACE, EGL_NO_CONTEXT);
 
     {
-        std::lock_guard<decltype(outputs_mutex)> lock{outputs_mutex};
+        std::lock_guard lock{outputs_mutex};
         bound_outputs.clear();
     }
     registry.reset();
@@ -540,19 +606,23 @@ void mgw::DisplayClient::new_global(
     {
         auto output =
             static_cast<wl_output*>(wl_registry_bind(registry, id, &wl_output_interface, std::min(version, 2u)));
-        std::lock_guard<decltype(self->outputs_mutex)> lock{self->outputs_mutex};
+        std::lock_guard lock{self->outputs_mutex};
         self->bound_outputs.insert(
             std::make_pair(
                 id,
                 std::make_unique<Output>(
                     output,
                     self,
-                    [self](Output const& output) { self->on_new_output(&output); },
-                    [self](Output const& output) { self->on_output_changed(&output); })));
+                    [self]() { self->on_display_config_changed(); })));
     }
-    else if (strcmp(interface, "wl_shell") == 0)
+    else if (strcmp(interface, xdg_wm_base_interface.name) == 0)
     {
-        self->shell = static_cast<decltype(self->shell)>(wl_registry_bind(registry, id, &wl_shell_interface, std::min(version, 1u)));
+        static xdg_wm_base_listener const shell_listener{
+            [](void*, xdg_wm_base* shell, uint32_t serial){ xdg_wm_base_pong(shell, serial); },
+        };
+        self->shell = static_cast<decltype(self->shell)>(
+            wl_registry_bind(registry, id, &xdg_wm_base_interface, std::min(version, 1u)));
+        xdg_wm_base_add_listener(self->shell, &shell_listener, self);
     }
 }
 
@@ -563,12 +633,13 @@ void mgw::DisplayClient::remove_global(
 {
     DisplayClient* self = static_cast<decltype(self)>(data);
 
-    std::lock_guard<decltype(self->outputs_mutex)> lock{self->outputs_mutex};
+    std::lock_guard lock{self->outputs_mutex};
     auto const output = self->bound_outputs.find(id);
     if (output != self->bound_outputs.end())
     {
-        self->on_output_gone(output->second.get());
+        self->outputs_to_be_deleted.push_back(std::move(output->second));
         self->bound_outputs.erase(output);
+        self->on_display_config_changed();
     }
     // TODO: We should probably also delete any other globals we've bound to that disappear.
 }
@@ -632,7 +703,7 @@ void mgw::DisplayClient::pointer_enter(
     wl_fixed_t /*x*/,
     wl_fixed_t /*y*/)
 {
-    std::lock_guard<decltype(outputs_mutex)> lock{outputs_mutex};
+    std::lock_guard lock{outputs_mutex};
 
     for (auto const& out : bound_outputs)
     {
@@ -700,7 +771,7 @@ void mgw::DisplayClient::touch_down(
     wl_fixed_t /*x*/,
     wl_fixed_t /*y*/)
 {
-    std::lock_guard<decltype(outputs_mutex)> lock{outputs_mutex};
+    std::lock_guard lock{outputs_mutex};
 
     for (auto const& out : bound_outputs)
     {
@@ -757,6 +828,9 @@ void mgw::DisplayClient::touch_orientation(
 // if the new capabilities do not contain the relevant capability.
 void mgw::DisplayClient::seat_capabilities(wl_seat* seat, uint32_t capabilities)
 {
+// If building against newer Wayland protocol definitions we may miss trailing fields
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
     if (capabilities & WL_SEAT_CAPABILITY_POINTER) {
         static wl_pointer_listener pointer_listener =
             {
@@ -809,6 +883,7 @@ void mgw::DisplayClient::seat_capabilities(wl_seat* seat, uint32_t capabilities)
 
         wl_touch_add_listener(wl_seat_get_touch(seat), &touch_listener, this);
     }
+#pragma GCC diagnostic pop
 }
 
 void mgw::DisplayClient::seat_name(wl_seat* /*seat*/, const char */*name*/)
@@ -864,7 +939,6 @@ public:
     explicit WaylandDisplayConfiguration(std::vector<DisplayConfigurationOutput> && outputs);
     WaylandDisplayConfiguration(WaylandDisplayConfiguration const&);
 
-    void for_each_card(std::function<void(DisplayConfigurationCard const&)> f) const override;
     void for_each_output(std::function<void(DisplayConfigurationOutput const&)> f) const override;
     void for_each_output(std::function<void(UserDisplayConfigurationOutput&)> f) override;
     auto clone() const -> std::unique_ptr<DisplayConfiguration> override;
@@ -883,7 +957,7 @@ auto mgw::DisplayClient::display_configuration() const -> std::unique_ptr<Displa
     std::vector<DisplayConfigurationOutput> outputs;
 
     {
-        std::lock_guard<decltype(outputs_mutex)> lock{outputs_mutex};
+        std::lock_guard lock{outputs_mutex};
         for (auto const& output : bound_outputs)
         {
             outputs.push_back(output.second->dcout);
@@ -895,7 +969,7 @@ auto mgw::DisplayClient::display_configuration() const -> std::unique_ptr<Displa
 
 void mgw::DisplayClient::for_each_display_sync_group(const std::function<void(DisplaySyncGroup&)>& f)
 {
-    std::lock_guard<decltype(outputs_mutex)> lock{outputs_mutex};
+    std::lock_guard lock{outputs_mutex};
     for (auto& output : bound_outputs)
     {
         f(*output.second);
@@ -913,12 +987,6 @@ mgw::WaylandDisplayConfiguration::WaylandDisplayConfiguration(WaylandDisplayConf
 {
 }
 
-void mgw::WaylandDisplayConfiguration::for_each_card(
-    std::function<void(DisplayConfigurationCard const&)> f) const
-{
-    f(card);
-}
-
 void mgw::WaylandDisplayConfiguration::for_each_output(
     std::function<void(DisplayConfigurationOutput const&)> f) const
 {
