@@ -24,7 +24,9 @@
 #include <mir/graphics/display_configuration.h>
 #include <mir/renderer/gl/render_target.h>
 #include <mir/graphics/gl_config.h>
+#include <mir/executor.h>
 
+#include "protocol/xdg-shell-client.h"
 #include <wayland-client.h>
 #include <EGL/egl.h>
 
@@ -46,6 +48,7 @@ namespace wayland
 {
 
 class DisplayClient
+    : public Executor
 {
 public:
     DisplayClient(wl_display* display,
@@ -124,12 +127,11 @@ protected:
         wl_fixed_t orientation);
 
     class Output;
-    void on_new_output(Output const*);
-    void on_output_changed(Output const*);
-    void on_output_gone(Output const*);
+    void on_display_config_changed();
+    void delete_outputs_to_be_deleted();
 
     wl_compositor* compositor = nullptr;
-    wl_shell* shell = nullptr;
+    xdg_wm_base* shell = nullptr;
     wl_seat* seat = nullptr;
     wl_shm* shm = nullptr;
 
@@ -163,7 +165,11 @@ protected:
     std::unique_ptr<wl_registry, decltype(&wl_registry_destroy)> registry;
 
     std::mutex mutable outputs_mutex;
+    // Outputs that will be dropped during the next Display::configure(). It is unsafe to actually drop them until then.
+    std::vector<std::unique_ptr<Output>> outputs_to_be_deleted;
     std::unordered_map<uint32_t, std::unique_ptr<Output>> bound_outputs;
+    std::mutex mutable config_change_handlers_mutex;
+    std::vector<DisplayConfigurationChangeHandler> config_change_handlers;
 
     EGLDisplay egldisplay;
     EGLConfig eglconfig;
