@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Cemil Azizoglu <cemil.azizoglu@canonical.com>
  */
 
 #ifndef MIR_GRAPHICS_X_DISPLAY_H_
@@ -21,7 +19,6 @@
 
 #include "mir/graphics/display.h"
 #include "mir/geometry/size.h"
-#include "mir/geometry/size_f.h"
 #include "mir/renderer/gl/context_source.h"
 #include "mir_toolkit/common.h"
 #include "egl_helper.h"
@@ -53,6 +50,7 @@ class X11Window
 {
 public:
     X11Window(mir::X::X11Resources* x11_resources,
+              std::string title,
               EGLDisplay egl_dpy,
               geometry::Size const size,
               EGLConfig const egl_cfg);
@@ -71,6 +69,7 @@ class Display : public graphics::Display
 {
 public:
     explicit Display(std::shared_ptr<mir::X::X11Resources> const& x11_resources,
+                     std::string const title,
                      std::vector<X11OutputConfig> const& requested_size,
                      std::shared_ptr<DisplayConfigurationPolicy> const& initial_conf_policy,
                      std::shared_ptr<GLConfig> const& gl_config,
@@ -98,7 +97,6 @@ public:
     void resume() override;
 
     std::shared_ptr<Cursor> create_hardware_cursor() override;
-    std::unique_ptr<VirtualOutput> create_virtual_output(int width, int height) override;
 
     std::unique_ptr<renderer::gl::Context> create_gl_context() const override;
 
