@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Cemil Azizoglu <cemil.azizoglu@canonical.com>
  */
 
 #ifndef MIR_GRAPHICS_X_PLATFORM_H_
@@ -61,6 +59,7 @@ public:
     static auto parse_output_sizes(std::string output_sizes) -> std::vector<X11OutputConfig>;
 
     explicit Platform(std::shared_ptr<mir::X::X11Resources> const& x11_resources,
+                      std::string const title,
                       std::vector<X11OutputConfig> output_sizes,
                       std::shared_ptr<DisplayReport> const& report);
     ~Platform() = default;
@@ -71,6 +70,7 @@ public:
         std::shared_ptr<GLConfig> const& gl_config) override;
 private:
     std::shared_ptr<mir::X::X11Resources> const x11_resources;
+    std::string const title;
     std::shared_ptr<DisplayReport> const report;
     std::vector<X11OutputConfig> const output_sizes;
 };
