@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "mir/default_server_configuration.h"
@@ -23,13 +21,22 @@
 #include "default_display_buffer_compositor_factory.h"
 #include "multi_threaded_compositor.h"
 #include "gl/renderer_factory.h"
+#include "basic_screen_shooter.h"
+#include "null_screen_shooter.h"
 #include "mir/main_loop.h"
+#include "mir/graphics/display.h"
+#include "mir/executor.h"
+#include "mir/renderer/gl/basic_buffer_render_target.h"
+#include "mir/renderer/gl/context.h"
+#include "mir/renderer/renderer.h"
+#include "mir/log.h"
 
 #include "mir/options/configuration.h"
 
 namespace mc = mir::compositor;
 namespace ms = mir::scene;
 namespace mf = mir::frontend;
+namespace mrg = mir::renderer::gl;
 
 std::shared_ptr<ms::BufferStreamFactory>
 mir::DefaultServerConfiguration::the_buffer_stream_factory()
@@ -87,3 +94,31 @@ std::shared_ptr<mir::renderer::RendererFactory> mir::DefaultServerConfiguration:
             return std::make_shared<mir::renderer::gl::RendererFactory>();
         });
 }
+
+auto mir::DefaultServerConfiguration::the_screen_shooter() -> std::shared_ptr<compositor::ScreenShooter>
+{
+    return screen_shooter(
+        [this]() -> std::shared_ptr<compositor::ScreenShooter>
+        {
+            try
+            {
+                auto render_target = std::make_unique<mrg::BasicBufferRenderTarget>(the_display()->create_gl_context());
+                auto renderer = the_renderer_factory()->create_renderer_for(*render_target);
+                return std::make_shared<compositor::BasicScreenShooter>(
+                    the_scene(),
+                    the_clock(),
+                    thread_pool_executor,
+                    std::move(render_target),
+                    std::move(renderer));
+            }
+            catch (...)
+            {
+                mir::log(
+                    ::mir::logging::Severity::error,
+                    "",
+                    std::current_exception(),
+                    "failed to create BasicScreenShooter");
+                return std::make_shared<compositor::NullScreenShooter>(thread_pool_executor);
+            }
+        });
+}
