@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
 #include "dropping_schedule.h"
@@ -29,13 +27,13 @@ mc::DroppingSchedule::DroppingSchedule()
 
 void mc::DroppingSchedule::schedule(std::shared_ptr<mg::Buffer> const& buffer)
 {
-    std::lock_guard<decltype(mutex)> lk(mutex);
+    std::lock_guard lk(mutex);
     the_only_buffer = buffer;
 }
 
 unsigned int mc::DroppingSchedule::num_scheduled()
 {
-    std::lock_guard<decltype(mutex)> lk(mutex);
+    std::lock_guard lk(mutex);
     if (the_only_buffer)
         return 1;
     else
@@ -44,7 +42,7 @@ unsigned int mc::DroppingSchedule::num_scheduled()
 
 std::shared_ptr<mg::Buffer> mc::DroppingSchedule::next_buffer()
 {
-    std::lock_guard<decltype(mutex)> lk(mutex);
+    std::lock_guard lk(mutex);
     if (!the_only_buffer)
         BOOST_THROW_EXCEPTION(std::logic_error("no buffer scheduled"));
     auto buffer = the_only_buffer;
