@@ -12,14 +12,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #ifndef MIR_COMPOSITOR_MULTI_THREADED_COMPOSITOR_H_
 #define MIR_COMPOSITOR_MULTI_THREADED_COMPOSITOR_H_
 
 #include "mir/compositor/compositor.h"
+#include "mir/geometry/forward.h"
 
 #include <mutex>
 #include <memory>
@@ -30,7 +29,6 @@
 
 namespace mir
 {
-namespace geometry { struct Rectangle; }
 namespace graphics
 {
 class Display;
