@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
 #include "queueing_schedule.h"
@@ -25,7 +23,7 @@ namespace mg = mir::graphics;
 
 void mc::QueueingSchedule::schedule(std::shared_ptr<graphics::Buffer> const& buffer)
 {
-    std::lock_guard<decltype(mutex)> lk(mutex);
+    std::lock_guard lk(mutex);
     auto it = std::find(queue.begin(), queue.end(), buffer);
     if (it != queue.end())
         queue.erase(it);
@@ -34,13 +32,13 @@ void mc::QueueingSchedule::schedule(std::shared_ptr<graphics::Buffer> const& buf
 
 unsigned int mc::QueueingSchedule::num_scheduled()
 {
-    std::lock_guard<decltype(mutex)> lk(mutex);
+    std::lock_guard lk(mutex);
     return queue.size();
 }
 
 std::shared_ptr<mg::Buffer> mc::QueueingSchedule::next_buffer()
 {
-    std::lock_guard<decltype(mutex)> lk(mutex);
+    std::lock_guard lk(mutex);
     if (queue.empty())
         BOOST_THROW_EXCEPTION(std::logic_error("no buffer scheduled"));
     auto buffer = queue.front();
