@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #include "linux_virtual_terminal.h"
@@ -23,6 +21,7 @@
 #include "mir/emergency_cleanup_registry.h"
 #include "ioctl_vt_switcher.h"
 #include "mir/raii.h"
+#include "mir/synchronised.h"
 
 #define MIR_LOG_COMPONTENT "VT-handler"
 #include "mir/log.h"
@@ -70,7 +69,7 @@ public:
             : devices{std::move(devices)}
         {
         }
-        Synchronised<std::vector<Device*>>::Locked devices;
+        Synchronised<std::vector<Device*>>::Locked const devices;
     };
 
     DeviceListIterable as_iterable()
