@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #ifndef MIR_GRAPHICS_GBM_LINUX_VIRTUAL_TERMINAL_H_
@@ -21,8 +19,6 @@
 
 #include "mir/console_services.h"
 
-#include "mir/synchronised.h"
-
 #include <memory>
 #include <linux/vt.h>
 #include <termios.h>
