@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: William Wold <william.wold@canonical.com>
  */
 
 #include "foreign_toplevel_manager_v1.h"
@@ -102,7 +100,6 @@ class ForeignSurfaceObserver
 {
 public:
     ForeignSurfaceObserver(
-        std::shared_ptr<Executor> const& wayland_executor,
         wayland::Weak<ForeignToplevelManagerV1> manager,
         std::shared_ptr<scene::Surface> const& surface);
     ~ForeignSurfaceObserver();
@@ -117,11 +114,10 @@ private:
     /// Surface observer
     ///@{
     void attrib_changed(scene::Surface const*, MirWindowAttrib attrib, int) override;
-    void renamed(scene::Surface const*, char const* name) override;
+    void renamed(scene::Surface const*, std::string const& name) override;
     void application_id_set_to(scene::Surface const*, std::string const& application_id) override;
     ///@}
 
-    std::shared_ptr<Executor> const wayland_executor;
     wayland::Weak<ForeignToplevelManagerV1> const manager;
 
     std::mutex mutex;
@@ -238,7 +234,7 @@ void mf::ForeignSceneObserver::surface_added(std::shared_ptr<scene::Surface> con
 
 void mf::ForeignSceneObserver::surface_removed(std::shared_ptr<scene::Surface> const& surface)
 {
-    std::lock_guard<std::mutex> lock{mutex};
+    std::lock_guard lock{mutex};
     auto const iter = surface_observers.find(surface);
     if (iter == surface_observers.end())
     {
@@ -265,9 +261,9 @@ void mf::ForeignSceneObserver::end_observation()
 
 void mf::ForeignSceneObserver::create_surface_observer(std::shared_ptr<scene::Surface> const& surface)
 {
-    std::lock_guard<std::mutex> lock{mutex};
-    auto observer = std::make_shared<ForeignSurfaceObserver>(wayland_executor, manager, surface);
-    surface->add_observer(observer);
+    std::lock_guard lock{mutex};
+    auto observer = std::make_shared<ForeignSurfaceObserver>(manager, surface);
+    surface->register_interest(observer, *wayland_executor);
     auto insert_result = surface_observers.insert(std::make_pair(surface, observer));
     if (!insert_result.second)
     {
@@ -280,13 +276,13 @@ void mf::ForeignSceneObserver::create_surface_observer(std::shared_ptr<scene::Su
 
 void mf::ForeignSceneObserver::clear_surface_observers()
 {
-    std::lock_guard<std::mutex> lock{mutex};
+    std::lock_guard lock{mutex};
     for (auto const& pair : surface_observers)
     {
         pair.second->cease_and_desist();
         if (auto const surface = pair.first.lock())
         {
-            surface->remove_observer(pair.second);
+            surface->unregister_interest(*pair.second);
         }
     }
     surface_observers.clear();
@@ -295,14 +291,12 @@ void mf::ForeignSceneObserver::clear_surface_observers()
 // ForeignSurfaceObserver
 
 mf::ForeignSurfaceObserver::ForeignSurfaceObserver(
-    std::shared_ptr<Executor> const& wayland_executor,
     mw::Weak<ForeignToplevelManagerV1> manager,
     std::shared_ptr<scene::Surface> const& surface)
-    : wayland_executor{wayland_executor},
-      manager{manager},
+    : manager{manager},
       weak_surface{surface}
 {
-    std::lock_guard<std::mutex> lock{mutex};
+    std::lock_guard lock{mutex};
     create_or_close_toplevel_handle_as_needed(lock);
 }
 
@@ -313,7 +307,7 @@ mf::ForeignSurfaceObserver::~ForeignSurfaceObserver()
 
 void mf::ForeignSurfaceObserver::cease_and_desist()
 {
-    std::lock_guard<std::mutex> lock{mutex};
+    std::lock_guard lock{mutex};
     weak_surface.reset();
     create_or_close_toplevel_handle_as_needed(lock);
 }
@@ -322,16 +316,9 @@ void mf::ForeignSurfaceObserver::with_toplevel_handle(
     std::lock_guard<std::mutex>&,
     std::function<void(ForeignToplevelHandleV1&)>&& action)
 {
-    if (handle)
+    if (handle && *handle)
     {
-        wayland_executor->spawn(
-            [handle = handle, action = std::move(action)]()
-            {
-                if (*handle)
-                {
-                    action(handle->value());
-                }
-            });
+        action(handle->value());
     }
 }
 
@@ -385,23 +372,20 @@ void mf::ForeignSurfaceObserver::create_or_close_toplevel_handle_as_needed(std::
             auto const focused = surface->focus_state();
             auto const state = surface->state_tracker();
 
-            wayland_executor->spawn([manager = manager, handle = handle, surface, name, app_id, focused, state]()
-                {
-                    // If the manager has been destroyed we can't create a toplevel handle
-                    if (!manager)
-                        return;
+            // If the manager has been destroyed we can't create a toplevel handle
+            if (!manager)
+                return;
 
-                    // Remember Wayland objects manage their own lifetime
-                    auto const handle_ptr = new ForeignToplevelHandleV1{manager.value(), surface};
-                    *handle = mw::make_weak(handle_ptr);
+            // Remember Wayland objects manage their own lifetime
+            auto const handle_ptr = new ForeignToplevelHandleV1{manager.value(), surface};
+            *handle = mw::make_weak(handle_ptr);
 
-                    if (!name.empty())
-                        handle->value().send_title_event(name);
-                    if (!app_id.empty())
-                        handle->value().send_app_id_event(app_id);
-                    handle->value().send_state(focused, state);
-                    handle->value().send_done_event();
-                });
+            if (!name.empty())
+                handle->value().send_title_event(name);
+            if (!app_id.empty())
+                handle->value().send_app_id_event(app_id);
+            handle->value().send_state(focused, state);
+            handle->value().send_done_event();
         }
         else
         {
@@ -416,7 +400,7 @@ void mf::ForeignSurfaceObserver::create_or_close_toplevel_handle_as_needed(std::
 
 void mf::ForeignSurfaceObserver::attrib_changed(const scene::Surface*, MirWindowAttrib attrib, int)
 {
-    std::lock_guard<std::mutex> lock{mutex};
+    std::lock_guard lock{mutex};
 
     auto surface = weak_surface.lock();
     if (!surface)
@@ -461,11 +445,10 @@ void mf::ForeignSurfaceObserver::attrib_changed(const scene::Surface*, MirWindow
     }
 }
 
-void mf::ForeignSurfaceObserver::renamed(ms::Surface const*, char const* name_c_str)
+void mf::ForeignSurfaceObserver::renamed(ms::Surface const*, std::string const& name)
 {
-    std::lock_guard<std::mutex> lock{mutex};
+    std::lock_guard lock{mutex};
 
-    std::string name = name_c_str;
     with_toplevel_handle(lock, [name](ForeignToplevelHandleV1& handle)
         {
             handle.send_title_event(name);
@@ -477,7 +460,7 @@ void mf::ForeignSurfaceObserver::application_id_set_to(
     scene::Surface const*,
     std::string const& application_id)
 {
-    std::lock_guard<std::mutex> lock{mutex};
+    std::lock_guard lock{mutex};
 
     std::string id = application_id;
     with_toplevel_handle(lock, [id](ForeignToplevelHandleV1& handle)
