@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #include "wayland_connector.h"
@@ -21,61 +19,30 @@
 #include "wl_client.h"
 #include "wl_data_device_manager.h"
 #include "wayland_utils.h"
-#include "wl_surface_role.h"
-#include "window_wl_surface_role.h"
 #include "wl_subcompositor.h"
-#include "wl_surface.h"
 #include "wl_seat.h"
 #include "wl_region.h"
 #include "frame_executor.h"
-
 #include "output_manager.h"
 #include "wayland_executor.h"
 
-#include "mir/frontend/wayland.h"
-
 #include "mir/main_loop.h"
-
-#include "mir/compositor/buffer_stream.h"
-
-#include "mir/shell/shell.h"
-#include "mir/shell/surface_specification.h"
-#include "mir/scene/surface.h"
-#include <mir/thread_name.h>
-
-#include "mir/graphics/buffer_properties.h"
-#include "mir/graphics/buffer.h"
+#include "mir/thread_name.h"
+#include "mir/log.h"
 #include "mir/graphics/graphic_buffer_allocator.h"
-
+#include "mir/frontend/wayland.h"
 #include "mir/frontend/buffer_stream_id.h"
 
-#include "mir/input/seat.h"
-#include "mir/input/device.h"
-#include "mir/input/mir_keyboard_config.h"
-#include "mir/input/input_device_hub.h"
-#include "mir/input/input_device_observer.h"
-
-#include <system_error>
 #include <sys/eventfd.h>
+#include <sys/stat.h>
+#include <sys/socket.h>
 #include <wayland-server-core.h>
-#include <unordered_map>
 #include <boost/throw_exception.hpp>
 
 #include <functional>
 #include <type_traits>
-
-#include <xkbcommon/xkbcommon.h>
-#include <linux/input.h>
-#include <mir/log.h>
 #include <cstring>
 
-#include "mir/fd.h"
-
-#include <sys/stat.h>
-#include <sys/socket.h>
-#include <unordered_set>
-#include "mir/anonymous_shm_file.h"
-
 namespace mf = mir::frontend;
 namespace mg = mir::graphics;
 namespace mc = mir::compositor;
@@ -172,236 +139,6 @@ void WlCompositor::Instance::create_region(wl_resource* new_region)
 {
     new WlRegion{new_region};
 }
-
-class WlShellSurface : public wayland::ShellSurface, public WindowWlSurfaceRole
-{
-public:
-    WlShellSurface(
-        wl_resource* new_resource,
-        Executor& wayland_executor,
-        WlSurface* surface,
-        std::shared_ptr<msh::Shell> const& shell,
-        WlSeat& seat,
-        OutputManager* output_manager)
-        : ShellSurface(new_resource, Version<1>()),
-          WindowWlSurfaceRole{wayland_executor, &seat, wayland::ShellSurface::client, surface, shell, output_manager}
-    {
-    }
-
-    ~WlShellSurface() = default;
-
-protected:
-    void surface_destroyed() override
-    {
-        // The spec is a little contradictory:
-        // wl_surface: When a client wants to destroy a wl_surface, they must destroy this 'role object' before the wl_surface
-        // wl_shell_surface: On the server side the object is automatically destroyed when the related wl_surface is destroyed
-        // Without a destroy request, it seems the latter must be correct, so that is what we implement
-        destroy_and_delete();
-    }
-
-    void set_toplevel() override
-    {
-    }
-
-    void set_transient(
-        struct wl_resource* parent,
-        int32_t x,
-        int32_t y,
-        uint32_t flags) override
-    {
-        auto& parent_surface = *WlSurface::from(parent);
-
-        mir::shell::SurfaceSpecification mods;
-
-        if (flags & WL_SHELL_SURFACE_TRANSIENT_INACTIVE)
-            mods.type = mir_window_type_gloss;
-        if (auto parent = parent_surface.scene_surface())
-            mods.parent = parent.value();
-        mods.aux_rect = geom::Rectangle{{x, y}, {}};
-        mods.surface_placement_gravity = mir_placement_gravity_northwest;
-        mods.aux_rect_placement_gravity = mir_placement_gravity_southeast;
-        mods.placement_hints = mir_placement_hints_slide_x;
-        mods.aux_rect_placement_offset_x = 0;
-        mods.aux_rect_placement_offset_y = 0;
-
-        apply_spec(mods);
-    }
-
-    void handle_commit() override {};
-    void handle_state_change(MirWindowState /*new_state*/) override {};
-    void handle_active_change(bool /*is_now_active*/) override {};
-
-    void handle_resize(
-        std::optional<geometry::Point> const& /*new_top_left*/,
-        geometry::Size const& new_size) override
-    {
-        wl_shell_surface_send_configure(resource, WL_SHELL_SURFACE_RESIZE_NONE, new_size.width.as_int(),
-                                        new_size.height.as_int());
-    }
-
-    void handle_close_request() override
-    {
-        // It seems there is no way to request close of a wl_shell_surface
-    }
-
-    void set_fullscreen(
-        uint32_t /*method*/,
-        uint32_t /*framerate*/,
-        std::optional<struct wl_resource*> const& output) override
-    {
-        WindowWlSurfaceRole::set_fullscreen(output);
-    }
-
-    void set_popup(
-        struct wl_resource* /*seat*/,
-        uint32_t /*serial*/,
-        struct wl_resource* parent,
-        int32_t x,
-        int32_t y,
-        uint32_t flags) override
-    {
-        auto& parent_surface = *WlSurface::from(parent);
-
-        mir::shell::SurfaceSpecification mods;
-
-        if (flags & WL_SHELL_SURFACE_TRANSIENT_INACTIVE)
-            mods.type = mir_window_type_gloss;
-        if (auto parent = parent_surface.scene_surface())
-            mods.parent = parent.value();
-        mods.aux_rect = geom::Rectangle{{x, y}, {}};
-        mods.surface_placement_gravity = mir_placement_gravity_northwest;
-        mods.aux_rect_placement_gravity = mir_placement_gravity_southeast;
-        mods.placement_hints = mir_placement_hints_slide_x;
-        mods.aux_rect_placement_offset_x = 0;
-        mods.aux_rect_placement_offset_y = 0;
-
-        apply_spec(mods);
-    }
-
-    void set_maximized(std::optional<struct wl_resource*> const& output) override
-    {
-        (void)output;
-        WindowWlSurfaceRole::add_state_now(mir_window_state_maximized);
-    }
-
-    void set_title(std::string const& title) override
-    {
-        WindowWlSurfaceRole::set_title(title);
-    }
-
-    void pong(uint32_t /*serial*/) override
-    {
-    }
-
-    void move(struct wl_resource* /*seat*/, uint32_t /*serial*/) override
-    {
-        WindowWlSurfaceRole::initiate_interactive_move();
-    }
-
-    void resize(struct wl_resource* /*seat*/, uint32_t /*serial*/, uint32_t edges) override
-    {
-        MirResizeEdge edge = mir_resize_edge_none;
-
-        switch (edges)
-        {
-        case WL_SHELL_SURFACE_RESIZE_TOP:
-            edge = mir_resize_edge_north;
-            break;
-
-        case WL_SHELL_SURFACE_RESIZE_BOTTOM:
-            edge = mir_resize_edge_south;
-            break;
-
-        case WL_SHELL_SURFACE_RESIZE_LEFT:
-            edge = mir_resize_edge_west;
-            break;
-
-        case WL_SHELL_SURFACE_RESIZE_TOP_LEFT:
-            edge = mir_resize_edge_northwest;
-            break;
-
-        case WL_SHELL_SURFACE_RESIZE_BOTTOM_LEFT:
-            edge = mir_resize_edge_southwest;
-            break;
-
-        case WL_SHELL_SURFACE_RESIZE_RIGHT:
-            edge = mir_resize_edge_east;
-            break;
-
-        case WL_SHELL_SURFACE_RESIZE_TOP_RIGHT:
-            edge = mir_resize_edge_northeast;
-            break;
-
-        case WL_SHELL_SURFACE_RESIZE_BOTTOM_RIGHT:
-            edge = mir_resize_edge_southeast;
-            break;
-
-        default:;
-        }
-
-        WindowWlSurfaceRole::initiate_interactive_resize(edge);
-    }
-
-    void set_class(std::string const& /*class_*/) override
-    {
-    }
-};
-
-class WlShell : public wayland::Shell::Global
-{
-public:
-    WlShell(
-        wl_display* display,
-        Executor& wayland_executor,
-        std::shared_ptr<msh::Shell> const& shell,
-        WlSeat& seat,
-        OutputManager* const output_manager)
-        : Global(display, Version<1>()),
-          wayland_executor{wayland_executor},
-          shell{shell},
-          seat{seat},
-          output_manager{output_manager}
-    {
-    }
-
-    static auto get_window(wl_resource* window) -> std::shared_ptr<Surface>;
-
-private:
-    Executor& wayland_executor;
-    std::shared_ptr<msh::Shell> const shell;
-    WlSeat& seat;
-    OutputManager* const output_manager;
-
-    class Instance : public wayland::Shell
-    {
-    public:
-        Instance(wl_resource* new_resource, WlShell* shell)
-            : mw::Shell{new_resource, Version<1>()},
-              shell{shell}
-        {
-        }
-
-    private:
-        WlShell* const shell;
-
-        void get_shell_surface(wl_resource* new_shell_surface, wl_resource* surface) override
-        {
-            new WlShellSurface(
-                new_shell_surface,
-                shell->wayland_executor,
-                WlSurface::from(surface),
-                shell->shell,
-                shell->seat,
-                shell->output_manager);
-        }
-    };
-
-    void bind(wl_resource* new_resource) override
-    {
-        new Instance{new_resource, this};
-    }
-};
 }
 }
 
@@ -449,17 +186,6 @@ std::shared_ptr<mg::GraphicBufferAllocator> allocator_for_display(
 }
 }
 
-auto mf::create_wl_shell(
-    wl_display* display,
-    Executor& wayland_executor,
-    std::shared_ptr<msh::Shell> const& shell,
-    WlSeat* seat,
-    OutputManager* const output_manager)
--> std::shared_ptr<mw::Shell::Global>
-{
-    return std::make_shared<mf::WlShell>(display, wayland_executor, shell, *seat, output_manager);
-}
-
 void mf::WaylandExtensions::init(Context const& context)
 {
     custom_extensions(context);
@@ -489,17 +215,20 @@ void mf::WaylandExtensions::run_builders(wl_display*, std::function<void(std::fu
 
 mf::WaylandConnector::WaylandConnector(
     std::shared_ptr<msh::Shell> const& shell,
-    std::shared_ptr<MirDisplay> const& display_config,
     std::shared_ptr<time::Clock> const& clock,
     std::shared_ptr<mi::InputDeviceHub> const& input_hub,
     std::shared_ptr<mi::Seat> const& seat,
+    std::shared_ptr<ObserverRegistrar<input::KeyboardObserver>> const& keyboard_observer_registrar,
     std::shared_ptr<mi::InputDeviceRegistry> const& input_device_registry,
     std::shared_ptr<mi::CompositeEventFilter> const& composite_event_filter,
     std::shared_ptr<mg::GraphicBufferAllocator> const& allocator,
     std::shared_ptr<mf::SessionAuthorizer> const& session_authorizer,
     std::shared_ptr<SurfaceStack> const& surface_stack,
+    std::shared_ptr<ObserverRegistrar<graphics::DisplayConfigurationObserver>> const& display_config_registrar,
     std::shared_ptr<ms::Clipboard> const& clipboard,
     std::shared_ptr<ms::TextInputHub> const& text_input_hub,
+    std::shared_ptr<ms::IdleHub> const& idle_hub,
+    std::shared_ptr<mc::ScreenShooter> const& screen_shooter,
     std::shared_ptr<MainLoop> const& main_loop,
     bool arw_socket,
     std::unique_ptr<WaylandExtensions> extensions_,
@@ -548,11 +277,18 @@ mf::WaylandConnector::WaylandConnector(
         std::make_shared<FrameExecutor>(*main_loop),
         this->allocator);
     subcompositor_global = std::make_unique<mf::WlSubcompositor>(display.get());
-    seat_global = std::make_unique<mf::WlSeat>(display.get(), clock, input_hub, seat, enable_key_repeat);
+    seat_global = std::make_unique<mf::WlSeat>(
+        display.get(),
+        *executor,
+        clock,
+        input_hub,
+        keyboard_observer_registrar,
+        seat,
+        enable_key_repeat);
     output_manager = std::make_unique<mf::OutputManager>(
         display.get(),
-        display_config,
-        executor);
+        executor,
+        display_config_registrar);
 
     data_device_manager_global = std::make_unique<WlDataDeviceManager>(display.get(), executor, clipboard);
 
@@ -562,11 +298,14 @@ mf::WaylandConnector::WaylandConnector(
         shell,
         clipboard,
         text_input_hub,
+        idle_hub,
         seat_global.get(),
         output_manager.get(),
         surface_stack,
         input_device_registry,
-        composite_event_filter});
+        composite_event_filter,
+        allocator,
+        screen_shooter});
 
     wl_display_init_shm(display.get());
 
@@ -598,6 +337,10 @@ mf::WaylandConnector::WaylandConnector(
 
         this->wayland_display = wayland_display;
     }
+    else
+    {
+        fatal_error("Unable to bind Wayland socket");
+    }
 
     auto wayland_loop = wl_display_get_event_loop(display.get());
 
@@ -785,19 +528,3 @@ auto mf::get_session(wl_resource* surface) -> std::shared_ptr<ms::Session>
     // applicable session for the surface. See WlClient::client_session for details.
     return get_session(wl_resource_get_client(surface));
 }
-
-auto mf::get_wl_shell_window(wl_resource* surface) -> std::shared_ptr<ms::Surface>
-{
-    if (mw::Surface::is_instance(surface))
-    {
-        auto const wlsurface = WlSurface::from(surface);
-        if (auto const scene_surface = wlsurface->scene_surface())
-        {
-            return scene_surface.value();
-        }
-
-        log_debug("No window currently associated with wayland::Surface %p", static_cast<void*>(surface));
-    }
-
-    return {};
-}
