@@ -12,28 +12,30 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #include "mir/default_server_configuration.h"
 #include "mir/frontend/wayland.h"
 
 #include "wayland_connector.h"
+#include "wl_shell.h"
 #include "xdg_shell_v6.h"
 #include "xdg_shell_stable.h"
 #include "layer_shell_v1.h"
 #include "xwayland_wm_shell.h"
-#include "mir_display.h"
 #include "wl_seat.h"
 #include "xdg_output_v1.h"
 #include "foreign_toplevel_manager_v1.h"
 #include "pointer_constraints_unstable_v1.h"
 #include "relative_pointer_unstable_v1.h"
 #include "virtual_keyboard_v1.h"
+#include "virtual_pointer_v1.h"
 #include "text_input_v3.h"
 #include "text_input_v2.h"
+#include "text_input_v1.h"
 #include "input_method_v2.h"
+#include "idle_inhibit_v1.h"
+#include "wlr_screencopy_v1.h"
 
 #include "mir/graphics/platform.h"
 #include "mir/options/default_configuration.h"
@@ -104,7 +106,7 @@ std::vector<ExtensionBuilder> const internal_extension_builders = {
         }),
     make_extension_builder<mw::XdgOutputManagerV1>([](auto const& ctx)
         {
-            return create_xdg_output_manager_v1(ctx.display, ctx.output_manager);
+            return mf::create_xdg_output_manager_v1(ctx.display);
         }),
     make_extension_builder<mw::ForeignToplevelManagerV1>([](auto const& ctx)
         {
@@ -126,6 +128,14 @@ std::vector<ExtensionBuilder> const internal_extension_builders = {
         {
             return mf::create_virtual_keyboard_manager_v1(ctx.display, ctx.input_device_registry);
         }),
+    make_extension_builder<mw::VirtualPointerManagerV1>([](auto const& ctx)
+        {
+            return mf::create_virtual_pointer_manager_v1(ctx.display, ctx.output_manager, ctx.input_device_registry);
+        }),
+    make_extension_builder<mw::TextInputManagerV1>([](auto const& ctx)
+        {
+           return mf::create_text_input_manager_v1(ctx.display, ctx.wayland_executor, ctx.text_input_hub);
+        }),
     make_extension_builder<mw::TextInputManagerV2>([](auto const& ctx)
         {
             return mf::create_text_input_manager_v2(ctx.display, ctx.wayland_executor, ctx.text_input_hub);
@@ -142,6 +152,22 @@ std::vector<ExtensionBuilder> const internal_extension_builders = {
                 ctx.text_input_hub,
                 ctx.composite_event_filter);
         }),
+    make_extension_builder<mw::IdleInhibitManagerV1>([](auto const& ctx)
+        {
+            return mf::create_idle_inhibit_manager_v1(
+                ctx.display,
+                ctx.wayland_executor,
+                ctx.idle_hub);
+        }),
+    make_extension_builder<mw::WlrScreencopyManagerV1>([](auto const& ctx)
+        {
+            return mf::create_wlr_screencopy_manager_unstable_v1(
+                ctx.display,
+                ctx.wayland_executor,
+                ctx.graphic_buffer_allocator,
+                ctx.screen_shooter,
+                ctx.surface_stack);
+        }),
 };
 
 ExtensionBuilder const xwayland_builder {
@@ -161,8 +187,8 @@ struct WaylandExtensions : mf::WaylandExtensions
     WaylandExtensions(
         std::vector<ExtensionBuilder> enabled_internal_builders,
         std::vector<mir::WaylandExtensionHook> enabled_external_hooks) :
-        enabled_internal_builders{move(enabled_internal_builders)},
-        enabled_external_hooks{move(enabled_external_hooks)}
+        enabled_internal_builders{std::move(enabled_internal_builders)},
+        enabled_external_hooks{std::move(enabled_external_hooks)}
     {
     }
 
@@ -226,7 +252,7 @@ auto configure_wayland_extensions(
         mir::log_warning("Wayland extension %s not supported", name.c_str());
     }
 
-    return std::make_unique<WaylandExtensions>(move(enabled_internal_builders), move(enabled_external_hooks));
+    return std::make_unique<WaylandExtensions>(std::move(enabled_internal_builders), std::move(enabled_external_hooks));
 }
 }
 
@@ -237,6 +263,7 @@ auto mf::get_standard_extensions() -> std::vector<std::string>
         mw::XdgWmBase::interface_name,
         mw::XdgShellV6::interface_name,
         mw::XdgOutputManagerV1::interface_name,
+        mw::TextInputManagerV1::interface_name,
         mw::TextInputManagerV2::interface_name,
         mw::TextInputManagerV3::interface_name};
 }
@@ -264,25 +291,24 @@ std::shared_ptr<mf::Connector>
                 enabled_wayland_extensions.begin(),
                 enabled_wayland_extensions.end()};
 
-            auto const display_config = std::make_shared<mf::MirDisplay>(
-                the_frontend_display_changer(),
-                the_display_configuration_observer_registrar());
-
             auto const enable_repeat = options->get<bool>(options::enable_key_repeat_opt);
 
             return std::make_shared<mf::WaylandConnector>(
                 the_shell(),
-                display_config,
                 the_clock(),
                 the_input_device_hub(),
                 the_seat(),
+                the_keyboard_observer_registrar(),
                 the_input_device_registry(),
                 the_composite_event_filter(),
                 the_buffer_allocator(),
                 the_session_authorizer(),
                 the_frontend_surface_stack(),
+                the_display_configuration_observer_registrar(),
                 the_clipboard(),
                 the_text_input_hub(),
+                the_idle_hub(),
+                the_screen_shooter(),
                 the_main_loop(),
                 arw_socket,
                 configure_wayland_extensions(
