@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: William Wold <william.wold@canonical.com>
  */
 
 #ifndef MIR_FRONTEND_WAYLAND_INPUT_DISPATCHER_H
@@ -50,7 +48,6 @@ public:
         WlSurface* wl_surface);
     ~WaylandInputDispatcher() = default;
 
-    void set_focus(bool has_focus);
     void handle_event(MirInputEvent const* event);
 
     auto latest_timestamp() const -> std::chrono::nanoseconds { return timestamp; }
