@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #ifndef MIR_FRONTEND_WINDOW_WL_SURFACE_ROLE_H
@@ -128,7 +126,9 @@ private:
     std::shared_ptr<shell::Shell> const shell;
     std::shared_ptr<scene::Session> const session;
     OutputManager* output_manager;
+    Executor& wayland_executor;
     std::shared_ptr<WaylandSurfaceObserver> const observer;
+    bool scene_surface_marked_ready{false};
     std::weak_ptr<scene::Surface> weak_scene_surface;
 
     /// The explicitly set (not taken from the surface buffer size) uncommitted window size
