@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #include "wl_keyboard.h"
@@ -21,7 +19,6 @@
 #include "wl_surface.h"
 #include "wl_seat.h"
 #include "mir/log.h"
-#include "mir/fatal.h"
 
 #include <xkbcommon/xkbcommon.h>
 #include <cstring> // memcpy
@@ -31,7 +28,7 @@ namespace mw = mir::wayland;
 namespace mi = mir::input;
 
 mf::WlKeyboard::WlKeyboard(wl_resource* new_resource, WlSeat& seat)
-    : wayland::Keyboard{new_resource, Version<6>()},
+    : wayland::Keyboard{new_resource, Version<8>()},
       seat{seat},
       helper{seat.make_keyboard_helper(this)}
 {
@@ -43,17 +40,8 @@ mf::WlKeyboard::~WlKeyboard()
     seat.remove_focus_listener(client, this);
 }
 
-void mf::WlKeyboard::handle_event(MirInputEvent const* event, WlSurface& surface)
+void mf::WlKeyboard::handle_event(MirInputEvent const* event)
 {
-    if (!focused_surface.is(surface))
-    {
-        log_warning(
-            "Sending keyboard event to wl_surface@%u even though it was not explicitly given keyboard focus",
-            wl_resource_get_id(surface.resource));
-
-        focus_on(&surface);
-    }
-
     helper->handle_event(event);
 }
 
@@ -70,8 +58,6 @@ void mf::WlKeyboard::focus_on(WlSurface* surface)
         send_leave_event(serial, focused_surface.value().raw_resource());
     }
 
-    focused_surface = mw::make_weak(surface);
-
     if (surface)
     {
         // TODO: Send the surface's keymap here
@@ -102,15 +88,15 @@ void mf::WlKeyboard::focus_on(WlSurface* surface)
         auto const serial = wl_display_next_serial(wl_client_get_display(client));
         send_enter_event(serial, surface->raw_resource(), &key_state);
         wl_array_release(&key_state);
+        send_modifiers_event(serial, depressed_modifiers, latched_modifiers, locked_modifiers, group_modifiers);
     }
+
+    focused_surface = mw::make_weak(surface);
 }
 
 void mf::WlKeyboard::send_repeat_info(int32_t rate, int32_t delay)
 {
-    if (version_supports_repeat_info())
-    {
-        send_repeat_info_event(rate, delay);
-    }
+    send_repeat_info_event_if_supported(rate, delay);
 }
 
 void mf::WlKeyboard::send_keymap_xkb_v1(mir::Fd const& fd, size_t length)
@@ -127,6 +113,14 @@ void mf::WlKeyboard::send_key(uint32_t timestamp, int scancode, bool down)
 
 void mf::WlKeyboard::send_modifiers(uint32_t depressed, uint32_t latched, uint32_t locked, uint32_t group)
 {
-    auto const serial = wl_display_get_serial(wl_client_get_display(client));
-    send_modifiers_event(serial, depressed, latched, locked, group);
+    depressed_modifiers = depressed;
+    latched_modifiers = latched;
+    locked_modifiers = locked;
+    group_modifiers = group;
+
+    if (focused_surface)
+    {
+        auto const serial = wl_display_get_serial(wl_client_get_display(client));
+        send_modifiers_event(serial, depressed, latched, locked, group);
+    }
 }
