@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #ifndef MIR_FRONTEND_WL_KEYBOARD_H
@@ -39,13 +37,18 @@ public:
 
     ~WlKeyboard();
 
-    void handle_event(MirInputEvent const* event, WlSurface& surface);
+    void handle_event(MirInputEvent const* event);
 
 private:
     WlSeat& seat;
     std::unique_ptr<KeyboardHelper> const helper;
     wayland::Weak<WlSurface> focused_surface;
 
+    uint32_t depressed_modifiers = 0;
+    uint32_t latched_modifiers = 0;
+    uint32_t locked_modifiers = 0;
+    uint32_t group_modifiers = 0;
+
     /// WlSeat::FocusListener override
     void focus_on(WlSurface* surface) override;
 
