@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #include "wayland_wrapper.h"
@@ -26,18 +24,24 @@
 #include "wl_pointer.h"
 #include "wl_touch.h"
 
+#include "mir/executor.h"
+#include "mir/observer_registrar.h"
 #include "mir/input/input_device_observer.h"
 #include "mir/input/input_device_hub.h"
 #include "mir/input/device.h"
 #include "mir/input/parameter_keymap.h"
 #include "mir/input/mir_keyboard_config.h"
+#include "mir/input/keyboard_observer.h"
+#include "mir/scene/surface.h"
 
 #include <mutex>
 #include <algorithm>
 
 namespace mf = mir::frontend;
 namespace mi = mir::input;
+namespace ms = mir::scene;
 namespace mw = mir::wayland;
+namespace mev = mir::events;
 
 template<class T>
 class mf::WlSeat::ListenerList
@@ -131,6 +135,42 @@ void mf::WlSeat::ConfigObserver::changes_complete()
     pending_keymap.reset();
 }
 
+class mf::WlSeat::KeyboardObserver
+    : public input::KeyboardObserver
+{
+public:
+    KeyboardObserver(WlSeat& seat)
+        : seat{seat}
+    {
+    }
+
+    void keyboard_event(std::shared_ptr<MirEvent const> const& event) override
+    {
+        if (seat.focused_surface)
+        {
+            seat.for_each_listener(seat.focused_surface.value().client, [&](WlKeyboard* keyboard)
+                {
+                    keyboard->handle_event(mir_event_get_input_event(event.get()));
+                });
+        }
+    }
+
+    void keyboard_focus_set(std::shared_ptr<mi::Surface> const& surface) override
+    {
+        if (auto const scene_surface = dynamic_cast<ms::Surface*>(surface.get()))
+        {
+            seat.set_focus_to(mw::as_nullable_ptr(scene_surface->wayland_surface()));
+        }
+        else
+        {
+            seat.set_focus_to({});
+        }
+    }
+
+private:
+    WlSeat& seat;
+};
+
 class mf::WlSeat::Instance : public wayland::Seat
 {
 public:
@@ -146,11 +186,13 @@ private:
 
 mf::WlSeat::WlSeat(
     wl_display* display,
+    Executor& wayland_executor,
     std::shared_ptr<time::Clock> const& clock,
     std::shared_ptr<mi::InputDeviceHub> const& input_hub,
+    std::shared_ptr<ObserverRegistrar<input::KeyboardObserver>> const& keyboard_observer_registrar,
     std::shared_ptr<mi::Seat> const& seat,
     bool enable_key_repeat)
-    :   Global(display, Version<6>()),
+    :   Global(display, Version<8>()),
         keymap{std::make_shared<input::ParameterKeymap>()},
         config_observer{
             std::make_shared<ConfigObserver>(
@@ -159,6 +201,8 @@ mf::WlSeat::WlSeat(
                 {
                     keymap = new_keymap;
                 })},
+        keyboard_observer_registrar{keyboard_observer_registrar},
+        keyboard_observer{std::make_shared<KeyboardObserver>(*this)},
         focus_listeners{std::make_shared<ListenerList<FocusListener>>()},
         pointer_listeners{std::make_shared<ListenerList<WlPointer>>()},
         keyboard_listeners{std::make_shared<ListenerList<WlKeyboard>>()},
@@ -169,10 +213,12 @@ mf::WlSeat::WlSeat(
         enable_key_repeat{enable_key_repeat}
 {
     input_hub->add_observer(config_observer);
+    keyboard_observer_registrar->register_interest(keyboard_observer, wayland_executor);
 }
 
 mf::WlSeat::~WlSeat()
 {
+    keyboard_observer_registrar->unregister_interest(*keyboard_observer);
     input_hub->remove_observer(config_observer);
     if (focused_surface)
     {
@@ -206,20 +252,6 @@ auto mf::WlSeat::make_keyboard_helper(KeyboardCallbacks* callbacks) -> std::uniq
     return std::make_unique<KeyboardHelper>(callbacks, keymap, seat, enable_key_repeat);
 }
 
-void mf::WlSeat::notify_focus(WlSurface& surface, bool has_focus)
-{
-    if (has_focus && !focused_surface.is(surface))
-    {
-        // give focus to any surface other than the current one
-        set_focus_to(&surface);
-    }
-    else if (!has_focus && focused_surface.is(surface))
-    {
-        // only take focus away if the newly unfocused surface is the current one
-        set_focus_to(nullptr);
-    }
-}
-
 void mf::WlSeat::bind(wl_resource* new_wl_seat)
 {
     new Instance{new_wl_seat, this};
@@ -260,13 +292,12 @@ void mf::WlSeat::set_focus_to(WlSurface* new_surface)
 }
 
 mf::WlSeat::Instance::Instance(wl_resource* new_resource, mf::WlSeat* seat)
-    : mw::Seat(new_resource, Version<6>()),
+    : mw::Seat(new_resource, Version<8>()),
       seat{seat}
 {
     // TODO: Read the actual capabilities. Do we have a keyboard? Mouse? Touch?
     send_capabilities_event(Capability::pointer | Capability::keyboard | Capability::touch);
-    if (version_supports_name())
-        send_name_event("seat0");
+    send_name_event_if_supported("seat0");
 }
 
 void mf::WlSeat::Instance::get_pointer(wl_resource* new_pointer)
