@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #include "wl_surface.h"
@@ -138,7 +136,7 @@ auto mf::WlSurface::subsurface_at(geom::Point point) -> std::optional<WlSurface*
     geom::Rectangle surface_rect = {geom::Point{}, buffer_size_.value_or(geom::Size{})};
     for (auto& rect : input_shape.value_or(std::vector<geom::Rectangle>{surface_rect}))
     {
-        if (rect.intersection_with(surface_rect).contains(point))
+        if (intersection_of(rect, surface_rect).contains(point))
             return this;
     }
     return std::nullopt;
@@ -205,7 +203,7 @@ void mf::WlSurface::populate_surface_data(std::vector<shell::StreamSpecification
         for (auto rect : input_shape.value())
         {
             rect.top_left = rect.top_left + offset;
-            rect = rect.intersection_with(surface_rect); // clip to surface
+            rect = intersection_of(rect, surface_rect); // clip to surface
             input_shape_accumulator.push_back(rect);
         }
 
@@ -296,7 +294,7 @@ void mf::WlSurface::set_input_region(std::optional<wl_resource*> const& region)
     {
         // since pending.input_shape is an optional optional, this is needed
         auto shape = WlRegion::from(region.value())->rectangle_vector();
-        pending.input_shape = decltype(pending.input_shape)::value_type{move(shape)};
+        pending.input_shape = decltype(pending.input_shape)::value_type{std::move(shape)};
     }
     else
     {
