@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #ifndef MIR_FRONTEND_WL_SURFACE_H
@@ -26,6 +24,7 @@
 #include "mir/geometry/displacement.h"
 #include "mir/geometry/size.h"
 #include "mir/geometry/point.h"
+#include "mir/geometry/rectangle.h"
 
 #include <vector>
 #include <map>
@@ -46,10 +45,6 @@ namespace shell
 {
 struct StreamSpecification;
 }
-namespace geometry
-{
-class Rectangle;
-}
 namespace compositor
 {
 class BufferStream;
