@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: William Wold <william.wold@canonical.com>
  */
 
 #ifndef MIR_FRONTEND_XDG_OUTPUT_V1_H
@@ -28,11 +26,7 @@ namespace mir
 {
 namespace frontend
 {
-class OutputManager;
-
-auto create_xdg_output_manager_v1(struct wl_display* display, OutputManager* const output_manager)
-    -> std::shared_ptr<wayland::XdgOutputManagerV1::Global>;
-
+auto create_xdg_output_manager_v1(struct wl_display* display) -> std::shared_ptr<wayland::XdgOutputManagerV1::Global>;
 }
 }
 
