@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: William Wold <william.wold@canonical.com>
  */
 
 #include "xwayland_surface_role.h"
@@ -160,6 +158,12 @@ void mf::XWaylandSurfaceRole::commit(WlSurfaceState const& state)
         {
             shell->modify_surface(session, surface.value(), spec);
         }
+
+        if (should_be_mapped && !surface_marked_ready)
+        {
+            shell->surface_ready(surface.value());
+            surface_marked_ready = true;
+        }
     }
 }
 
