@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "mir/default_server_configuration.h"
@@ -37,13 +35,13 @@
 #include "mir/emergency_cleanup.h"
 #include "mir/log.h"
 #include "mir/report_exception.h"
+#include "mir/main_loop.h"
 
 #include <boost/throw_exception.hpp>
 
 #include <sstream>
 
 namespace mg = mir::graphics;
-namespace ml = mir::logging;
 
 std::shared_ptr<mg::DisplayConfigurationPolicy>
 mir::DefaultServerConfiguration::the_display_configuration_policy()
@@ -142,7 +140,7 @@ auto mir::DefaultServerConfiguration::the_display_platforms() -> std::vector<std
     if (display_platforms.empty())
     {
         std::stringstream error_report;
-        std::vector<std::shared_ptr<mir::SharedLibrary>> platform_modules;
+        std::vector<std::pair<mg::SupportedDevice, std::shared_ptr<mir::SharedLibrary>>> platform_modules;
 
         try
         {
@@ -157,25 +155,35 @@ auto mir::DefaultServerConfiguration::the_display_platforms() -> std::vector<std
 
             if (the_options()->is_set(options::platform_display_libs))
             {
-                platform_modules =
+                auto const manually_selected_platforms =
                     select_platforms_from_list(the_options()->get<std::string>(options::platform_display_libs), platforms);
 
-                for (auto const& platform : platform_modules)
+                for (auto const& platform : manually_selected_platforms)
                 {
-                    auto const platform_priority =
+                    auto supported_devices =
                         graphics::probe_display_module(
                             *platform,
                             dynamic_cast<mir::options::ProgramOption&>(*the_options()),
                             the_console_services());
 
-                    if (platform_priority < mir::graphics::PlatformPriority::supported)
+                    bool found_supported_device{false};
+                    for (auto& device : supported_devices)
+                    {
+                        if (device.support_level >= mg::PlatformPriority::supported)
+                        {
+                            found_supported_device = true;
+                        }
+                        platform_modules.emplace_back(std::move(device), platform);
+                    }
+
+                    if (!found_supported_device)
                     {
                         auto const describe_module = platform->load_function<mg::DescribeModule>(
                             "describe_graphics_module",
                             MIR_SERVER_GRAPHICS_PLATFORM_VERSION);
                         auto const descriptor = describe_module();
 
-                        mir::log_warning("Manually-specified graphics platform %s does not claim to support this system. Trying anyway...", descriptor->name);
+                        mir::log_warning("Manually-specified display platform %s does not claim to support this system. Trying anyway...", descriptor->name);
                     }
                 }
             }
@@ -184,7 +192,7 @@ auto mir::DefaultServerConfiguration::the_display_platforms() -> std::vector<std
                 platform_modules = mir::graphics::display_modules_for_device(platforms, dynamic_cast<mir::options::ProgramOption&>(*the_options()), the_console_services());
             }
 
-            for (auto const& platform : platform_modules)
+            for (auto const& [device, platform]: platform_modules)
             {
                 auto create_display_platform = platform->load_function<mg::CreateDisplayPlatform>(
                     "create_display_platform",
@@ -195,7 +203,7 @@ auto mir::DefaultServerConfiguration::the_display_platforms() -> std::vector<std
                     MIR_SERVER_GRAPHICS_PLATFORM_VERSION);
 
                 auto description = describe_module();
-                mir::log_info("Selected driver: %s (version %d.%d.%d)",
+                mir::log_info("Selected display driver: %s (version %d.%d.%d)",
                               description->name,
                               description->major_version,
                               description->minor_version,
@@ -204,6 +212,7 @@ auto mir::DefaultServerConfiguration::the_display_platforms() -> std::vector<std
                 // TODO: Do we want to be able to continue on partial failure here?
                 display_platforms.push_back(
                     create_display_platform(
+                        device,
                         the_options(),
                         the_emergency_cleanup(),
                         the_console_services(),
@@ -234,7 +243,7 @@ auto mir::DefaultServerConfiguration::the_rendering_platforms() ->
     if (rendering_platforms.empty())
     {
         std::stringstream error_report;
-        std::vector<std::shared_ptr<mir::SharedLibrary>> platform_modules;
+        std::vector<std::pair<mg::SupportedDevice, std::shared_ptr<mir::SharedLibrary>>> platform_modules;
 
         try
         {
@@ -249,25 +258,35 @@ auto mir::DefaultServerConfiguration::the_rendering_platforms() ->
 
             if (the_options()->is_set(options::platform_rendering_libs))
             {
-                platform_modules =
+                auto const manually_selected_platforms =
                     select_platforms_from_list(the_options()->get<std::string>(options::platform_rendering_libs), platforms);
 
-                for (auto const& platform : platform_modules)
+                for (auto const& platform : manually_selected_platforms)
                 {
-                    auto const platform_priority =
+                    auto supported_devices =
                         graphics::probe_rendering_module(
                             *platform,
                             dynamic_cast<mir::options::ProgramOption&>(*the_options()),
                             the_console_services());
 
-                    if (platform_priority < mir::graphics::PlatformPriority::supported)
+                    bool found_supported_device{false};
+                    for (auto& device : supported_devices)
+                    {
+                        if (device.support_level >= mg::PlatformPriority::supported)
+                        {
+                            found_supported_device = true;
+                        }
+                        platform_modules.emplace_back(std::move(device), platform);
+                    }
+
+                    if (!found_supported_device)
                     {
                         auto const describe_module = platform->load_function<mg::DescribeModule>(
                             "describe_graphics_module",
                             MIR_SERVER_GRAPHICS_PLATFORM_VERSION);
                         auto const descriptor = describe_module();
 
-                        mir::log_warning("Manually-specified graphics platform %s does not claim to support this system. Trying anyway...", descriptor->name);
+                        mir::log_warning("Manually-specified rendering platform %s does not claim to support this system. Trying anyway...", descriptor->name);
                     }
                 }
             }
@@ -276,7 +295,7 @@ auto mir::DefaultServerConfiguration::the_rendering_platforms() ->
                 platform_modules = mir::graphics::rendering_modules_for_device(platforms, dynamic_cast<mir::options::ProgramOption&>(*the_options()), the_console_services());
             }
 
-            for (auto const& platform : platform_modules)
+            for (auto const& [device, platform]: platform_modules)
             {
                 auto create_rendering_platform = platform->load_function<mg::CreateRenderPlatform>(
                     "create_rendering_platform",
@@ -287,7 +306,7 @@ auto mir::DefaultServerConfiguration::the_rendering_platforms() ->
                     MIR_SERVER_GRAPHICS_PLATFORM_VERSION);
 
                 auto description = describe_module();
-                mir::log_info("Selected driver: %s (version %d.%d.%d)",
+                mir::log_info("Selected rendering driver: %s (version %d.%d.%d)",
                               description->name,
                               description->major_version,
                               description->minor_version,
@@ -296,6 +315,8 @@ auto mir::DefaultServerConfiguration::the_rendering_platforms() ->
                 // TODO: Do we want to be able to continue on partial failure here?
                 rendering_platforms.push_back(
                     create_rendering_platform(
+                        device,
+                        the_display_platforms(),
                         *the_options(),
                         *the_emergency_cleanup()));
                 // Add this module to the list searched by the input stack later
