@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #include "display_configuration_observer_multiplexer.h"
@@ -21,15 +19,41 @@
 namespace mg = mir::graphics;
 namespace ms = mir::scene;
 
+mg::DisplayConfigurationObserverMultiplexer::DisplayConfigurationObserverMultiplexer(
+    std::shared_ptr<Executor> const& default_executor)
+    : ObserverMultiplexer(*default_executor),
+      executor{default_executor}
+{
+}
+
+void mg::DisplayConfigurationObserverMultiplexer::register_interest(
+    std::weak_ptr<DisplayConfigurationObserver> const& observer,
+    Executor& executor)
+{
+    std::lock_guard lock{mutex};
+    ObserverMultiplexer::register_interest(observer, executor);
+    auto const shared = observer.lock();
+    if (shared && current_config)
+    {
+        for_single_observer(*shared, &mg::DisplayConfigurationObserver::initial_configuration, current_config);
+    }
+}
+
 void mg::DisplayConfigurationObserverMultiplexer::initial_configuration(
     std::shared_ptr<mg::DisplayConfiguration const> const& config)
 {
+    std::lock_guard lock{mutex};
+    current_config = config;
     for_each_observer(&mg::DisplayConfigurationObserver::initial_configuration, config);
 }
 
 void mg::DisplayConfigurationObserverMultiplexer::configuration_applied(
     std::shared_ptr<mg::DisplayConfiguration const> const& config)
 {
+    {
+        std::lock_guard lock{mutex};
+        current_config = config;
+    }
     for_each_observer(&mg::DisplayConfigurationObserver::configuration_applied, config);
 }
 
@@ -72,10 +96,3 @@ void mg::DisplayConfigurationObserverMultiplexer::configuration_updated_for_sess
 {
     for_each_observer(&mg::DisplayConfigurationObserver::configuration_updated_for_session, session, config);
 }
-
-mg::DisplayConfigurationObserverMultiplexer::DisplayConfigurationObserverMultiplexer(
-    std::shared_ptr<Executor> const& default_executor)
-    : ObserverMultiplexer(*default_executor),
-      executor{default_executor}
-{
-}
