@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Christopher James Halse Rogers <christopher.halse.rogers@canonical.com>
  */
 
 #ifndef MIR_DISPLAY_CONFIGURATION_MULTIPLEXER_H_
@@ -23,6 +21,8 @@
 #include "mir/observer_multiplexer.h"
 #include "mir/graphics/display_configuration_observer.h"
 
+#include <mutex>
+
 namespace mir
 {
 namespace frontend
@@ -36,6 +36,8 @@ class DisplayConfigurationObserverMultiplexer : public ObserverMultiplexer<Displ
 public:
     DisplayConfigurationObserverMultiplexer(std::shared_ptr<Executor> const& default_executor);
 
+    void register_interest(std::weak_ptr<DisplayConfigurationObserver> const& observer, Executor& executor) override;
+
     void initial_configuration(std::shared_ptr<DisplayConfiguration const> const& config) override;
 
     void configuration_applied(std::shared_ptr<DisplayConfiguration const> const& config) override;
@@ -61,6 +63,9 @@ public:
 
 private:
     std::shared_ptr<Executor> const executor;
+
+    std::mutex mutex;
+    std::shared_ptr<DisplayConfiguration const> current_config;
 };
 
 }
