@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #include "software_cursor.h"
@@ -78,13 +76,13 @@ public:
 
     geom::Rectangle screen_position() const override
     {
-        std::lock_guard<std::mutex> lock{position_mutex};
+        std::lock_guard lock{position_mutex};
         return {position, buffer_->size()};
     }
 
-    std::experimental::optional<geometry::Rectangle> clip_area() const override
+    std::optional<geometry::Rectangle> clip_area() const override
     {
-        return std::experimental::optional<geometry::Rectangle>();
+        return std::optional<geometry::Rectangle>();
     }
 
     float alpha() const override
@@ -104,7 +102,7 @@ public:
 
     void move_to(geom::Point new_position)
     {
-        std::lock_guard<std::mutex> lock{position_mutex};
+        std::lock_guard lock{position_mutex};
         position = new_position;
     }
 
@@ -134,7 +132,7 @@ mg::SoftwareCursor::~SoftwareCursor()
 
 void mg::SoftwareCursor::show(CursorImage const& cursor_image)
 {
-    std::lock_guard<std::mutex> lg{guard};
+    std::lock_guard lg{guard};
 
     auto const to_remove = visible ? renderable : nullptr;
 
@@ -181,7 +179,7 @@ mg::SoftwareCursor::create_renderable_for(CursorImage const& cursor_image, geom:
 
 void mg::SoftwareCursor::hide()
 {
-    std::lock_guard<std::mutex> lg{guard};
+    std::lock_guard lg{guard};
 
     if (visible && renderable)
     {
@@ -197,7 +195,7 @@ void mg::SoftwareCursor::hide()
 void mg::SoftwareCursor::move_to(geometry::Point position)
 {
     {
-        std::lock_guard<std::mutex> lg{guard};
+        std::lock_guard lg{guard};
 
         if (!renderable)
             return;
