@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "mir/default_server_configuration.h"
@@ -52,7 +50,6 @@
 #include "mir/shared_library.h"
 #include "mir/dispatch/action_queue.h"
 #include "mir/console_services.h"
-#include "mir/log.h"
 
 #include "mir_toolkit/cursors.h"
 
@@ -118,6 +115,12 @@ mir::DefaultServerConfiguration::the_input_targeter()
         });
 }
 
+std::shared_ptr<mir::ObserverRegistrar<mi::KeyboardObserver>>
+mir::DefaultServerConfiguration::the_keyboard_observer_registrar()
+{
+    return the_surface_input_dispatcher();
+}
+
 std::shared_ptr<mi::SurfaceInputDispatcher>
 mir::DefaultServerConfiguration::the_surface_input_dispatcher()
 {
