@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Robert Carr <racarr@canonical.com>
  */
 
 #include "application_session.h"
@@ -71,7 +69,7 @@ ms::ApplicationSession::ApplicationSession(
 
 ms::ApplicationSession::~ApplicationSession()
 {
-    std::unique_lock<std::mutex> lock(surfaces_and_streams_mutex);
+    std::unique_lock lock(surfaces_and_streams_mutex);
     for (auto const& surface : surfaces)
     {
         session_listener->destroying_surface(*this, surface);
@@ -81,8 +79,10 @@ ms::ApplicationSession::~ApplicationSession()
 
 auto ms::ApplicationSession::create_surface(
     std::shared_ptr<Session> const& session,
+    wayland::Weak<frontend::WlSurface> const& wayland_surface,
     shell::SurfaceSpecification const& the_params,
-    std::shared_ptr<ms::SurfaceObserver> const& observer) -> std::shared_ptr<Surface>
+    std::shared_ptr<ms::SurfaceObserver> const& observer,
+    Executor* observer_executor) -> std::shared_ptr<Surface>
 {
     if (session && session.get() != this)
         fatal_error("Incorrect session");
@@ -105,16 +105,22 @@ auto ms::ApplicationSession::create_surface(
         streams.push_back({std::dynamic_pointer_cast<mc::BufferStream>(stream.stream.lock()), stream.displacement, stream.size});
     }
 
-    auto surface = surface_factory->create_surface(session, streams, params);
+    auto surface = surface_factory->create_surface(session, wayland_surface, streams, params);
 
     auto const input_mode = params.input_mode.is_set() ? params.input_mode.value() : input::InputReceptionMode::normal;
     surface_stack->add_surface(surface, input_mode);
 
-    if (observer)
-        surface->add_observer(observer);
+    if (observer && observer_executor)
+    {
+        surface->register_interest(observer, *observer_executor);
+    }
+    else if (observer)
+    {
+        surface->register_interest(observer);
+    }
 
     {
-        std::unique_lock<std::mutex> lock(surfaces_and_streams_mutex);
+        std::unique_lock lock(surfaces_and_streams_mutex);
         surfaces.push_back(surface);
         default_content_map[surface] = buffer_stream;
     }
@@ -145,7 +151,7 @@ auto ms::ApplicationSession::create_surface(
 void ms::ApplicationSession::destroy_surface(std::shared_ptr<Surface> const& surface)
 {
     {
-        std::unique_lock<std::mutex> lock(surfaces_and_streams_mutex);
+        std::unique_lock lock(surfaces_and_streams_mutex);
 
         auto default_content_map_iter = default_content_map.find(surface);
         auto surface_iter = std::find(surfaces.begin(), surfaces.end(), surface);
@@ -163,7 +169,7 @@ void ms::ApplicationSession::destroy_surface(std::shared_ptr<Surface> const& sur
 
 std::shared_ptr<ms::Surface> ms::ApplicationSession::surface_after(std::shared_ptr<ms::Surface> const& before) const
 {
-    std::lock_guard<std::mutex> lock(surfaces_and_streams_mutex);
+    std::lock_guard lock(surfaces_and_streams_mutex);
     auto current = surfaces.begin();
     for (; current != surfaces.end(); ++current)
     {
@@ -209,7 +215,7 @@ std::shared_ptr<ms::Surface> ms::ApplicationSession::surface_after(std::shared_p
 
 std::shared_ptr<ms::Surface> ms::ApplicationSession::default_surface() const
 {
-    std::unique_lock<std::mutex> lock(surfaces_and_streams_mutex);
+    std::unique_lock lock(surfaces_and_streams_mutex);
 
     if (!surfaces.empty())
         return *surfaces.begin();
@@ -234,7 +240,7 @@ mir::Fd ms::ApplicationSession::socket_fd() const
 
 void ms::ApplicationSession::hide()
 {
-    std::unique_lock<std::mutex> lock(surfaces_and_streams_mutex);
+    std::unique_lock lock(surfaces_and_streams_mutex);
     for (auto& surface : surfaces)
     {
         surface->hide();
@@ -243,7 +249,7 @@ void ms::ApplicationSession::hide()
 
 void ms::ApplicationSession::show()
 {
-    std::unique_lock<std::mutex> lock(surfaces_and_streams_mutex);
+    std::unique_lock lock(surfaces_and_streams_mutex);
     for (auto& surface : surfaces)
     {
         surface->show();
@@ -287,14 +293,14 @@ auto ms::ApplicationSession::create_buffer_stream(mg::BufferProperties const& pr
     auto stream = buffer_stream_factory->create_buffer_stream(props);
     session_listener->buffer_stream_created(*this, stream);
 
-    std::unique_lock<std::mutex> lock(surfaces_and_streams_mutex);
+    std::unique_lock lock(surfaces_and_streams_mutex);
     streams.insert(stream);
     return stream;
 }
 
 void ms::ApplicationSession::destroy_buffer_stream(std::shared_ptr<frontend::BufferStream> const& stream)
 {
-    std::unique_lock<std::mutex> lock(surfaces_and_streams_mutex);
+    std::unique_lock lock(surfaces_and_streams_mutex);
     auto stream_it = streams.find(std::dynamic_pointer_cast<compositor::BufferStream>(stream));
     if (stream_it == streams.end())
         BOOST_THROW_EXCEPTION(std::runtime_error("cannot destroy stream: Invalid BufferStream"));
