@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #include "rendering_tracker.h"
@@ -33,7 +31,7 @@ ms::RenderingTracker::RenderingTracker(
 
 void ms::RenderingTracker::rendered_in(mc::CompositorID cid)
 {
-    std::lock_guard<std::mutex> lock{guard};
+    std::lock_guard lock{guard};
 
     ensure_is_active_compositor(cid);
 
@@ -44,7 +42,7 @@ void ms::RenderingTracker::rendered_in(mc::CompositorID cid)
 
 void ms::RenderingTracker::occluded_in(mc::CompositorID cid)
 {
-    std::lock_guard<std::mutex> lock{guard};
+    std::lock_guard lock{guard};
 
     ensure_is_active_compositor(cid);
 
@@ -56,7 +54,7 @@ void ms::RenderingTracker::occluded_in(mc::CompositorID cid)
 
 void ms::RenderingTracker::active_compositors(std::set<mc::CompositorID> const& cids)
 {
-    std::lock_guard<std::mutex> lock{guard};
+    std::lock_guard lock{guard};
 
     active_compositors_ = cids;
 
@@ -68,7 +66,7 @@ void ms::RenderingTracker::active_compositors(std::set<mc::CompositorID> const&
 
 bool ms::RenderingTracker::is_exposed_in(mc::CompositorID cid) const
 {
-    std::lock_guard<std::mutex> lock{guard};
+    std::lock_guard lock{guard};
 
     ensure_is_active_compositor(cid);
 
