@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored By: Robert Carr <robert.carr@canonical.com>
  */
 
 #include "mir/scene/session_container.h"
@@ -30,14 +28,14 @@ ms::SessionContainer::~SessionContainer() = default;
 
 void ms::SessionContainer::insert_session(std::shared_ptr<Session> const& session)
 {
-    std::unique_lock<std::mutex> lk(guard);
+    std::unique_lock lk(guard);
 
     apps.push_back(session);
 }
 
 void ms::SessionContainer::remove_session(std::shared_ptr<Session> const& session)
 {
-    std::unique_lock<std::mutex> lk(guard);
+    std::unique_lock lk(guard);
 
     auto it = std::find(apps.begin(), apps.end(), session);
     if (it != apps.end())
@@ -52,7 +50,7 @@ void ms::SessionContainer::remove_session(std::shared_ptr<Session> const& sessio
 
 void ms::SessionContainer::for_each(std::function<void(std::shared_ptr<Session> const&)> f) const
 {
-    std::unique_lock<std::mutex> lk(guard);
+    std::unique_lock lk(guard);
 
     for (auto const& ptr : apps)
     {
