@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Thomas Voss <thomas.voss@canonical.com>
  */
 
 #include "session_manager.h"
@@ -41,16 +39,12 @@ namespace ms = mir::scene;
 namespace mg = mir::graphics;
 namespace msh = mir::shell;
 
-struct ms::SessionManager::SessionObservers : mir::Executor, mir::ObserverMultiplexer<ms::SessionListener>
+struct ms::SessionManager::SessionObservers : mir::ObserverMultiplexer<ms::SessionListener>
 {
     SessionObservers()
-        : ObserverMultiplexer<ms::SessionListener>(static_cast<Executor&>(*this))
+        : ObserverMultiplexer(immediate_executor)
     {
     }
-    void spawn(std::function<void()>&& work) override
-    {
-        work();
-    }
 
     void starting(std::shared_ptr<Session> const& session) override
     {
