@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
 #include "surface_allocator.h"
@@ -39,6 +37,7 @@ ms::SurfaceAllocator::SurfaceAllocator(
 
 std::shared_ptr<ms::Surface> ms::SurfaceAllocator::create_surface(
     std::shared_ptr<Session> const& session,
+    wayland::Weak<frontend::WlSurface> const& wayland_surface,
     std::list<ms::StreamInfo> const& streams,
     shell::SurfaceSpecification const& params)
 {
@@ -51,6 +50,7 @@ std::shared_ptr<ms::Surface> ms::SurfaceAllocator::create_surface(
     auto const parent = params.parent.is_set() ? params.parent.value() : std::weak_ptr<scene::Surface>{};
     auto const surface = std::make_shared<BasicSurface>(
         session,
+        wayland_surface,
         name,
         rect,
         parent,
