@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored By: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "mir/server.h"
@@ -138,11 +136,11 @@ struct TemporaryCompositeEventFilter : public mi::CompositeEventFilter
     MACRO(the_seat_observer_registrar)
 
 #define MIR_SERVER_BUILDER(name)\
-    std::function<std::result_of<decltype(&mir::DefaultServerConfiguration::the_##name)(mir::DefaultServerConfiguration*)>::type()> name##_builder;
+    std::function<std::invoke_result_t<decltype(&mir::DefaultServerConfiguration::the_##name),mir::DefaultServerConfiguration*>()> name##_builder;
 
 #define MIR_SERVER_WRAPPER(name)\
-    std::function<std::result_of<decltype(&mir::DefaultServerConfiguration::the_##name)(mir::DefaultServerConfiguration*)>::type\
-        (std::result_of<decltype(&mir::DefaultServerConfiguration::the_##name)(mir::DefaultServerConfiguration*)>::type const&)> name##_wrapper;
+    std::function<std::invoke_result_t<decltype(&mir::DefaultServerConfiguration::the_##name),mir::DefaultServerConfiguration*>\
+        (std::invoke_result_t<decltype(&mir::DefaultServerConfiguration::the_##name),mir::DefaultServerConfiguration*> const&)> name##_wrapper;
 
 struct mir::Server::Self
 {
@@ -731,5 +729,19 @@ void mir::Server::add_configuration_option(
             self->set_add_configuration_options(option_adder);
         }
         break;
+
+    case OptionType::strings:
+        {
+            auto const option_adder = [=](options::DefaultConfiguration& config)
+                {
+                    existing(config);
+
+                    config.add_options()
+                    (option.c_str(), po::value<std::vector<std::string>>(), description.c_str());
+                };
+
+            self->set_add_configuration_options(option_adder);
+        }
+        break;
     }
 }
