@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored By: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "mir/shell/abstract_shell.h"
@@ -29,6 +27,7 @@
 #include "mir/scene/session.h"
 #include "mir/scene/surface.h"
 #include "mir/input/seat.h"
+#include "mir/wayland/wayland_base.h"
 #include "decoration/manager.h"
 
 #include <algorithm>
@@ -43,33 +42,6 @@ namespace geom = mir::geometry;
 
 namespace
 {
-
-struct UpdateConfinementOnSurfaceChanges : ms::NullSurfaceObserver
-{
-    UpdateConfinementOnSurfaceChanges(msh::AbstractShell* shell) :
-        shell(shell)
-    {
-    }
-
-    void content_resized_to(ms::Surface const*, geom::Size const& /*content_size*/) override
-    {
-        update_confinement_region();
-    }
-
-    void moved_to(ms::Surface const*, geom::Point const& /*top_left*/) override
-    {
-        update_confinement_region();
-    }
-
-private:
-    void update_confinement_region()
-    {
-        shell->update_focused_surface_confined_region();
-    }
-
-    msh::AbstractShell* shell;
-};
-
 auto get_non_popup_parent(std::shared_ptr<ms::Surface> surface) -> std::shared_ptr<ms::Surface>
 {
     while (surface)
@@ -98,6 +70,55 @@ auto get_ancestry(std::shared_ptr<ms::Surface> surface) -> std::vector<std::shar
 }
 }
 
+class msh::AbstractShell::SurfaceConfinementUpdater : public scene::NullSurfaceObserver
+{
+public:
+    SurfaceConfinementUpdater(input::Seat* const seat)
+        : seat{seat}
+    {
+    }
+
+    void set_focus_surface(std::shared_ptr<scene::Surface> const& surface)
+    {
+        std::lock_guard lock{mutex};
+        focus_surface = surface;
+    }
+
+private:
+    void content_resized_to(scene::Surface const*, geom::Size const& /*content_size*/) override
+    {
+        update_confinement_region();
+    }
+
+    void moved_to(scene::Surface const*, geom::Point const& /*top_left*/) override
+    {
+        update_confinement_region();
+    }
+
+    void update_confinement_region()
+    {
+        std::lock_guard lock{mutex};
+
+        if (auto const current_focus = focus_surface.lock())
+        {
+            switch (current_focus->confine_pointer_state())
+            {
+            case mir_pointer_confined_oneshot:
+            case mir_pointer_confined_persistent:
+                seat->set_confinement_regions({current_focus->input_bounds()});
+                break;
+
+            default:
+                break;
+            }
+        }
+    }
+
+    input::Seat* const seat; ///< Shared ownership is held by the shell that owns us
+    std::mutex mutex;
+    std::weak_ptr<scene::Surface> focus_surface;
+};
+
 msh::AbstractShell::AbstractShell(
     std::shared_ptr<InputTargeter> const& input_targeter,
     std::shared_ptr<msh::SurfaceStack> const& surface_stack,
@@ -114,7 +135,7 @@ msh::AbstractShell::AbstractShell(
     window_manager(wm_builder(this)),
     seat(seat),
     report(report),
-    focus_surface_observer(std::make_shared<UpdateConfinementOnSurfaceChanges>(this)),
+    surface_confinement_updater(std::make_shared<SurfaceConfinementUpdater>(seat.get())),
     decoration_manager(decoration_manager)
 {
 }
@@ -122,22 +143,9 @@ msh::AbstractShell::AbstractShell(
 msh::AbstractShell::~AbstractShell() noexcept
 {
     decoration_manager->undecorate_all();
-}
-
-void msh::AbstractShell::update_focused_surface_confined_region()
-{
-    if (auto const current_focus = focus_surface.lock())
+    if (auto const current_keyboard_focus = notified_keyboard_focus_surface.lock())
     {
-        switch (current_focus->confine_pointer_state())
-        {
-        case mir_pointer_confined_oneshot:
-        case mir_pointer_confined_persistent:
-            seat->set_confinement_regions({current_focus->input_bounds()});
-            break;
-
-        default:
-            break;
-        }
+        current_keyboard_focus->unregister_interest(*surface_confinement_updater);
     }
 }
 
@@ -180,13 +188,15 @@ void msh::AbstractShell::close_session(
 
 auto msh::AbstractShell::create_surface(
     std::shared_ptr<ms::Session> const& session,
+    wayland::Weak<frontend::WlSurface> const& wayland_surface,
     SurfaceSpecification const& spec,
-    std::shared_ptr<ms::SurfaceObserver> const& observer) -> std::shared_ptr<ms::Surface>
+    std::shared_ptr<ms::SurfaceObserver> const& observer,
+    Executor* observer_executor) -> std::shared_ptr<ms::Surface>
 {
     // Instead of a shared pointer, a local variable could be used and the lambda could capture a reference to it
     // This should be safe, but could be the source of nasty bugs and crashes if the wm did something unexpected
     auto const should_decorate = std::make_shared<bool>(false);
-    auto const build = [observer, should_decorate](
+    auto const build = [observer, observer_executor, should_decorate, wayland_surface](
             std::shared_ptr<ms::Session> const& session,
             msh::SurfaceSpecification const& placed_params)
         {
@@ -194,7 +204,7 @@ auto msh::AbstractShell::create_surface(
             {
                 *should_decorate = true;
             }
-            return session->create_surface(session, placed_params, observer);
+            return session->create_surface(session, wayland_surface, placed_params, observer, observer_executor);
         };
 
     auto const result = window_manager->add_surface(session, spec, build);
@@ -207,6 +217,11 @@ auto msh::AbstractShell::create_surface(
     return result;
 }
 
+void msh::AbstractShell::surface_ready(std::shared_ptr<ms::Surface> const& surface)
+{
+    window_manager->surface_ready(surface);
+}
+
 void msh::AbstractShell::modify_surface(std::shared_ptr<scene::Session> const& session, std::shared_ptr<scene::Surface> const& surface, SurfaceSpecification const& modifications)
 {
     auto wm_relevant_mods = modifications;
@@ -254,20 +269,6 @@ void msh::AbstractShell::modify_surface(std::shared_ptr<scene::Session> const& s
         }
     }
 
-    if (modifications.stream_cursor.is_set())
-    {
-        auto const& cursor = modifications.stream_cursor.value();
-        if (auto const stream = cursor.stream.lock())
-        {
-            auto hotspot = cursor.hotspot;
-            surface->set_cursor_stream(stream, hotspot);
-        }
-        else
-        {
-            surface->set_cursor_image({});
-        }
-    }
-
     if (modifications.confine_pointer.is_set())
     {
         auto const prev_state = surface->confine_pointer_state();
@@ -372,7 +373,7 @@ void msh::AbstractShell::request_resize(
 
 void msh::AbstractShell::focus_next_session()
 {
-    std::unique_lock<std::mutex> lock(focus_mutex);
+    std::unique_lock lock(focus_mutex);
     auto const focused_session = focus_session.lock();
     auto successor = session_coordinator->successor_of(focused_session);
     auto const sentinel = successor;
@@ -395,7 +396,7 @@ void msh::AbstractShell::focus_next_session()
 
 void msh::AbstractShell::focus_prev_session()
 {
-    std::unique_lock<std::mutex> lock(focus_mutex);
+    std::unique_lock lock(focus_mutex);
     auto const focused_session = focus_session.lock();
     auto predecessor = session_coordinator->predecessor_of(focused_session);
     auto const sentinel = predecessor;
@@ -418,13 +419,13 @@ void msh::AbstractShell::focus_prev_session()
 
 std::shared_ptr<ms::Session> msh::AbstractShell::focused_session() const
 {
-    std::unique_lock<std::mutex> lg(focus_mutex);
+    std::unique_lock lg(focus_mutex);
     return focus_session.lock();
 }
 
 std::shared_ptr<ms::Surface> msh::AbstractShell::focused_surface() const
 {
-    std::unique_lock<std::mutex> lock(focus_mutex);
+    std::unique_lock lock(focus_mutex);
     return focus_surface.lock();
 }
 
@@ -432,7 +433,7 @@ void msh::AbstractShell::set_focus_to(
     std::shared_ptr<ms::Session> const& focus_session,
     std::shared_ptr<ms::Surface> const& focus_surface)
 {
-    std::unique_lock<std::mutex> lock(focus_mutex);
+    std::unique_lock lock(focus_mutex);
 
     if (last_requested_focus_surface.lock() != focus_surface)
     {
@@ -509,7 +510,7 @@ void msh::AbstractShell::set_keyboard_focus_surface(
 
     if (current_keyboard_focus)
     {
-        current_keyboard_focus->remove_observer(focus_surface_observer);
+        current_keyboard_focus->unregister_interest(*surface_confinement_updater);
 
         switch (current_keyboard_focus->confine_pointer_state())
         {
@@ -528,8 +529,9 @@ void msh::AbstractShell::set_keyboard_focus_surface(
         update_confinement_for(new_keyboard_focus_surface);
 
         input_targeter->set_focus(new_keyboard_focus_surface);
-        new_keyboard_focus_surface->consume(seat->create_device_state().get());
-        new_keyboard_focus_surface->add_observer(focus_surface_observer);
+        new_keyboard_focus_surface->consume(seat->create_device_state());
+        surface_confinement_updater->set_focus_surface(new_keyboard_focus_surface);
+        new_keyboard_focus_surface->register_interest(surface_confinement_updater);
     }
     else
     {
@@ -619,7 +621,7 @@ bool msh::AbstractShell::handle(MirEvent const& event)
 
     case mir_input_event_type_keyboard_resync:
         return false;
-    
+
     case mir_input_event_types:
         abort();
         return false;
