@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "mir/terminate_with_current_exception.h"
@@ -32,20 +30,20 @@ std::mutex termination_exception_mutex;
 
 void mir::clear_termination_exception()
 {
-    std::lock_guard<std::mutex> lock{termination_exception_mutex};
+    std::lock_guard lock{termination_exception_mutex};
     termination_exception = nullptr;
 }
 
 void mir::check_for_termination_exception()
 {
-    std::lock_guard<std::mutex> lock{termination_exception_mutex};
+    std::lock_guard lock{termination_exception_mutex};
     if (termination_exception)
         std::rethrow_exception(termination_exception);
 }
 
 void mir::terminate_with_current_exception()
 {
-    std::lock_guard<std::mutex> lock{termination_exception_mutex};
+    std::lock_guard lock{termination_exception_mutex};
     if (!termination_exception)
     {
         termination_exception = std::current_exception();
