@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored By: William Wold <william.wold@canonical.com>
  */
 
 #include "mir/wayland/wayland_base.h"
@@ -153,3 +151,23 @@ void mw::internal_error_processing_request(wl_client* client, char const* method
         std::current_exception(),
         std::string() + "Exception processing " + method_name + " request");
 }
+
+void mw::tried_to_send_unsupported_event(wl_client* client, wl_resource* resource, char const* event, int required_version)
+{
+    wl_client_post_implementation_error(
+        client,
+        "Mir tried to send %s@%d.%s to object with version %d (requires version %d)",
+        wl_resource_get_class(resource),
+        wl_resource_get_id(resource),
+        event,
+        wl_resource_get_version(resource),
+        required_version);
+
+    log_critical(
+        "Tried to send %s@%d.%s to object with version %d (requires version %d)",
+        wl_resource_get_class(resource),
+        wl_resource_get_id(resource),
+        event,
+        wl_resource_get_version(resource),
+        required_version);
+}
