@@ -12,16 +12,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored By: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #ifndef MIR_TEST_DOUBLES_ADVANCEABLE_CLOCK_H_
 #define MIR_TEST_DOUBLES_ADVANCEABLE_CLOCK_H_
 
 #include "mir/time/steady_clock.h"
-#include <functional>
-#include <list>
 #include <mutex>
 
 namespace mir
@@ -34,9 +30,19 @@ namespace doubles
 class AdvanceableClock : public mir::time::Clock
 {
 public:
+    AdvanceableClock()
+        : current_time{mir::time::SteadyClock{}.now()}
+    {
+    }
+
+    AdvanceableClock(mir::time::Timestamp start_time)
+        : current_time{start_time}
+    {
+    }
+
     mir::time::Timestamp now() const override
     {
-        std::lock_guard<std::recursive_mutex> lock{mutex};
+        std::lock_guard lock{mutex};
         return current_time;
     }
 
@@ -47,19 +53,13 @@ public:
 
     void advance_by(mir::time::Duration step)
     {
-        std::lock_guard<std::recursive_mutex> lock{mutex};
+        std::lock_guard lock{mutex};
         current_time += step;
     }
 
 private:
-    mutable std::recursive_mutex mutex;
-    mir::time::Timestamp current_time{
-        []
-        {
-           mir::time::SteadyClock clock;
-           return clock.now();
-        }()
-        };
+    mutable std::mutex mutex;
+    mir::time::Timestamp current_time;
 };
 
 }
