@@ -12,14 +12,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #ifndef MIR_TEST_DOUBLES_MOCK_DRM_H_
 #define MIR_TEST_DOUBLES_MOCK_DRM_H_
 
 #include "mir_test_framework/open_wrapper.h"
+#include "mir/geometry/forward.h"
 
 #include <gmock/gmock.h>
 
@@ -29,11 +28,6 @@
 
 namespace mir
 {
-namespace geometry
-{
-struct Size;
-}
-
 namespace test
 {
 namespace doubles
