@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #ifndef MIR_TEST_DOUBLES_STUB_GL_DISPLAY_BUFFER_H_
@@ -34,6 +32,7 @@ class StubGLDisplayBuffer : public StubDisplayBuffer,
 {
 public:
     using StubDisplayBuffer::StubDisplayBuffer;
+    StubGLDisplayBuffer(StubGLDisplayBuffer const& s) : StubDisplayBuffer(s) {}
 
     void make_current() override {}
     void release_current() override {}
