@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Andreas Pokorny <andreas.pokorny@canonical.com>
  */
 
 #include "src/server/input/default_input_device_hub.h"
@@ -50,6 +48,7 @@
 #include "mir/input/touch_visualizer.h"
 #include "mir/input/input_device_info.h"
 #include "mir/geometry/rectangles.h"
+#include "mir/wayland/wayland_base.h"
 #include "mir/test/input_config_matchers.h"
 #include "mir/test/fd_utils.h"
 
@@ -184,6 +183,32 @@ struct SingleSeatInputDeviceHubSetup : ::testing::Test
     }
 };
 
+auto motion_event(mi::EventBuilder& builder, float x, float y) -> mir::EventUPtr
+{
+    return builder.pointer_event(
+        0ns,
+        mir_pointer_action_motion,
+        0,
+        std::nullopt,
+        {x, y},
+        mir_pointer_axis_source_none,
+        {},
+        {});
+}
+
+auto button_event(mi::EventBuilder& builder, MirPointerAction action, MirPointerButtons buttons) -> mir::EventUPtr
+{
+    return builder.pointer_event(
+        0ns,
+        action,
+        buttons,
+        std::nullopt,
+        {},
+        mir_pointer_axis_source_none,
+        {},
+        {});
+}
+
 }
 
 TEST_F(SingleSeatInputDeviceHubSetup, input_sink_posts_events_to_input_dispatcher)
@@ -263,12 +288,9 @@ TEST_F(SingleSeatInputDeviceHubSetup, tracks_pointer_position)
     capture_input_sink(device, sink, builder);
 
     hub.add_device(mt::fake_shared(device));
-    sink->handle_input(
-        builder->pointer_event(arbitrary_timestamp, mir_pointer_action_motion, 0, 0.0f, 0.0f, 10.0f, 10.0f));
-    sink->handle_input(
-        builder->pointer_event(arbitrary_timestamp, mir_pointer_action_motion, 0, 0.0f, 0.0f, 10.0f, 10.0f));
-    sink->handle_input(
-        builder->pointer_event(arbitrary_timestamp, mir_pointer_action_motion, 0, 0.0f, 0.0f, -10.0f, 10.0f));
+    sink->handle_input(motion_event(*builder, 10.0f, 10.0f));
+    sink->handle_input(motion_event(*builder, 10.0f, 10.0f));
+    sink->handle_input(motion_event(*builder, -10.0f, 10.0f));
 }
 
 TEST_F(SingleSeatInputDeviceHubSetup, confines_pointer_movement)
@@ -283,10 +305,8 @@ TEST_F(SingleSeatInputDeviceHubSetup, confines_pointer_movement)
     capture_input_sink(device, sink, builder);
     hub.add_device(mt::fake_shared(device));
 
-    sink->handle_input(
-        builder->pointer_event(arbitrary_timestamp, mir_pointer_action_motion, 0, 0.0f, 0.0f, 10.0f, 20.0f));
-    sink->handle_input(
-        builder->pointer_event(arbitrary_timestamp, mir_pointer_action_motion, 0, 0.0f, 0.0f, 10.0f, 10.0f));
+    sink->handle_input(motion_event(*builder, 10.0f, 20.0f));
+    sink->handle_input(motion_event(*builder, 10.0f, 10.0f));
 }
 
 TEST_F(SingleSeatInputDeviceHubSetup, forwards_pointer_updates_to_cursor_listener)
@@ -298,7 +318,7 @@ TEST_F(SingleSeatInputDeviceHubSetup, forwards_pointer_updates_to_cursor_listene
     capture_input_sink(device, sink, builder);
     hub.add_device(mt::fake_shared(device));
 
-    auto event = builder->pointer_event(0ns, mir_pointer_action_motion, 0, 0.0f, 0.0f, move_x, move_y);
+    auto event = motion_event(*builder, move_x, move_y);
 
     EXPECT_CALL(mock_cursor_listener, cursor_moved_to(move_x, move_y)).Times(1);
 
@@ -393,8 +413,7 @@ TEST_F(SingleSeatInputDeviceHubSetup, input_sink_unifies_modifier_state_accross_
     const MirInputEventModifiers r_alt_modifier = mir_input_event_modifier_alt_right | mir_input_event_modifier_alt;
     auto key =
         key_event_builder->key_event(arbitrary_timestamp, mir_keyboard_action_down, 0, KEY_RIGHTALT);
-    auto motion =
-        mouse_event_builder->pointer_event(arbitrary_timestamp, mir_pointer_action_motion, 0, 0, 0, 12, 40);
+    auto motion = motion_event(*mouse_event_builder, 12, 40);
 
     EXPECT_CALL(mock_dispatcher, dispatch(mt::KeyWithModifiers(r_alt_modifier)));
     EXPECT_CALL(mock_dispatcher, dispatch(mt::PointerEventWithModifiers(r_alt_modifier)));
@@ -443,10 +462,8 @@ TEST_F(SingleSeatInputDeviceHubSetup, input_sink_reduces_modifier_state_accross_
     auto ctrl_down = key_event_builder_2->key_event(arbitrary_timestamp, mir_keyboard_action_down, 0, KEY_LEFTCTRL);
     auto ctrl_up = key_event_builder_2->key_event(arbitrary_timestamp, mir_keyboard_action_up, 0, KEY_LEFTCTRL);
 
-    auto motion_1 =
-        mouse_event_builder->pointer_event(arbitrary_timestamp, mir_pointer_action_motion, 0, 0, 0, 12, 40);
-    auto motion_2 =
-        mouse_event_builder->pointer_event(arbitrary_timestamp, mir_pointer_action_motion, 0, 0, 0, 18, 10);
+    auto motion_1 = motion_event(*mouse_event_builder, 12, 40);
+    auto motion_2 = motion_event(*mouse_event_builder, 18, 10);
 
     EXPECT_CALL(mock_dispatcher, dispatch(mt::KeyWithModifiers(r_alt_modifier)));
     EXPECT_CALL(mock_dispatcher, dispatch(mt::KeyWithModifiers(l_ctrl_modifier)));
@@ -476,12 +493,9 @@ TEST_F(SingleSeatInputDeviceHubSetup, tracks_a_single_cursor_position_from_multi
     hub.add_device(mt::fake_shared(device));
     hub.add_device(mt::fake_shared(another_device));
 
-    auto motion_1 =
-        mouse_event_builder_1->pointer_event(arbitrary_timestamp, mir_pointer_action_motion, 0, 0, 0, 23, 20);
-    auto motion_2 =
-        mouse_event_builder_2->pointer_event(arbitrary_timestamp, mir_pointer_action_motion, 0, 0, 0, 18, -10);
-    auto motion_3 =
-        mouse_event_builder_2->pointer_event(arbitrary_timestamp, mir_pointer_action_motion, 0, 0, 0, 2, 10);
+    auto motion_1 = motion_event(*mouse_event_builder_1, 23, 20);
+    auto motion_2 = motion_event(*mouse_event_builder_2, 18, -10);
+    auto motion_3 = motion_event(*mouse_event_builder_2, 2, 10);
 
     EXPECT_CALL(mock_cursor_listener, cursor_moved_to(23, 20));
     EXPECT_CALL(mock_cursor_listener, cursor_moved_to(41, 10));
@@ -507,14 +521,10 @@ TEST_F(SingleSeatInputDeviceHubSetup, tracks_a_single_button_state_from_multiple
     hub.add_device(mt::fake_shared(device));
     hub.add_device(mt::fake_shared(another_device));
 
-    auto motion_1 =
-        mouse_event_builder_1->pointer_event(arbitrary_timestamp, mir_pointer_action_button_down, mir_pointer_button_primary, 0, 0, 0, 0);
-    auto motion_2 =
-        mouse_event_builder_2->pointer_event(arbitrary_timestamp, mir_pointer_action_button_down, mir_pointer_button_secondary, 0, 0, 0, 0);
-    auto motion_3 =
-        mouse_event_builder_1->pointer_event(arbitrary_timestamp, mir_pointer_action_button_up, no_buttons, 0, 0, 0, 0);
-    auto motion_4 =
-        mouse_event_builder_2->pointer_event(arbitrary_timestamp, mir_pointer_action_button_up, no_buttons, 0, 0, 0, 0);
+    auto motion_1 = button_event(*mouse_event_builder_1, mir_pointer_action_button_down, mir_pointer_button_primary);
+    auto motion_2 = button_event(*mouse_event_builder_2, mir_pointer_action_button_down, mir_pointer_button_secondary);
+    auto motion_3 = button_event(*mouse_event_builder_1, mir_pointer_action_button_up, no_buttons);
+    auto motion_4 = button_event(*mouse_event_builder_2, mir_pointer_action_button_up, no_buttons);
 
     InSequence seq;
     EXPECT_CALL(mock_dispatcher, dispatch(mt::ButtonsDown(x, y, mir_pointer_button_primary)));
