@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "mir/test/doubles/fake_display.h"
@@ -79,14 +77,14 @@ mtd::FakeDisplay::FakeDisplay(std::vector<geometry::Rectangle> const& output_rec
 
 void mtd::FakeDisplay::for_each_display_sync_group(std::function<void(mir::graphics::DisplaySyncGroup&)> const& f)
 {
-    std::lock_guard<decltype(configuration_mutex)> lock{configuration_mutex};
+    std::lock_guard lock{configuration_mutex};
     for (auto& group : groups)
         f(*group);
 }
 
 std::unique_ptr<mir::graphics::DisplayConfiguration> mtd::FakeDisplay::configuration() const
 {
-    std::lock_guard<decltype(configuration_mutex)> lock{configuration_mutex};
+    std::lock_guard lock{configuration_mutex};
     return std::unique_ptr<mir::graphics::DisplayConfiguration>(new StubDisplayConfig(*config));
 }
 
@@ -116,7 +114,7 @@ bool mtd::FakeDisplay::apply_if_configuration_preserves_display_buffers(graphics
 {
     auto new_configuration = std::make_shared<StubDisplayConfig>(new_config);
 
-    std::lock_guard<decltype(configuration_mutex)> lock{configuration_mutex};
+    std::lock_guard lock{configuration_mutex};
     if (compatible(*config, *new_configuration))
     {
         std::swap(config, new_configuration);
@@ -128,7 +126,7 @@ bool mtd::FakeDisplay::apply_if_configuration_preserves_display_buffers(graphics
 
 void mtd::FakeDisplay::configure(mir::graphics::DisplayConfiguration const& new_config)
 {
-    std::lock_guard<decltype(configuration_mutex)> lock{configuration_mutex};
+    std::lock_guard lock{configuration_mutex};
     decltype(config) new_configuration = std::make_shared<StubDisplayConfig>(new_config);
     decltype(groups) new_groups;
 
@@ -145,7 +143,7 @@ void mtd::FakeDisplay::emit_configuration_change_event(
     std::shared_ptr<mir::graphics::DisplayConfiguration> const& new_config)
 {
     handler_called = false;
-    std::lock_guard<decltype(configuration_mutex)> lock{configuration_mutex};
+    std::lock_guard lock{configuration_mutex};
     config = std::make_shared<StubDisplayConfig>(*new_config);
     if (eventfd_write(wakeup_trigger, 1) == -1)
     {
