@@ -12,12 +12,13 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Andreas Pokorny <andreas.pokorny@canonical.com>
  */
 
 #include "mir/test/doubles/mock_libinput.h"
 
+#include <boost/throw_exception.hpp>
+#include <stdexcept>
+
 namespace mtd = mir::test::doubles;
 using namespace testing;
 
@@ -62,10 +63,8 @@ mtd::MockLibInput::MockLibInput()
         .WillByDefault(Return(LIBINPUT_CONFIG_STATUS_SUCCESS));
     ON_CALL(*this, libinput_device_config_middle_emulation_set_enabled(_, _))
         .WillByDefault(Return(LIBINPUT_CONFIG_STATUS_SUCCESS));
-#if MIR_LIBINPUT_HAS_ACCEL_PROFILE
     ON_CALL(*this, libinput_device_config_accel_set_profile(_, _))
         .WillByDefault(Return(LIBINPUT_CONFIG_STATUS_SUCCESS));
-#endif
 }
 
 void mtd::MockLibInput::wake()
@@ -234,6 +233,28 @@ double libinput_event_pointer_get_axis_value_discrete(libinput_event_pointer* ev
     return global_libinput->libinput_event_pointer_get_axis_value_discrete(event, axis);
 }
 
+#ifdef MIR_LIBINPUT_HAS_VALUE120
+double libinput_event_pointer_get_scroll_value_v120(libinput_event_pointer* event, libinput_pointer_axis axis)
+{
+    return global_libinput->libinput_event_pointer_get_scroll_value_v120(event, axis);
+}
+
+double libinput_event_pointer_get_scroll_value(libinput_event_pointer* event, libinput_pointer_axis axis)
+{
+    return global_libinput->libinput_event_pointer_get_scroll_value(event, axis);
+}
+#else
+double libinput_event_pointer_get_scroll_value_v120(libinput_event_pointer* event, libinput_pointer_axis axis)
+{
+    return global_libinput->libinput_event_pointer_get_axis_value_discrete(event, axis) * 120;
+}
+#endif
+
+libinput_event* libinput_event_pointer_get_base_event(libinput_event_pointer* event)
+{
+    return global_libinput->libinput_event_pointer_get_base_event(event);
+}
+
 int libinput_event_pointer_has_axis(libinput_event_pointer* event, libinput_pointer_axis axis)
 {
     return global_libinput->libinput_event_pointer_has_axis(event, axis);
@@ -495,7 +516,6 @@ double libinput_device_config_accel_get_default_speed(libinput_device *device)
     return global_libinput->libinput_device_config_accel_get_default_speed(device);
 }
 
-#if MIR_LIBINPUT_HAS_ACCEL_PROFILE
 libinput_config_status libinput_device_config_accel_set_profile(libinput_device* dev, libinput_config_accel_profile profile)
 {
     return global_libinput->libinput_device_config_accel_set_profile(dev, profile);
@@ -505,7 +525,6 @@ libinput_config_accel_profile libinput_device_config_accel_get_profile(libinput_
 {
     return global_libinput->libinput_device_config_accel_get_profile(dev);
 }
-#endif
 
 int libinput_device_config_scroll_has_natural_scroll(libinput_device *device)
 {
@@ -804,6 +823,10 @@ libinput_event* mtd::MockLibInput::setup_axis_event(
     std::optional<double> horizontal, std::optional<double> vertical,
     double horizontal_discrete, double vertical_discrete)
 {
+#ifdef MIR_LIBINPUT_HAS_VALUE120
+    return setup_pointer_scroll_wheel_event(dev, event_time, horizontal, vertical,
+                                            120*horizontal_discrete, 120*vertical_discrete);
+#else
     auto event = get_next_fake_ptr<libinput_event*>();
     auto pointer_event = reinterpret_cast<libinput_event_pointer*>(event);
     push_back(event);
@@ -831,6 +854,72 @@ libinput_event* mtd::MockLibInput::setup_axis_event(
     ON_CALL(*this, libinput_event_pointer_get_axis_value(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
         .WillByDefault(Return(horizontal.value_or(0.0)));
     return event;
+#endif
+}
+
+libinput_event* mtd::MockLibInput::setup_pointer_scroll_wheel_event(
+    libinput_device* dev, uint64_t event_time,
+    std::optional<double> horizontal, std::optional<double> vertical,
+    double horizontal_value120, double vertical_value120)
+{
+    auto event = get_next_fake_ptr<libinput_event*>();
+    auto pointer_event = reinterpret_cast<libinput_event_pointer*>(event);
+    push_back(event);
+
+#ifdef MIR_LIBINPUT_HAS_VALUE120
+    ON_CALL(*this, libinput_event_get_type(event))
+        .WillByDefault(Return(LIBINPUT_EVENT_POINTER_SCROLL_WHEEL));
+    ON_CALL(*this, libinput_event_pointer_get_scroll_value(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
+        .WillByDefault(Return(vertical.value_or(0.0)));
+    ON_CALL(*this, libinput_event_pointer_get_scroll_value(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
+        .WillByDefault(Return(horizontal.value_or(0.0)));
+    ON_CALL(*this, libinput_event_pointer_get_scroll_value_v120(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
+        .WillByDefault(Return(vertical_value120));
+    ON_CALL(*this, libinput_event_pointer_get_scroll_value_v120(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
+        .WillByDefault(Return(horizontal_value120));
+    ON_CALL(*this, libinput_event_pointer_get_axis_value_discrete(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
+        .WillByDefault(
+            InvokeWithoutArgs(
+                []() -> double
+                {
+                    BOOST_THROW_EXCEPTION((
+                        std::logic_error{"axis_value_discrete only returns a non-zero value on EVENT_POINTER_AXIS events"}));
+                }));
+    ON_CALL(*this, libinput_event_pointer_get_axis_value_discrete(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
+        .WillByDefault(
+            InvokeWithoutArgs(
+                []() -> double
+                {
+                    BOOST_THROW_EXCEPTION((
+                        std::logic_error{"axis_value_discrete only returns a non-zero value on EVENT_POINTER_AXIS events"}));
+                }));
+#else
+    ON_CALL(*this, libinput_event_get_type(event))
+        .WillByDefault(Return(LIBINPUT_EVENT_POINTER_AXIS));
+    ON_CALL(*this, libinput_event_pointer_get_axis_value_discrete(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
+        .WillByDefault(Return(vertical_value120/120));
+    ON_CALL(*this, libinput_event_pointer_get_axis_value_discrete(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
+        .WillByDefault(Return(horizontal_value120/120));
+    ON_CALL(*this, libinput_event_pointer_get_axis_value(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
+        .WillByDefault(Return(vertical.value_or(0.0)));
+    ON_CALL(*this, libinput_event_pointer_get_axis_value(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
+        .WillByDefault(Return(horizontal.value_or(0.0)));
+#endif
+    ON_CALL(*this, libinput_event_get_pointer_event(event))
+        .WillByDefault(Return(pointer_event));
+    ON_CALL(*this, libinput_event_get_device(event))
+        .WillByDefault(Return(dev));
+    ON_CALL(*this, libinput_event_pointer_get_time_usec(pointer_event))
+        .WillByDefault(Return(event_time));
+    ON_CALL(*this, libinput_event_pointer_get_axis_source(pointer_event))
+        .WillByDefault(Return(LIBINPUT_POINTER_AXIS_SOURCE_WHEEL));
+    ON_CALL(*this, libinput_event_pointer_has_axis(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
+        .WillByDefault(Return(horizontal.operator bool()));
+    ON_CALL(*this, libinput_event_pointer_has_axis(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
+        .WillByDefault(Return(vertical.operator bool()));
+    ON_CALL(*this, libinput_event_pointer_get_base_event(pointer_event))
+        .WillByDefault(Return(event));
+    return event;
 }
 
 libinput_event* mtd::MockLibInput::setup_finger_axis_event(
@@ -842,9 +931,25 @@ libinput_event* mtd::MockLibInput::setup_finger_axis_event(
     auto event = get_next_fake_ptr<libinput_event*>();
     auto pointer_event = reinterpret_cast<libinput_event_pointer*>(event);
     push_back(event);
-
+#ifdef MIR_LIBINPUT_HAS_VALUE120
+    ON_CALL(*this, libinput_event_get_type(event))
+        .WillByDefault(Return(LIBINPUT_EVENT_POINTER_SCROLL_FINGER));
+    ON_CALL(*this, libinput_event_pointer_get_scroll_value(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
+        .WillByDefault(Return(vertical.value_or(0.0)));
+    ON_CALL(*this, libinput_event_pointer_get_scroll_value(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
+        .WillByDefault(Return(horizontal.value_or(0.0)));
+    ON_CALL(*this, libinput_event_pointer_get_scroll_value_v120(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
+        .WillByDefault(Return(0));
+    ON_CALL(*this, libinput_event_pointer_get_scroll_value_v120(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
+        .WillByDefault(Return(0));
+#else
     ON_CALL(*this, libinput_event_get_type(event))
         .WillByDefault(Return(LIBINPUT_EVENT_POINTER_AXIS));
+    ON_CALL(*this, libinput_event_pointer_get_axis_value(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
+        .WillByDefault(Return(vertical.value_or(0.0)));
+    ON_CALL(*this, libinput_event_pointer_get_axis_value(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
+        .WillByDefault(Return(horizontal.value_or(0.0)));
+#endif
     ON_CALL(*this, libinput_event_get_device(event))
         .WillByDefault(Return(dev));
     ON_CALL(*this, libinput_event_get_pointer_event(event))
@@ -857,10 +962,8 @@ libinput_event* mtd::MockLibInput::setup_finger_axis_event(
         .WillByDefault(Return(horizontal.operator bool()));
     ON_CALL(*this, libinput_event_pointer_has_axis(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
         .WillByDefault(Return(vertical.operator bool()));
-    ON_CALL(*this, libinput_event_pointer_get_axis_value(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL))
-        .WillByDefault(Return(vertical.value_or(0.0)));
-    ON_CALL(*this, libinput_event_pointer_get_axis_value(pointer_event, LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL))
-        .WillByDefault(Return(horizontal.value_or(0.0)));
+    ON_CALL(*this, libinput_event_pointer_get_base_event(pointer_event))
+        .WillByDefault(Return(event));
     return event;
 }
 
