@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Andreas Pokorny <andreas.pokorny@canonical.com>
  */
 
 #include "mir/graphics/platform.h"
@@ -53,8 +51,13 @@ public:
         auto create_stub_render_platform = stub_platform_library.load_function<mg::CreateRenderPlatform>("create_rendering_platform");
 
         mtd::NullEmergencyCleanup null_cleanup;
-        stub_render_platform = create_stub_render_platform(mo::ProgramOption{}, null_cleanup);
-        stub_display_platform = create_stub_display_platform(nullptr, nullptr, nullptr, nullptr);
+        mg::SupportedDevice device = {
+            nullptr,
+            mg::PlatformPriority::unsupported,
+            nullptr
+        };
+        stub_render_platform = create_stub_render_platform(device, {}, mo::ProgramOption{}, null_cleanup);
+        stub_display_platform = create_stub_display_platform(device, nullptr, nullptr, nullptr, nullptr);
     }
 
     mir::UniqueModulePtr<mir::graphics::GraphicBufferAllocator>
@@ -110,20 +113,36 @@ private:
 
 }
 
-mg::PlatformPriority probe_display_platform(
+auto probe_display_platform(
     std::shared_ptr<mir::ConsoleServices> const&,
-    mo::ProgramOption const& /*options*/)
+    std::shared_ptr<mir::udev::Context> const&,
+    mir::options::ProgramOption const&) -> std::vector<mir::graphics::SupportedDevice>
 {
     mir::assert_entry_point_signature<mg::PlatformProbe>(&probe_display_platform);
-    return mg::PlatformPriority::unsupported;
+    std::vector<mg::SupportedDevice> result;
+    result.emplace_back(
+        mg::SupportedDevice {
+            nullptr,
+            mg::PlatformPriority::unsupported,
+            nullptr
+         });
+    return result;
 }
 
-mg::PlatformPriority probe_rendering_platform(
+auto probe_rendering_platform(
     std::shared_ptr<mir::ConsoleServices> const&,
-    mo::ProgramOption const& /*options*/)
+    std::shared_ptr<mir::udev::Context> const&,
+    mir::options::ProgramOption const&) -> std::vector<mir::graphics::SupportedDevice>
 {
     mir::assert_entry_point_signature<mg::PlatformProbe>(&probe_rendering_platform);
-    return mg::PlatformPriority::unsupported;
+    std::vector<mg::SupportedDevice> result;
+    result.emplace_back(
+        mg::SupportedDevice {
+            nullptr,
+            mg::PlatformPriority::unsupported,
+            nullptr
+         });
+    return result;
 }
 
 mir::ModuleProperties const description {
@@ -146,6 +165,8 @@ void add_graphics_platform_options(boost::program_options::options_description&)
 }
 
 mir::UniqueModulePtr<mg::RenderingPlatform> create_rendering_platform(
+    mg::SupportedDevice const&,
+    std::vector<std::shared_ptr<mg::DisplayPlatform>> const&,
     mo::Option const&,
     mir::EmergencyCleanupRegistry&)
 {
@@ -154,6 +175,7 @@ mir::UniqueModulePtr<mg::RenderingPlatform> create_rendering_platform(
 }
 
 mir::UniqueModulePtr<mg::DisplayPlatform> create_display_platform(
+    mg::SupportedDevice const&,
     std::shared_ptr<mo::Option> const&,
     std::shared_ptr<mir::EmergencyCleanupRegistry> const&,
     std::shared_ptr<mir::ConsoleServices> const&,
