@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "mir_test_framework/server_runner.h"
@@ -36,6 +34,8 @@ namespace mtf = mir_test_framework;
 mtf::ServerRunner::ServerRunner()
 {
     unsetenv("WAYLAND_DISPLAY");    // We don't want to conflict with any existing server
+    if (getenv("XDG_RUNTIME_DIR") == nullptr)
+        env.emplace_back("XDG_RUNTIME_DIR", "/tmp");
 }
 
 void mtf::ServerRunner::start_server()
@@ -46,7 +46,7 @@ void mtf::ServerRunner::start_server()
         BOOST_THROW_EXCEPTION(std::runtime_error{"Failed to start server thread"});
     }
 
-    std::lock_guard<std::mutex> main_loop_lock{main_loop_mutex};
+    std::lock_guard main_loop_lock{main_loop_mutex};
     std::swap(ml, main_loop);
 }
 
@@ -56,7 +56,7 @@ void mtf::ServerRunner::stop_server()
         decltype(main_loop) ml;
 
         {
-            std::lock_guard<std::mutex> main_loop_lock{main_loop_mutex};
+            std::lock_guard main_loop_lock{main_loop_mutex};
             std::swap(ml, main_loop);
         }
 
@@ -97,8 +97,10 @@ std::shared_ptr<mir::MainLoop> mtf::ServerRunner::start_mir_server()
                     this,
                     [&]
                     {
-                        std::lock_guard<std::mutex> lock(mutex);
-                        started = true;
+                        {
+                            std::lock_guard lock(mutex);
+                            started = true;
+                        }
                         started_cv.notify_one();
                     });
             });
@@ -111,7 +113,7 @@ std::shared_ptr<mir::MainLoop> mtf::ServerRunner::start_mir_server()
         }
     });
 
-    std::unique_lock<std::mutex> lock(mutex);
+    std::unique_lock lock(mutex);
     started_cv.wait_for(lock, std::chrono::seconds{30}, [&]{ return started; });
 
     return ml;
