@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored By: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "mir/test/doubles/stub_session.h"
@@ -82,8 +80,10 @@ void mtd::StubSession::resume_prompt_session()
 
 auto mtd::StubSession::create_surface(
     std::shared_ptr<Session> const& /*session*/,
+    wayland::Weak<frontend::WlSurface> const& /*wayland_surface*/,
     mir::shell::SurfaceSpecification const& /*params*/,
-    std::shared_ptr<scene::SurfaceObserver> const& /*observer*/) -> std::shared_ptr<ms::Surface>
+    std::shared_ptr<scene::SurfaceObserver> const& /*observer*/,
+    Executor* /*observer_executor*/) -> std::shared_ptr<ms::Surface>
 {
     return nullptr;
 }
