@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include <miral/test_server.h>
@@ -30,11 +28,6 @@ void miral::TestServer::SetUp()
 
 void miral::TestServer::TearDown()
 {
-    // There's a race between closing a client and closing the server.
-    // AutoSendBuffer is trying to send *after* SessionMediator is destroyed.
-    // This sleep() is not a good fix, but a good fix would be deep in legacy code.
-    std::this_thread::sleep_for(100ms);
-
     stop_server();
     testing::Test::TearDown();
 }
