@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan@octopull.co.uk>
  */
 
 #include "test_window_manager_tools.h"
@@ -27,6 +25,7 @@
 #include <mir/shell/focus_controller.h>
 #include <mir/shell/persistent_surface_store.h>
 #include "mir/graphics/display_configuration_observer.h"
+#include <mir/wayland/wayland_base.h>
 
 #include <mir/test/doubles/stub_session.h>
 #include <mir/test/doubles/stub_surface.h>
@@ -152,8 +151,10 @@ struct StubStubSession : mir::test::doubles::StubSession
 {
     auto create_surface(
         std::shared_ptr<mir::scene::Session> const& /*session*/,
+        mir::wayland::Weak<mir::frontend::WlSurface> const& /*wayland_surface*/,
         mir::shell::SurfaceSpecification const& params,
-        std::shared_ptr<mir::scene::SurfaceObserver> const& /*observer*/) -> std::shared_ptr<mir::scene::Surface> override
+        std::shared_ptr<mir::scene::SurfaceObserver> const& /*observer*/,
+        mir::Executor*) -> std::shared_ptr<mir::scene::Surface> override
     {
         auto id = mir::frontend::SurfaceId{next_surface_id.fetch_add(1)};
         auto surface = std::make_shared<StubSurface>(
@@ -246,11 +247,6 @@ struct FakeDisplayConfiguration : public mir::graphics::DisplayConfiguration
     {
     }
 
-    void for_each_card(std::function<void(mir::graphics::DisplayConfigurationCard const&)> /*f*/) const override
-    {
-        throw std::runtime_error("FakeDisplayConfiguration::for_each_card is not implemented");
-    }
-
     void for_each_output(std::function<void(mir::graphics::DisplayConfigurationOutput const&)> f) const override
     {
         for (auto const& output : outputs)
@@ -316,7 +312,7 @@ auto mt::TestWindowManagerTools::create_surface(
 {
     // This type is Mir-internal, I hope we don't need to create it here
     std::shared_ptr<mir::scene::SurfaceObserver> const observer;
-    return session->create_surface(nullptr, params, observer);
+    return session->create_surface(nullptr, {}, params, observer, nullptr);
 }
 
 auto mt::TestWindowManagerTools::create_fake_display_configuration(std::vector<miral::Rectangle> const& outputs)
