@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014-2020 Canonical Ltd.
+ * Copyright © 2014-2022 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -47,6 +47,7 @@ struct AbstractGLMark2Test : testing::Test, mtf::AsyncServerRunner {
 
     void TearDown() override {
         stop_server();
+        record_properties(output_filename, "server");
     }
 
     virtual char const *command() =0;
@@ -69,12 +70,16 @@ struct AbstractGLMark2Test : testing::Test, mtf::AsyncServerRunner {
         std::string line;
         std::ofstream glmark2_output;
         int score = -1;
+        std::string renderer{"unknown"};
         glmark2_output.open(output_filename);
         while (p.get_line(line)) {
             int match;
             if (sscanf(line.c_str(), " glmark2 Score: %d", &match) == 1) {
                 score = match;
             }
+            if (const auto n = line.find("GL_RENDERER:   "); n != std::string::npos) {
+                renderer = line.substr(n + 15, line.size());
+            }
 
             glmark2_output << line << std::endl;
         }
@@ -82,8 +87,38 @@ struct AbstractGLMark2Test : testing::Test, mtf::AsyncServerRunner {
         // Use GTest's structured annotation support to expose the score
         // to the test runner.
         RecordProperty("score", score);
+        RecordProperty("client_renderer", renderer);
         return score;
     }
+
+    void record_properties(std::string const& log_filename, std::string const& prefix)
+    {
+        std::ifstream logs(log_filename);
+        if (!logs)
+        {
+            std::cerr << "Failed to open log file for analysis: " << log_filename << std::endl;
+            return;
+        }
+
+        std::string line;
+        while (logs.good() && getline(logs, line))
+        {
+            if (const auto n = line.find("GL renderer:"); n != std::string::npos)
+            {
+                std::ostringstream property;
+                property << prefix << "_renderer";
+                RecordProperty(property.str(), line.substr(n+13, line.size()));
+                continue;
+            }
+            if (const auto n = line.find("Current mode"); n != std::string::npos)
+            {
+                std::ostringstream property;
+                property << prefix << "_mode";
+                RecordProperty(property.str(), line.substr(n+13, line.size()));
+                break;
+            }
+        }
+    }
 };
 
 struct GLMark2Xwayland : AbstractGLMark2Test
@@ -122,10 +157,18 @@ struct GLMark2Wayland : AbstractGLMark2Test
 struct HostedGLMark2Wayland : GLMark2Wayland
 {
     static char const* const host_socket;
+    char host_output_filename[256];
     pid_t pid = 0;
 
     HostedGLMark2Wayland()
     {
+        const ::testing::TestInfo *const test_info =
+            ::testing::UnitTest::GetInstance()->current_test_info();
+
+        snprintf(host_output_filename, sizeof(host_output_filename) - 1,
+                 "/tmp/%s_%s_host.log",
+                 test_info->test_case_name(), test_info->name());
+
         if ((pid = fork()))
         {
             EXPECT_THAT(pid, Gt(0));
@@ -138,17 +181,9 @@ struct HostedGLMark2Wayland : GLMark2Wayland
             std::string const server_path{mtf::executable_path() + "/mir_demo_server"};
             args[0] = server_path.c_str();
 
-            const ::testing::TestInfo *const test_info =
-                ::testing::UnitTest::GetInstance()->current_test_info();
-
-            char output_filename[256];
-            snprintf(output_filename, sizeof(output_filename) - 1,
-                     "/tmp/%s_%s_host.log",
-                     test_info->test_case_name(), test_info->name());
-
-            printf("Saving host output to: %s\n", output_filename);
-            if (freopen(output_filename, "a", stdout)) { /* (void)freopen(...); doesn't work */ };
-            if (freopen(output_filename, "a", stderr)) { /* (void)freopen(...); doesn't work */ };
+            printf("Saving host output to: %s\n", host_output_filename);
+            if (freopen(host_output_filename, "a", stdout)) { /* (void)freopen(...); doesn't work */ };
+            if (freopen(host_output_filename, "a", stderr)) { /* (void)freopen(...); doesn't work */ };
 
             execv(server_path.c_str(), const_cast<char* const*>(args.data()));
         }
@@ -181,6 +216,7 @@ struct HostedGLMark2Wayland : GLMark2Wayland
         if (pid > 0)
         {
             kill(pid, SIGTERM);
+            record_properties(host_output_filename, "host");
         }
     }
 
