@@ -12,12 +12,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #include "mir/geometry/displacement.h"
-#include "mir/geometry/displacement_f.h"
+#include "mir/geometry/point.h"
 
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
