@@ -12,12 +12,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #include "src/platforms/common/server/shm_buffer.h"
-#include "src/platforms/common/server/egl_context_executor.h"
+#include "mir/graphics/egl_context_executor.h"
 #include "mir/renderer/gl/context.h"
 
 #include "mir/test/doubles/mock_gl.h"
