@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Andreas Pokorny <andreas.pokorny@canonical.com>
  */
 
 #include "src/platforms/evdev/libinput_device.h"
@@ -53,6 +51,22 @@ namespace mev = mir::events;
 namespace mtd = mt::doubles;
 namespace geom = mir::geometry;
 
+namespace mir
+{
+namespace events
+{
+template<typename Tag>
+std::ostream& operator<<(std::ostream& out, mev::ScrollAxisV1<Tag> const& axis)
+{
+    return out
+        << "(precise: " << axis.precise
+        << ", discrete: " << axis.discrete
+        << ", value120: " << axis.value120
+        << ", stop: " << axis.stop << ")";
+}
+}
+}
+
 namespace
 {
 using namespace ::testing;
@@ -66,8 +80,7 @@ struct MockEventBuilder : mi::EventBuilder
     mi::DefaultEventBuilder builder{
         MirInputDeviceId{3},
         mt::fake_shared(clock),
-        cookie_authority,
-        mt::fake_shared(seat)};
+        cookie_authority};
     MockEventBuilder()
     {
         ON_CALL(*this, key_event(_,_,_,_)).WillByDefault(
@@ -82,46 +95,21 @@ struct MockEventBuilder : mi::EventBuilder
                 return builder.touch_event(time, contacts);
             });
 
-        ON_CALL(*this, pointer_event(_, _, _, _, _, _, _)).WillByDefault(
-            [this](std::optional<Timestamp> time, MirPointerAction action, MirPointerButtons buttons,
-                   float hscroll, float vscroll, float relative_x, float relative_y)
+        ON_CALL(*this, pointer_event(_, _, _, _, _, _, _, _)).WillByDefault(
+            [this](
+                std::optional<Timestamp> timestamp,
+                MirPointerAction action,
+                MirPointerButtons buttons,
+                std::optional<mir::geometry::PointF> position,
+                mir::geometry::DisplacementF motion,
+                MirPointerAxisSource axis_source,
+                mir::events::ScrollAxisH h_scroll,
+                mir::events::ScrollAxisV v_scroll)
             {
-                return builder.pointer_event(time, action, buttons, hscroll, vscroll, relative_x, relative_y);
-            });
-
-        ON_CALL(*this, pointer_event(_, _, _, _, _, _, _, _, _)).WillByDefault(
-            [this](std::optional<Timestamp> time, MirPointerAction action, MirPointerButtons buttons,
-                   float x, float y, float hscroll, float vscroll, float relative_x, float relative_y)
-            {
-                return builder.pointer_event(time, action, buttons, x, y, hscroll, vscroll, relative_x, relative_y);
-            });
-
-        ON_CALL(*this, pointer_axis_event(_, _, _, _, _, _, _, _, _, _)).WillByDefault(
-            [this](MirPointerAxisSource axis_source, std::optional<Timestamp> time, MirPointerAction action,
-                   MirPointerButtons buttons, float x, float y, float hscroll, float vscroll, float relative_x, float relative_y)
-            {
-                return builder.pointer_axis_event(
-                    axis_source, time, action, buttons, x, y, hscroll, vscroll, relative_x, relative_y);
-            });
-
-        ON_CALL(*this, pointer_axis_with_stop_event(_, _, _, _, _, _, _, _, _, _, _, _)).WillByDefault(
-            [this](MirPointerAxisSource axis_source, std::optional<Timestamp> time, MirPointerAction action,
-                   MirPointerButtons buttons, float x, float y, float hscroll, float vscroll,
-                   bool hscroll_stop, bool vscroll_stop, float relative_x, float relative_y)
-            {
-                return builder.pointer_axis_with_stop_event(
-                    axis_source, time, action, buttons, x, y, hscroll, vscroll, vscroll_stop, hscroll_stop,
-                    relative_x, relative_y);
-            });
-
-        ON_CALL(*this, pointer_axis_discrete_scroll_event(_, _, _, _, _, _, _, _)).WillByDefault(
-            [this](MirPointerAxisSource axis_source, std::optional<Timestamp> timestamp, MirPointerAction action,
-                   MirPointerButtons buttons_pressed, float hscroll_value, float vscroll_value,
-                   float hscroll_discrete, float vscroll_discrete)
-            {
-                return builder.pointer_axis_discrete_scroll_event(
-                    axis_source, timestamp, action, buttons_pressed, hscroll_value, vscroll_value,
-                    hscroll_discrete, vscroll_discrete);
+                return builder.pointer_event(
+                    timestamp, action, buttons,
+                    position, motion,
+                    axis_source, h_scroll, v_scroll);
             });
     }
     using EventBuilder::Timestamp;
@@ -129,22 +117,66 @@ struct MockEventBuilder : mi::EventBuilder
     MOCK_METHOD(mir::EventUPtr, key_event, (std::optional<Timestamp>, MirKeyboardAction, xkb_keysym_t, int));
     MOCK_METHOD(mir::EventUPtr, touch_event, (std::optional<Timestamp>, std::vector<mir::events::ContactState> const&));
     MOCK_METHOD(mir::EventUPtr, pointer_event,
-                (std::optional<Timestamp>, MirPointerAction, MirPointerButtons, float, float, float, float));
-    MOCK_METHOD(mir::EventUPtr, pointer_event,
-                (std::optional<Timestamp>, MirPointerAction, MirPointerButtons, float, float, float, float, float, float));
-    MOCK_METHOD(mir::EventUPtr, pointer_axis_event,
-                (MirPointerAxisSource axis_source, std::optional<Timestamp> timestamp, MirPointerAction action,
-                 MirPointerButtons buttons_pressed, float x_position, float y_position,
-                 float hscroll_value, float vscroll_value, float relative_x_value, float relative_y_value));
-    MOCK_METHOD(mir::EventUPtr, pointer_axis_with_stop_event,
-                (MirPointerAxisSource axis_source, std::optional<Timestamp> timestamp, MirPointerAction action,
-                 MirPointerButtons buttons_pressed, float x_position, float y_position,
-                 float hscroll_value, float vscroll_value, bool hscroll_stop, bool vscroll_stop,
-                 float relative_x_value, float relative_y_value));
-    MOCK_METHOD(mir::EventUPtr, pointer_axis_discrete_scroll_event,
-                (MirPointerAxisSource axis_source, std::optional<Timestamp> timestamp, MirPointerAction action,
-                 MirPointerButtons buttons_pressed, float hscroll_value, float vscroll_value, float hscroll_discrete,
-                 float vscroll_discrete));
+                (std::optional<Timestamp>, MirPointerAction, MirPointerButtons, std::optional<mir::geometry::PointF>,
+                 mir::geometry::DisplacementF, MirPointerAxisSource, mir::events::ScrollAxisH,
+                 mir::events::ScrollAxisV), (override));
+
+    mir::EventUPtr pointer_event(
+        std::optional<Timestamp>,
+        MirPointerAction,
+        MirPointerButtons,
+        float, float,
+        float, float) override
+    {
+        BOOST_THROW_EXCEPTION(std::logic_error("deprecated event builder method called"));
+    }
+
+    mir::EventUPtr pointer_event(
+        std::optional<Timestamp>,
+        MirPointerAction,
+        MirPointerButtons,
+        float, float,
+        float, float,
+        float, float) override
+    {
+        BOOST_THROW_EXCEPTION(std::logic_error("deprecated event builder method called"));
+    }
+
+    mir::EventUPtr pointer_axis_event(
+        MirPointerAxisSource,
+        std::optional<Timestamp>,
+        MirPointerAction,
+        MirPointerButtons,
+        float, float,
+        float, float,
+        float, float) override
+    {
+        BOOST_THROW_EXCEPTION(std::logic_error("deprecated event builder method called"));
+    }
+
+    mir::EventUPtr pointer_axis_with_stop_event(
+        MirPointerAxisSource,
+        std::optional<Timestamp>,
+        MirPointerAction,
+        MirPointerButtons,
+        float, float,
+        float, float,
+        bool, bool,
+        float, float) override
+    {
+        BOOST_THROW_EXCEPTION(std::logic_error("deprecated event builder method called"));
+    }
+
+    mir::EventUPtr pointer_axis_discrete_scroll_event(
+        MirPointerAxisSource,
+        std::optional<Timestamp>,
+        MirPointerAction,
+        MirPointerButtons,
+        float, float,
+        float, float) override
+    {
+        BOOST_THROW_EXCEPTION(std::logic_error("deprecated event builder method called"));
+    }
 };
 
 struct LibInputDevice : public ::testing::Test
@@ -203,14 +235,10 @@ struct LibInputDevice : public ::testing::Test
             .WillByDefault(Return(accel_speed));
         ON_CALL(env.mock_libinput, libinput_device_config_left_handed_get(dev))
             .WillByDefault(Return(handedness == mir_pointer_handedness_left));
-#if MIR_LIBINPUT_HAS_ACCEL_PROFILE
         ON_CALL(env.mock_libinput, libinput_device_config_accel_get_profile(dev))
             .WillByDefault(Return((profile == mir_pointer_acceleration_none) ?
                                       LIBINPUT_CONFIG_ACCEL_PROFILE_FLAT :
                                       LIBINPUT_CONFIG_ACCEL_PROFILE_ADAPTIVE));
-#else
-        (void)profile;
-#endif
     }
 
     void setup_touchpad_configuration(libinput_device* dev,
@@ -264,7 +292,10 @@ struct LibInputDevice : public ::testing::Test
     void process_events(mie::LibInputDevice& device)
     {
         for (auto event : env.mock_libinput.events)
+        {
             device.process_event(event);
+        }
+        env.mock_libinput.events.clear();
     }
 };
 
@@ -540,19 +571,332 @@ TEST_F(LibInputDeviceOnMouse, process_event_handles_scroll)
 {
     InSequence seq;
     // expect two scroll events..
-    EXPECT_CALL(mock_builder, pointer_axis_discrete_scroll_event(
-        mir_pointer_axis_source_wheel, {time_stamp_1}, mir_pointer_action_motion, 0, 0.0f, -20.0f, 0.0f, 2.0f));
+
+    mev::ScrollAxisV const scroll_axis_v_1{geom::DeltaYF{-20}, geom::DeltaY{2}, geom::DeltaY{240}, false};
+    mev::ScrollAxisH const scroll_axis_h_2{geom::DeltaXF{5}, geom::DeltaX{1}, geom::DeltaX{120}, false};
+
+    EXPECT_CALL(mock_builder, pointer_event(
+        {time_stamp_1}, mir_pointer_action_motion, 0,
+        Eq(std::nullopt), geom::DisplacementF{},
+        mir_pointer_axis_source_wheel,
+        mev::ScrollAxisH{},
+        scroll_axis_v_1));
     EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_vscroll, -20.0f)));
-    EXPECT_CALL(mock_builder, pointer_axis_discrete_scroll_event(
-        mir_pointer_axis_source_wheel, {time_stamp_2}, mir_pointer_action_motion, 0, 5.0f, 0.0f, 1.0f, 0.0f));
+    EXPECT_CALL(mock_builder, pointer_event(
+        {time_stamp_2}, mir_pointer_action_motion, 0,
+        Eq(std::nullopt), geom::DisplacementF{},
+        mir_pointer_axis_source_wheel,
+        scroll_axis_h_2,
+        mev::ScrollAxisV{{}, {}, false}));
     EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_hscroll, 5.0f)));
 
     mouse.start(&mock_sink, &mock_builder);
-    env.mock_libinput.setup_axis_event(fake_device, event_time_1, {}, -20.0, 0, 2);
-    env.mock_libinput.setup_axis_event(fake_device, event_time_2, 5.0, {}, 1, 0);
+    env.mock_libinput.setup_pointer_scroll_wheel_event(fake_device, event_time_1, {}, -20.0, 0, 240);
+    env.mock_libinput.setup_pointer_scroll_wheel_event(fake_device, event_time_2, 5.0, {}, 120, 0);
     process_events(mouse);
 }
 
+TEST_F(LibInputDeviceOnMouse, hi_res_scroll_is_picked_up)
+{
+#ifdef MIR_LIBINPUT_HAS_VALUE120
+    auto const expected_v120 = 165;
+    auto const expected_discrete = 1;
+#else
+    auto const expected_v120 = 120;
+    auto const expected_discrete = 1;
+#endif
+
+    EXPECT_CALL(mock_builder, pointer_event(
+        {time_stamp_1}, mir_pointer_action_motion, 0,
+        Eq(std::nullopt), geom::DisplacementF{},
+        mir_pointer_axis_source_wheel,
+        mev::ScrollAxisH{},
+        mev::ScrollAxisV{geom::DeltaYF{1}, geom::DeltaY{expected_discrete}, geom::DeltaY{expected_v120}, false}));
+
+    mouse.start(&mock_sink, &mock_builder);
+    env.mock_libinput.setup_pointer_scroll_wheel_event(fake_device, event_time_1, {}, 1.0f, 0.0f, 165);
+    process_events(mouse);
+}
+
+TEST_F(LibInputDeviceOnMouse, hi_res_scroll_does_not_combine_with_precise)
+{
+    EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_vscroll, 1.0f)));
+
+    mouse.start(&mock_sink, &mock_builder);
+    env.mock_libinput.setup_pointer_scroll_wheel_event(fake_device, event_time_1, {}, 1.0f, 0.0f, 250.0f);
+    process_events(mouse);
+}
+
+TEST_F(LibInputDeviceOnMouse, hi_res_scroll_scroll_can_be_multiple_discrete_steps)
+{
+    mouse.start(&mock_sink, &mock_builder);
+
+    EXPECT_CALL(mock_builder, pointer_event(
+        _, _, _, _, _, _, _,
+        mev::ScrollAxisV{geom::DeltaYF{1}, geom::DeltaY{2}, geom::DeltaY{240}, false}));
+    env.mock_libinput.setup_pointer_scroll_wheel_event(fake_device, event_time_1, {}, 1.0f, 0.0f, 240.0f);
+    process_events(mouse);
+}
+
+TEST_F(LibInputDeviceOnMouse, hi_res_scroll_scroll_can_be_negative)
+{
+    mouse.start(&mock_sink, &mock_builder);
+
+    EXPECT_CALL(mock_builder, pointer_event(
+        _, _, _, _, _, _, _,
+        mev::ScrollAxisV{geom::DeltaYF{-1}, geom::DeltaY{-2}, geom::DeltaY{-240}, false}));
+    env.mock_libinput.setup_pointer_scroll_wheel_event(fake_device, event_time_1, {}, -1.0f, 0.0f, -240.0f);
+    process_events(mouse);
+}
+
+#ifdef MIR_LIBINPUT_HAS_VALUE120
+TEST_F(LibInputDeviceOnMouse, hi_res_scroll_scroll_is_accumulated)
+{
+    mouse.start(&mock_sink, &mock_builder);
+
+    EXPECT_CALL(mock_builder, pointer_event(
+        _, _, _, _, _, _, _,
+        mev::ScrollAxisV{geom::DeltaYF{1}, geom::DeltaY{0}, geom::DeltaY{50}, false}));
+    env.mock_libinput.setup_pointer_scroll_wheel_event(fake_device, event_time_1, {}, 1.0f, 0.0f, 50.0f);
+    process_events(mouse);
+
+    Mock::VerifyAndClearExpectations(&mock_builder);
+    ASSERT_THAT(env.mock_libinput.events.size(), Eq(0));
+
+    EXPECT_CALL(mock_builder, pointer_event(
+        _, _, _, _, _, _, _,
+        mev::ScrollAxisV{geom::DeltaYF{1}, geom::DeltaY{0}, geom::DeltaY{50}, false}));
+    env.mock_libinput.setup_pointer_scroll_wheel_event(fake_device, event_time_2, {}, 1.0f, 0.0f, 50.0f);
+    process_events(mouse);
+
+    Mock::VerifyAndClearExpectations(&mock_builder);
+    ASSERT_THAT(env.mock_libinput.events.size(), Eq(0));
+
+    EXPECT_CALL(mock_builder, pointer_event(
+        _, _, _, _, _, _, _,
+        mev::ScrollAxisV{geom::DeltaYF{1}, geom::DeltaY{1}, geom::DeltaY{50}, false}));
+    env.mock_libinput.setup_pointer_scroll_wheel_event(fake_device, event_time_3, {}, 1.0f, 0.0f, 50.0f);
+    process_events(mouse);
+}
+#endif
+
+#ifdef MIR_LIBINPUT_HAS_VALUE120
+TEST_F(LibInputDeviceOnMouse, hi_res_scroll_scroll_is_accumulated_negative)
+{
+    mouse.start(&mock_sink, &mock_builder);
+
+    EXPECT_CALL(mock_builder, pointer_event(
+        _, _, _, _, _, _, _,
+        mev::ScrollAxisV{geom::DeltaYF{-1}, geom::DeltaY{-2}, geom::DeltaY{-350}, false}));
+    env.mock_libinput.setup_pointer_scroll_wheel_event(fake_device, event_time_1, {}, -1.0f, 0.0f, -350.0f);
+    process_events(mouse);
+
+    Mock::VerifyAndClearExpectations(&mock_builder);
+    ASSERT_THAT(env.mock_libinput.events.size(), Eq(0));
+
+    EXPECT_CALL(mock_builder, pointer_event(
+        _, _, _, _, _, _, _,
+        mev::ScrollAxisV{geom::DeltaYF{-1}, geom::DeltaY{-1}, geom::DeltaY{-10}, false}));
+    env.mock_libinput.setup_pointer_scroll_wheel_event(fake_device, event_time_2, {}, -1.0f, 0.0f, -10.0f);
+    process_events(mouse);
+}
+#endif
+
+TEST_F(LibInputDeviceOnTouchScreen, process_event_ignores_uncorrelated_touch_up_events)
+{
+    MirTouchId slot = 3;
+
+    InSequence seq;
+    EXPECT_CALL(mock_builder, touch_event(_, _)).Times(0);
+    EXPECT_CALL(mock_sink, handle_input(_)).Times(0);
+
+    touch_screen.start(&mock_sink, &mock_builder);
+    env.mock_libinput.setup_touch_up_event(fake_device, event_time_1, slot);
+    env.mock_libinput.setup_touch_frame(fake_device, event_time_1);
+    process_events(touch_screen);
+}
+
+TEST_F(LibInputDeviceOnTouchScreen, process_event_ignores_excessive_touch_events_on_coordinate_0_0)
+{
+    MirTouchId slot1 = 0, slot2 = 1, slot3 = 2;
+    float major = 0;
+    float minor = 0;
+    float pressure = 0.0f;
+    float x = 0;
+    float y = 0;
+    float orientation = 0;
+
+    InSequence seq;
+    EXPECT_CALL(mock_builder, touch_event(_, _)).Times(0);
+    EXPECT_CALL(mock_sink, handle_input(_)).Times(0);
+
+    touch_screen.start(&mock_sink, &mock_builder);
+
+    //Add 2 touches on coordinate 0,0 - this should be detected as a spurious touch
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_1, slot1, x, y, major, minor,
+                                        pressure, orientation);
+    env.mock_libinput.setup_touch_up_event(fake_device, event_time_1, slot1);
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_1, slot2, x, y, major, minor,
+                                        pressure, orientation);
+    env.mock_libinput.setup_touch_up_event(fake_device, event_time_1, slot2);
+
+    //Add another valid touch event to make sure the frame is really not processed
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_1, slot3, 1, 1, major, minor,
+                                        pressure, orientation);
+    env.mock_libinput.setup_touch_up_event(fake_device, event_time_1, slot3);
+
+    env.mock_libinput.setup_touch_frame(fake_device, event_time_1);
+    process_events(touch_screen);
+}
+
+TEST_F(LibInputDeviceOnTouchScreen, process_event_does_not_ignore_valid_touch_events_on_coordinate_0_0)
+{
+    MirTouchId slot1 = 0, slot2 = 1;
+    float major = 0;
+    float minor = 0;
+    float pressure = 0.0f;
+    float x = 0;
+    float y = 0;
+    float orientation = 0;
+
+    InSequence seq;
+    EXPECT_CALL(mock_builder, touch_event(_, _)).Times(1);
+    EXPECT_CALL(mock_sink, handle_input(_)).Times(1);
+
+    touch_screen.start(&mock_sink, &mock_builder);
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_1, slot1, x, y, major, minor,
+                                        pressure, orientation);
+    env.mock_libinput.setup_touch_up_event(fake_device, event_time_1, slot1);
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_1, slot2, 1, 1, major, minor,
+                                        pressure, orientation);
+    env.mock_libinput.setup_touch_frame(fake_device, event_time_1);
+    process_events(touch_screen);
+}
+
+TEST_F(LibInputDeviceOnTouchScreen, process_event_ignores_touch_down_then_touch_up_in_same_frame)
+{
+    MirTouchId slot2 = 1;
+    float major = 0;
+    float minor = 0;
+    float pressure = 0.0f;
+    float orientation = 0;
+
+    InSequence seq;
+    EXPECT_CALL(mock_builder, touch_event(_, _)).Times(0);
+    EXPECT_CALL(mock_sink, handle_input(_)).Times(0);
+
+    touch_screen.start(&mock_sink, &mock_builder);
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_1, slot2, 1, 1, major, minor,
+                                        pressure, orientation);
+    env.mock_libinput.setup_touch_up_event(fake_device, event_time_1, slot2);
+    env.mock_libinput.setup_touch_frame(fake_device, event_time_1);
+    process_events(touch_screen);
+}
+
+TEST_F(LibInputDeviceOnTouchScreen, process_event_with_two_downs_but_one_up)
+{
+    MirTouchId slot1 = 0;
+    float major = 0;
+    float minor = 0;
+    float pressure = 0.0f;
+    float x = 1;
+    float y = 1;
+    float orientation = 0;
+
+    touch_screen.start(&mock_sink, &mock_builder);
+
+    // Send first down
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_1, slot1, x, y, major, minor,
+                                        pressure, orientation);
+    env.mock_libinput.setup_touch_frame(fake_device, event_time_1);
+
+    // Send second down
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_2, slot1, x, y, major, minor,
+                                        pressure, orientation);
+    env.mock_libinput.setup_touch_frame(fake_device, event_time_2);
+
+    // Send single up
+    env.mock_libinput.setup_touch_up_event(fake_device, event_time_3, slot1);
+    env.mock_libinput.setup_touch_frame(fake_device, event_time_3);
+
+    // Detect single touch down, a move, then single up
+    EXPECT_CALL(mock_builder, touch_event(_, _)).Times(3);
+    EXPECT_CALL(mock_sink, handle_input(mt::TouchContact(0, mir_touch_action_down, x, y))).Times(1);
+    EXPECT_CALL(mock_sink, handle_input(mt::TouchContact(0, mir_touch_action_change, x, y))).Times(1);
+    EXPECT_CALL(mock_sink, handle_input(mt::TouchUpEvent(x, y))).Times(1);
+
+    process_events(touch_screen);
+}
+
+TEST_F(LibInputDeviceOnTouchScreen, ignore_second_down_in_same_frame_then_detect_up)
+{
+    MirTouchId slot1 = 0;
+    float major = 0;
+    float minor = 0;
+    float pressure = 0.0f;
+    float x = 1;
+    float y = 1;
+    float orientation = 0;
+
+    touch_screen.start(&mock_sink, &mock_builder);
+
+    // Send first down
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_1, slot1, x, y, major, minor,
+                                        pressure, orientation);
+
+    // Send second down
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_1, slot1, x, y, major, minor,
+                                        pressure, orientation);
+    env.mock_libinput.setup_touch_frame(fake_device, event_time_1);
+
+    // Send single up
+    env.mock_libinput.setup_touch_up_event(fake_device, event_time_2, slot1);
+    env.mock_libinput.setup_touch_frame(fake_device, event_time_2);
+
+    // Detect single touch down, then single up
+    EXPECT_CALL(mock_builder, touch_event(_, _)).Times(2);
+    EXPECT_CALL(mock_sink, handle_input(mt::TouchContact(0, mir_touch_action_down, x, y))).Times(1);
+    EXPECT_CALL(mock_sink, handle_input(mt::TouchUpEvent(x, y))).Times(1);
+
+    process_events(touch_screen);
+}
+
+
+TEST_F(LibInputDeviceOnTouchScreen, process_event_spurious_frame_when_down)
+{
+    MirTouchId slot1 = 0, slot2 = 1;
+    float major = 0;
+    float minor = 0;
+    float pressure = 0.0f;
+    float x = 1;
+    float y = 1;
+    float orientation = 0;
+
+    touch_screen.start(&mock_sink, &mock_builder);
+
+    // Send first down
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_1, slot1, x, y, major, minor,
+                                        pressure, orientation);
+    env.mock_libinput.setup_touch_frame(fake_device, event_time_1);
+
+    // Send spurious down+up
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_2, slot1, 0, 0, major, minor,
+                                        pressure, orientation);
+    env.mock_libinput.setup_touch_up_event(fake_device, event_time_2, slot1);
+
+    env.mock_libinput.setup_touch_event(fake_device, LIBINPUT_EVENT_TOUCH_DOWN, event_time_2, slot2, 0, 0, major, minor,
+                                        pressure, orientation);
+    env.mock_libinput.setup_touch_up_event(fake_device, event_time_2, slot2);
+    env.mock_libinput.setup_touch_frame(fake_device, event_time_2);
+
+    // Detect single touch down, a move then single up
+    EXPECT_CALL(mock_builder, touch_event(_, _)).Times(2);
+    EXPECT_CALL(mock_sink, handle_input(mt::TouchContact(0, mir_touch_action_down, x, y))).Times(1);
+    EXPECT_CALL(mock_sink, handle_input(mt::TouchUpEvent(0, 0))).Times(1);
+
+    process_events(touch_screen);
+}
+
 TEST_F(LibInputDeviceOnTouchScreen, process_event_handles_touch_down_events)
 {
     MirTouchId slot = 0;
@@ -715,9 +1059,7 @@ TEST_F(LibInputDeviceOnMouse, applies_pointer_settings)
     settings.acceleration = mir_pointer_acceleration_none;
 
     EXPECT_CALL(env.mock_libinput, libinput_device_config_accel_set_speed(mouse.device(), 1.1)).Times(1);
-#if MIR_LIBINPUT_HAS_ACCEL_PROFILE
     EXPECT_CALL(env.mock_libinput, libinput_device_config_accel_set_profile(mouse.device(), LIBINPUT_CONFIG_ACCEL_PROFILE_FLAT)).Times(1);
-#endif
     EXPECT_CALL(env.mock_libinput, libinput_device_config_left_handed_set(mouse.device(), true)).Times(1);
 
     mouse.apply_settings(settings);
@@ -765,13 +1107,19 @@ TEST_F(LibInputDeviceOnTouchpad, process_event_handles_scroll)
 {
     InSequence seq;
     // expect two scroll events..
-    EXPECT_CALL(mock_builder, pointer_axis_with_stop_event(
-        mir_pointer_axis_source_finger, {time_stamp_1}, mir_pointer_action_motion, 0,
-        0, 0, 0.0f, -10.0f, false, false, 0.0f, 0.0f));
+    EXPECT_CALL(mock_builder, pointer_event(
+        {time_stamp_1}, mir_pointer_action_motion, 0,
+        Eq(std::nullopt), geom::DisplacementF{},
+        mir_pointer_axis_source_finger,
+        mev::ScrollAxisH{},
+        mev::ScrollAxisV{geom::DeltaYF{-10}, {}, false}));
     EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_vscroll, -10.0f)));
-    EXPECT_CALL(mock_builder, pointer_axis_with_stop_event(
-        mir_pointer_axis_source_finger, {time_stamp_2}, mir_pointer_action_motion, 0,
-        0, 0, 1.0f, 0.0f, false, false, 0.0f, 0.0f));
+    EXPECT_CALL(mock_builder, pointer_event(
+        {time_stamp_2}, mir_pointer_action_motion, 0,
+        Eq(std::nullopt), geom::DisplacementF{},
+        mir_pointer_axis_source_finger,
+        mev::ScrollAxisH{geom::DeltaXF{1}, {}, false},
+        mev::ScrollAxisV{}));
     EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_hscroll, 1.0f)));
 
     env.mock_libinput.setup_finger_axis_event(fake_device, event_time_1, {}, -10.0);
@@ -784,13 +1132,19 @@ TEST_F(LibInputDeviceOnTouchpad, process_event_handles_stop)
 {
     InSequence seq;
     // expect two scroll events..
-    EXPECT_CALL(mock_builder, pointer_axis_with_stop_event(
-        mir_pointer_axis_source_finger, {time_stamp_1}, mir_pointer_action_motion, 0,
-        0, 0, 0.0f, -10.0f, false, false, 0.0f, 0.0f));
+    EXPECT_CALL(mock_builder, pointer_event(
+        {time_stamp_1}, mir_pointer_action_motion, 0,
+        Eq(std::nullopt), geom::DisplacementF{},
+        mir_pointer_axis_source_finger,
+        mev::ScrollAxisH{},
+        mev::ScrollAxisV{geom::DeltaYF{-10}, {}, false}));
     EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_vscroll, -10.0f)));
-    EXPECT_CALL(mock_builder, pointer_axis_with_stop_event(
-        mir_pointer_axis_source_finger, {time_stamp_2}, mir_pointer_action_motion, 0,
-        0, 0, 0.0f, 0.0f, false, true, 0.0f, 0.0f));
+    EXPECT_CALL(mock_builder, pointer_event(
+        {time_stamp_2}, mir_pointer_action_motion, 0,
+        Eq(std::nullopt), geom::DisplacementF{},
+        mir_pointer_axis_source_finger,
+        mev::ScrollAxisH{},
+        mev::ScrollAxisV{{}, {}, true}));
     EXPECT_CALL(mock_sink, handle_input(mt::PointerAxisChange(mir_pointer_axis_vscroll, 0.0f)));
 
     env.mock_libinput.setup_finger_axis_event(fake_device, event_time_1, {}, -10.0);
