@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Andreas Pokorny <andreas.pokorny@canonical.com>
  */
 
 
@@ -24,6 +22,7 @@
 #include "mir/scene/session_event_handler_register.h"
 #include "mir/input/input_device_observer.h"
 #include "mir/input/mir_touchscreen_config.h"
+#include "mir/wayland/wayland_base.h"
 
 #include "mir/test/doubles/mock_input_device_hub.h"
 #include "mir/test/doubles/mock_input_manager.h"
