@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Robert Carr <robert.carr@canonical.com>
  */
 
 #include "src/server/input/cursor_controller.h"
@@ -144,25 +142,30 @@ struct StubInputSurface : public mtd::StubSurface
         cursor_image_ = image;
 
         {
-            std::unique_lock<decltype(observer_guard)> lk(observer_guard);
+            std::unique_lock lk(observer_guard);
             for (auto o : observers)
-                o->cursor_image_set_to(this, *image);
+                o->cursor_image_set_to(this, image);
         }
     }
 
-    void add_observer(std::shared_ptr<ms::SurfaceObserver> const& observer) override
+    void register_interest(std::weak_ptr<ms::SurfaceObserver> const& observer, mir::Executor&) override
     {
-        std::unique_lock<decltype(observer_guard)> lk(observer_guard);
-
-        observers.push_back(observer);
+        register_interest(observer);
     }
 
-    void remove_observer(std::weak_ptr<ms::SurfaceObserver> const& observer) override
+    void register_interest(std::weak_ptr<ms::SurfaceObserver> const& observer) override
     {
-        auto o = observer.lock();
-        assert(o);
+        std::unique_lock lk(observer_guard);
 
-        auto it = std::find(observers.begin(), observers.end(), o);
+        observers.push_back(observer.lock());
+    }
+
+    void unregister_interest(ms::SurfaceObserver const& observer) override
+    {
+        auto it = std::find_if(observers.begin(), observers.end(), [&observer](auto item)
+            {
+                return item.get() == &observer;
+            });
         observers.erase(it);
     }
 
@@ -170,7 +173,7 @@ struct StubInputSurface : public mtd::StubSurface
     {
         for (auto observer : observers)
         {
-            observer->frame_posted(this, 1, geom::Size{0, 0});
+            observer->frame_posted(this, 1, {});
         }
     }
 
@@ -179,12 +182,12 @@ struct StubInputSurface : public mtd::StubSurface
         cursor_image_ = image;
     }
 
-    std::experimental::optional<mir::geometry::Rectangle> clip_area() const override
+    std::optional<mir::geometry::Rectangle> clip_area() const override
     {
-        return std::experimental::optional<mir::geometry::Rectangle>();
+        return std::optional<mir::geometry::Rectangle>();
     }
 
-    void set_clip_area(std::experimental::optional<mir::geometry::Rectangle> const& /*area*/) override
+    void set_clip_area(std::optional<mir::geometry::Rectangle> const& /*area*/) override
     {
     }
 
