@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Robert Carr <robert.carr@canonical.com>
  */
 
 #include <gtest/gtest.h>
@@ -251,10 +249,9 @@ TEST(PointerInputEventProperties, axis_values_copied)
 {
     float x = 7, y = 9.3, hscroll = 13, vscroll = 17;
     MirPointerEvent old_ev;
-    old_ev.set_x(x);
-    old_ev.set_y(y);
-    old_ev.set_vscroll(vscroll);
-    old_ev.set_hscroll(hscroll);
+    old_ev.set_position({{x, y}});
+    old_ev.set_h_scroll({mir::geometry::DeltaXF{hscroll}, {}, false});
+    old_ev.set_v_scroll({mir::geometry::DeltaYF{vscroll}, {}, false});
 
     auto pev = mir_input_event_get_pointer_event(mir_event_get_input_event(&old_ev));
     EXPECT_EQ(x, mir_pointer_event_axis_value(pev, mir_pointer_axis_x));
