@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alexandros Frantzis <alexandros.frantzis@canonical.com>
  */
 
 #include "src/platforms/gbm-kms/server/kms/cursor.h"
@@ -191,11 +189,6 @@ struct StubKMSDisplayConfiguration : public mgg::KMSDisplayConfiguration
             });
     }
 
-    void for_each_card(std::function<void(mg::DisplayConfigurationCard const&)> f) const override
-    {
-        stub_config.for_each_card(f);
-    }
-
     void for_each_output(std::function<void(mg::DisplayConfigurationOutput const&)> f) const override
     {
         stub_config.for_each_output(f);
