@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Cemil Azizoglu <cemil.azizoglu@canonical.com>
  */
 
 #include <gtest/gtest.h>
@@ -103,6 +101,7 @@ public:
     {
         return std::make_shared<mgx::Display>(
                    mt::fake_shared(x11_resources),
+                   "Mir on X",
                    sizes,
                    mt::fake_shared(null_display_configuration_policy),
                    mt::fake_shared(mock_gl_config),
