@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Alan Griffiths <alan.griffiths@canonical.com>
  */
 
 #include "mir/shell/abstract_shell.h"
@@ -52,6 +50,7 @@
 #include <gtest/gtest.h>
 
 namespace mf = mir::frontend;
+namespace mw = mir::wayland;
 namespace mi = mir::input;
 namespace ms = mir::scene;
 namespace msh = mir::shell;
@@ -122,8 +121,9 @@ struct MockSessionManager : ms::SessionManager
 
 struct MockSurfaceFactory : public ms::SurfaceFactory
 {
-    MOCK_METHOD3(create_surface, std::shared_ptr<ms::Surface>(
+    MOCK_METHOD4(create_surface, std::shared_ptr<ms::Surface>(
         std::shared_ptr<ms::Session> const&,
+        mw::Weak<mf::WlSurface> const&,
         std::list<ms::StreamInfo> const&,
         msh::SurfaceSpecification const&));
 };
@@ -138,6 +138,9 @@ using NiceMockWindowManager = NiceMock<mtd::MockWindowManager>;
 struct AbstractShell : Test
 {
     NiceMock<mtd::MockSurface> mock_surface;
+    NiceMock<mtd::MockSurface> mock_surface1;
+    NiceMock<mtd::MockSurface> mock_surface2;
+    NiceMock<mtd::MockSurface> mock_surface_child;
     NiceMock<mtd::MockSurfaceStack> surface_stack;
     ms::SessionContainer session_container;
     NiceMock<MockSessionEventSink> session_event_sink;
@@ -172,7 +175,7 @@ struct AbstractShell : Test
             WillByDefault(Invoke(&session_manager, &MockSessionManager::unmocked_set_focus_to));
         ON_CALL(mock_surface, size())
             .WillByDefault(Return(geom::Size{}));
-        ON_CALL(surface_factory, create_surface(_, _, _))
+        ON_CALL(surface_factory, create_surface(_, _, _, _))
             .WillByDefault(Return(mt::fake_shared(mock_surface)));
         ON_CALL(seat, create_device_state())
             .WillByDefault(Invoke(
@@ -191,11 +194,13 @@ struct AbstractShell : Test
             mir::Fd{mir::Fd::invalid},
             "Foo",
             std::shared_ptr<mf::EventSink>());
-        EXPECT_CALL(surface_factory, create_surface(_, _, _))
+        EXPECT_CALL(surface_factory, create_surface(_, _, _, _))
             .WillOnce(Return(mt::fake_shared(surface)));
         return shell.create_surface(
             session,
+            {},
             mt::make_surface_spec(session->create_buffer_stream(properties)),
+            nullptr,
             nullptr);
     }
 
@@ -246,18 +251,18 @@ TEST_F(AbstractShell, close_session_removes_existing_session_surfaces_from_windo
     mtd::StubSurface surface1;
     mtd::StubSurface surface2;
     mtd::StubSurface surface3;
-    EXPECT_CALL(surface_factory, create_surface(_, _, _)).
+    EXPECT_CALL(surface_factory, create_surface(_, _, _, _)).
         WillOnce(Return(mt::fake_shared(surface1))).
         WillOnce(Return(mt::fake_shared(surface2))).
         WillOnce(Return(mt::fake_shared(surface3)));
 
     auto const session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
-    auto const created_surface1 = shell.create_surface(session,
-        mt::make_surface_spec(session->create_buffer_stream(properties)), nullptr);
-    auto const created_surface2 = shell.create_surface(session,
-        mt::make_surface_spec(session->create_buffer_stream(properties)), nullptr);
-    auto const created_surface3 = shell.create_surface(session,
-        mt::make_surface_spec(session->create_buffer_stream(properties)), nullptr);
+    auto const created_surface1 = shell.create_surface(session, {},
+        mt::make_surface_spec(session->create_buffer_stream(properties)), nullptr, nullptr);
+    auto const created_surface2 = shell.create_surface(session, {},
+        mt::make_surface_spec(session->create_buffer_stream(properties)), nullptr, nullptr);
+    auto const created_surface3 = shell.create_surface(session, {},
+        mt::make_surface_spec(session->create_buffer_stream(properties)), nullptr, nullptr);
 
     session->destroy_surface(created_surface2);
 
@@ -278,7 +283,7 @@ TEST_F(AbstractShell, create_surface_provides_create_parameters_to_window_manage
     auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
     EXPECT_CALL(*wm, add_surface(session, params, _));
 
-    shell.create_surface(session, params, nullptr);
+    shell.create_surface(session, {}, params, nullptr, nullptr);
 }
 
 TEST_F(AbstractShell, create_surface_allows_window_manager_to_set_create_parameters)
@@ -298,7 +303,7 @@ TEST_F(AbstractShell, create_surface_allows_window_manager_to_set_create_paramet
             std::function<std::shared_ptr<ms::Surface>(std::shared_ptr<ms::Session> const& session, msh::SurfaceSpecification const&)> const& build)
             { return build(session, params); }));
 
-    shell.create_surface(session, params, nullptr);
+    shell.create_surface(session, {}, params, nullptr, nullptr);
 }
 
 TEST_F(AbstractShell, create_surface_allows_window_manager_to_enable_ssd)
@@ -323,7 +328,7 @@ TEST_F(AbstractShell, create_surface_allows_window_manager_to_enable_ssd)
                 return build(session, modified_params);
             }));
 
-    shell.create_surface(session, params, nullptr);
+    shell.create_surface(session, {}, params, nullptr, nullptr);
 }
 
 TEST_F(AbstractShell, create_surface_allows_window_manager_to_disable_ssd)
@@ -349,7 +354,7 @@ TEST_F(AbstractShell, create_surface_allows_window_manager_to_disable_ssd)
                 return build(session, modified_params);
             }));
 
-    shell.create_surface(session, params, nullptr);
+    shell.create_surface(session, {}, params, nullptr, nullptr);
 }
 
 TEST_F(AbstractShell, create_surface_sets_surfaces_session)
@@ -359,12 +364,12 @@ TEST_F(AbstractShell, create_surface_sets_surfaces_session)
     std::shared_ptr<ms::Session> session =
         shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
-    EXPECT_CALL(surface_factory, create_surface(session, _, _)).
+    EXPECT_CALL(surface_factory, create_surface(session, _, _, _)).
         WillOnce(Return(mock_surface));
 
     auto params = mt::make_surface_spec(session->create_buffer_stream(properties));
 
-    shell.create_surface(session, params, nullptr);
+    shell.create_surface(session, {}, params, nullptr, nullptr);
 }
 
 TEST_F(AbstractShell, destroy_surface_removes_surface_from_window_manager)
@@ -373,7 +378,7 @@ TEST_F(AbstractShell, destroy_surface_removes_surface_from_window_manager)
         shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
 
-    auto const surface = shell.create_surface(session, params, nullptr);
+    auto const surface = shell.create_surface(session, {}, params, nullptr, nullptr);
 
     EXPECT_CALL(*wm, remove_surface(session, WeakPtrTo(surface)));
 
@@ -480,7 +485,7 @@ TEST_F(AbstractShell, setting_surface_state_is_handled_by_window_manager)
         shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto const surface = shell.create_surface(session, params, nullptr);
+    auto const surface = shell.create_surface(session, {}, params, nullptr, nullptr);
 
     MirWindowState const state{mir_window_state_fullscreen};
 
@@ -516,8 +521,8 @@ TEST_F(AbstractShell, as_focus_controller_focus_next_session_notifies_session_ev
     auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto const params2 = mt::make_surface_spec(session->create_buffer_stream(properties));
-    shell.create_surface(session, params, nullptr);
-    shell.create_surface(session1, params2, nullptr);
+    shell.create_surface(session, {}, params, nullptr, nullptr);
+    shell.create_surface(session1, {}, params2, nullptr, nullptr);
 
     focus_controller.set_focus_to(session, {});
 
@@ -532,8 +537,8 @@ TEST_F(AbstractShell, as_focus_controller_focused_session_follows_focus)
     auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
     auto const params2 = mt::make_surface_spec(session->create_buffer_stream(properties));
-    shell.create_surface(session, params, nullptr);
-    shell.create_surface(session1, params2, nullptr);
+    shell.create_surface(session, {}, params, nullptr, nullptr);
+    shell.create_surface(session1, {}, params2, nullptr, nullptr);
 
     msh::FocusController& focus_controller = shell;
 
@@ -549,16 +554,15 @@ TEST_F(AbstractShell, as_focus_controller_focused_surface_follows_focus)
 {
     auto const session0 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
     auto const session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
-    NiceMock<mtd::MockSurface> dummy_surface;
-    ON_CALL(dummy_surface, size()).WillByDefault(Return(geom::Size{}));
-    EXPECT_CALL(surface_factory, create_surface(_, _, _)).Times(AnyNumber())
-        .WillOnce(Return(mt::fake_shared(dummy_surface)))
+    ON_CALL(mock_surface1, size()).WillByDefault(Return(geom::Size{}));
+    EXPECT_CALL(surface_factory, create_surface(_, _, _, _)).Times(AnyNumber())
+        .WillOnce(Return(mt::fake_shared(mock_surface1)))
         .WillOnce(Return(mt::fake_shared(mock_surface)));
 
     auto const params0 = mt::make_surface_spec(session0->create_buffer_stream(properties));
     auto const params1 = mt::make_surface_spec(session1->create_buffer_stream(properties));
-    auto const surface0 = shell.create_surface(session0, params0, nullptr);
-    auto const surface1 = shell.create_surface(session1, params1, nullptr);
+    auto const surface0 = shell.create_surface(session0, {}, params0, nullptr, nullptr);
+    auto const surface1 = shell.create_surface(session1, {}, params1, nullptr, nullptr);
 
     msh::FocusController& focus_controller = shell;
 
@@ -595,9 +599,9 @@ TEST_F(AbstractShell, as_focus_controller_focus_next_session_skips_surfaceless_s
     auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Surfaceless", std::shared_ptr<mf::EventSink>());
     auto session2 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto created_surface = shell.create_surface(session, params, nullptr);
+    auto created_surface = shell.create_surface(session, {}, params, nullptr, nullptr);
     auto const params2 = mt::make_surface_spec(session2->create_buffer_stream(properties));
-    shell.create_surface(session2, params2, nullptr);
+    shell.create_surface(session2, {}, params2, nullptr, nullptr);
 
     focus_controller.set_focus_to(session, created_surface);
 
@@ -613,7 +617,7 @@ TEST_F(AbstractShell,
     auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
     auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Surfaceless", std::shared_ptr<mf::EventSink>());
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, creation_params, nullptr);
+    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
 
     focus_controller.set_focus_to(session, surface);
 
@@ -630,7 +634,7 @@ TEST_F(AbstractShell, modify_surface_with_only_streams_doesnt_call_into_wm)
         shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, creation_params, nullptr);
+    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
 
     msh::SurfaceSpecification stream_modification;
     stream_modification.streams = std::vector<msh::StreamSpecification>{};
@@ -647,7 +651,7 @@ TEST_F(AbstractShell, modify_surface_does_not_call_wm_for_empty_changes)
 
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
 
-    auto surface = shell.create_surface(session, creation_params, nullptr);
+    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
 
     msh::SurfaceSpecification stream_modification;
 
@@ -670,7 +674,7 @@ TEST_F(AbstractShell, size_gets_adjusted_for_windows_with_margins)
         shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, creation_params, nullptr);
+    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
     surface->resize({50, 50});
     surface->set_window_margins(top, left, bottom, right);
 
@@ -701,7 +705,7 @@ TEST_F(AbstractShell, max_size_gets_adjusted_for_windows_with_margins)
         shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, creation_params, nullptr);
+    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
     surface->resize({50, 50});
     surface->set_window_margins(top, left, bottom, right);
 
@@ -732,7 +736,7 @@ TEST_F(AbstractShell, min_size_gets_adjusted_for_windows_with_margins)
         shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, creation_params, nullptr);
+    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
     surface->resize({50, 50});
     surface->set_window_margins(top, left, bottom, right);
 
@@ -764,7 +768,7 @@ TEST_F(AbstractShell, aux_rect_gets_adjusted_for_windows_with_margins)
         shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
 
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, creation_params, nullptr);
+    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
     surface->resize(content_size);
     surface->set_window_margins(top, left, bottom, right);
 
@@ -790,7 +794,7 @@ TEST_F(AbstractShell, when_remaining_session_has_no_surface_focus_next_session_d
             shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "another_session", std::shared_ptr<mf::EventSink>());
 
         auto creation_params = mt::make_surface_spec(another_session->create_buffer_stream(properties));
-        auto surface = shell.create_surface(another_session, creation_params, nullptr);
+        auto surface = shell.create_surface(another_session, {}, creation_params, nullptr, nullptr);
 
         shell.set_focus_to(another_session, surface);
 
@@ -802,16 +806,15 @@ TEST_F(AbstractShell, when_remaining_session_has_no_surface_focus_next_session_d
 
 TEST_F(AbstractShell, focus_can_be_set)
 {
-    NiceMock<mtd::MockSurface> mock_surface1;
-    EXPECT_CALL(surface_factory, create_surface(_, _, _)).Times(AnyNumber())
+    EXPECT_CALL(surface_factory, create_surface(_, _, _, _)).Times(AnyNumber())
         .WillOnce(Return(mt::fake_shared(mock_surface1)))
         .WillOnce(Return(mt::fake_shared(mock_surface)));
 
     msh::FocusController& focus_controller = shell;
     auto const session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto const created_surface1 = shell.create_surface(session, params, nullptr);
-    auto const created_surface2 = shell.create_surface(session, params, nullptr);
+    auto const created_surface1 = shell.create_surface(session, {}, params, nullptr, nullptr);
+    auto const created_surface2 = shell.create_surface(session, {}, params, nullptr, nullptr);
 
     focus_controller.set_focus_to(session, created_surface2);
     EXPECT_THAT(created_surface1->focus_state(), Eq(mir_window_focus_state_unfocused));
@@ -824,11 +827,9 @@ TEST_F(AbstractShell, focus_can_be_set)
 
 TEST_F(AbstractShell, setting_focus_to_child_makes_parent_active)
 {
-    NiceMock<mtd::MockSurface> mock_surface1;
-    NiceMock<mtd::MockSurface> mock_surface2;
     ON_CALL(mock_surface1, parent())
         .WillByDefault(Return(mt::fake_shared(mock_surface)));
-    EXPECT_CALL(surface_factory, create_surface(_, _, _)).Times(AnyNumber())
+    EXPECT_CALL(surface_factory, create_surface(_, _, _, _)).Times(AnyNumber())
         .WillOnce(Return(mt::fake_shared(mock_surface)))
         .WillOnce(Return(mt::fake_shared(mock_surface1)))
         .WillOnce(Return(mt::fake_shared(mock_surface2)));
@@ -836,9 +837,9 @@ TEST_F(AbstractShell, setting_focus_to_child_makes_parent_active)
     msh::FocusController& focus_controller = shell;
     auto const session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto const parent_surface = shell.create_surface(session, params, nullptr);
-    auto const child_surface = shell.create_surface(session, params, nullptr);
-    auto const other_surface = shell.create_surface(session, params, nullptr);
+    auto const parent_surface = shell.create_surface(session, {}, params, nullptr, nullptr);
+    auto const child_surface = shell.create_surface(session, {}, params, nullptr, nullptr);
+    auto const other_surface = shell.create_surface(session, {}, params, nullptr, nullptr);
 
     ASSERT_THAT(child_surface->parent(), Eq(parent_surface));
 
@@ -855,7 +856,6 @@ TEST_F(AbstractShell, does_not_give_keyboard_focus_to_menu)
 {
     auto const surface_parent = create_surface(mock_surface);
 
-    NiceMock<mtd::MockSurface> mock_surface_child;
     auto const surface_child = create_surface(mock_surface_child);
     ON_CALL(mock_surface_child, parent())
         .WillByDefault(Return(surface_parent));
@@ -873,7 +873,6 @@ TEST_F(AbstractShell, does_not_give_keyboard_focus_to_tip)
 {
     auto const surface_parent = create_surface(mock_surface);
 
-    NiceMock<mtd::MockSurface> mock_surface_child;
     auto const surface_child = create_surface(mock_surface_child);
     ON_CALL(mock_surface_child, parent())
         .WillByDefault(Return(surface_parent));
@@ -891,14 +890,12 @@ TEST_F(AbstractShell, does_not_deactivate_parent_when_switching_children)
 {
     auto const surface_parent = create_surface(mock_surface);
 
-    NiceMock<mtd::MockSurface> mock_surface_child_a;
-    auto const surface_child_a = create_surface(mock_surface_child_a);
-    ON_CALL(mock_surface_child_a, parent())
+    auto const surface_child_a = create_surface(mock_surface1);
+    ON_CALL(mock_surface1, parent())
         .WillByDefault(Return(surface_parent));
 
-    NiceMock<mtd::MockSurface> mock_surface_child_b;
-    auto const surface_child_b = create_surface(mock_surface_child_b);
-    ON_CALL(mock_surface_child_b, parent())
+    auto const surface_child_b = create_surface(mock_surface2);
+    ON_CALL(mock_surface2, parent())
         .WillByDefault(Return(surface_parent));
 
     msh::FocusController& focus_controller = shell;
@@ -912,7 +909,6 @@ TEST_F(AbstractShell, makes_parent_active_when_switching_to_child)
 {
     auto const surface_parent = create_surface(mock_surface);
 
-    NiceMock<mtd::MockSurface> mock_surface_child;
     auto const surface_child = create_surface(mock_surface_child);
     ON_CALL(mock_surface_child, parent())
         .WillByDefault(Return(surface_parent));
@@ -939,7 +935,6 @@ TEST_F(AbstractShell, makes_parent_focused_when_switching_back_from_child)
 {
     auto const surface_parent = create_surface(mock_surface);
 
-    NiceMock<mtd::MockSurface> mock_surface_child;
     auto const surface_child = create_surface(mock_surface_child);
     ON_CALL(mock_surface_child, parent())
         .WillByDefault(Return(surface_parent));
@@ -965,25 +960,23 @@ TEST_F(AbstractShell, removing_focus_from_menu_closes_it)
 {
     auto const surface_parent = create_surface(mock_surface);
 
-    NiceMock<mtd::MockSurface> mock_surface_menu;
-    auto const surface_menu = create_surface(mock_surface_menu);
-    ON_CALL(mock_surface_menu, parent())
+    auto const surface_menu = create_surface(mock_surface1);
+    ON_CALL(mock_surface1, parent())
         .WillByDefault(Return(surface_parent));
-    ON_CALL(mock_surface_menu, type())
+    ON_CALL(mock_surface1, type())
         .WillByDefault(Return(mir_window_type_menu));
 
     msh::FocusController& focus_controller = shell;
     focus_controller.set_focus_to(surface_menu->session().lock(), surface_menu);
 
-    EXPECT_CALL(mock_surface_menu, request_client_surface_close());
+    EXPECT_CALL(mock_surface1, request_client_surface_close());
     focus_controller.set_focus_to(surface_parent->session().lock(), surface_parent);
 }
 
 // Regression test for https://github.com/MirServer/mir/issues/2279
 TEST_F(AbstractShell, focus_next_session_allows_later_focusing_same_window)
 {
-    NiceMock<mtd::MockSurface> mock_surface1;
-    EXPECT_CALL(surface_factory, create_surface(_, _, _)).Times(AnyNumber())
+    EXPECT_CALL(surface_factory, create_surface(_, _, _, _)).Times(AnyNumber())
         .WillOnce(Return(mt::fake_shared(mock_surface1)))
         .WillOnce(Return(mt::fake_shared(mock_surface)));
 
@@ -991,9 +984,9 @@ TEST_F(AbstractShell, focus_next_session_allows_later_focusing_same_window)
     auto session1 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "XPlane", std::shared_ptr<mf::EventSink>());
     auto session2 = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "Bla", std::shared_ptr<mf::EventSink>());
     auto const params1 = mt::make_surface_spec(session1->create_buffer_stream(properties));
-    auto created_surface1 = shell.create_surface(session1, params1, nullptr);
+    auto created_surface1 = shell.create_surface(session1, {}, params1, nullptr, nullptr);
     auto const params2 = mt::make_surface_spec(session2->create_buffer_stream(properties));
-    auto created_surface2 = shell.create_surface(session2, params2, nullptr);
+    auto created_surface2 = shell.create_surface(session2, {}, params2, nullptr, nullptr);
 
     focus_controller.set_focus_to(session1, created_surface1);
     focus_controller.focus_next_session();
@@ -1034,7 +1027,7 @@ TEST_F(AbstractShell, as_focus_controller_emits_input_device_state_event_on_focu
 
     auto session = shell.open_session(__LINE__, mir::Fd{mir::Fd::invalid}, "some", std::shared_ptr<mf::EventSink>());
     auto creation_params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surface = shell.create_surface(session, creation_params, nullptr);
+    auto surface = shell.create_surface(session, {}, creation_params, nullptr, nullptr);
 
     msh::FocusController& focus_controller = shell;
     focus_controller.set_focus_to(session, surface);
