@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored By: Robert Carr <racarr@canonical.com>
  */
 
 #include "src/server/scene/application_session.h"
@@ -44,6 +42,7 @@
 
 namespace mc = mir::compositor;
 namespace mf = mir::frontend;
+namespace mw = mir::wayland;
 namespace ms = mir::scene;
 namespace msh = mir::shell;
 namespace mi = mir::input;
@@ -222,8 +221,9 @@ struct ApplicationSession : public testing::Test
 
 struct MockSurfaceFactory : ms::SurfaceFactory
 {
-    MOCK_METHOD3(create_surface, std::shared_ptr<ms::Surface>(
+    MOCK_METHOD4(create_surface, std::shared_ptr<ms::Surface>(
         std::shared_ptr<ms::Session> const&,
+        mw::Weak<mf::WlSurface> const&,
         std::list<ms::StreamInfo> const&,
         msh::SurfaceSpecification const& params));
 };
@@ -237,14 +237,14 @@ TEST_F(ApplicationSession, adds_created_surface_to_coordinator)
     NiceMock<mtd::MockSurfaceStack> surface_stack;
     std::shared_ptr<ms::Surface> mock_surface = make_mock_surface();
 
-    EXPECT_CALL(mock_surface_factory, create_surface(_, _, _))
+    EXPECT_CALL(mock_surface_factory, create_surface(_, _, _, _))
         .WillOnce(Return(mock_surface));
     EXPECT_CALL(surface_stack, add_surface(mock_surface,_));
     auto session = make_application_session(
         mt::fake_shared(surface_stack), mt::fake_shared(mock_surface_factory));
 
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surf = session->create_surface(nullptr, params, surface_observer);
+    auto surf = session->create_surface(nullptr, {}, params, surface_observer, nullptr);
 
     session->destroy_surface(surf);
 }
@@ -271,7 +271,7 @@ TEST_F(ApplicationSession, can_destroy_buffer_stream_after_destroying_surface)
     NiceMock<mtd::MockSurfaceStack> surface_stack;
     std::shared_ptr<ms::Surface> mock_surface = make_mock_surface();
 
-    EXPECT_CALL(mock_surface_factory, create_surface(_, _, _))
+    EXPECT_CALL(mock_surface_factory, create_surface(_, _, _, _))
         .WillOnce(Return(mock_surface));
     EXPECT_CALL(surface_stack, add_surface(mock_surface,_));
     auto session = make_application_session(
@@ -279,7 +279,7 @@ TEST_F(ApplicationSession, can_destroy_buffer_stream_after_destroying_surface)
 
     auto buffer_stream = session->create_buffer_stream(properties);
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surf = session->create_surface(nullptr, params, surface_observer);
+    auto surf = session->create_surface(nullptr, {}, params, surface_observer, nullptr);
 
     session->destroy_surface(surf);
     session->destroy_buffer_stream(buffer_stream);
@@ -298,7 +298,7 @@ TEST_F(ApplicationSession, notifies_listener_of_create_and_destroy_surface)
     auto session = make_application_session_with_listener(mt::fake_shared(listener));
 
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surf = session->create_surface(nullptr, params, surface_observer);
+    auto surf = session->create_surface(nullptr, {}, params, surface_observer, nullptr);
 
     session->destroy_surface(surf);
 }
@@ -317,7 +317,7 @@ TEST_F(ApplicationSession, notifies_listener_of_surface_destruction_via_session_
         auto session = make_application_session_with_listener(mt::fake_shared(listener));
 
         auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
-        session->create_surface(nullptr, params, surface_observer);
+        session->create_surface(nullptr, {}, params, surface_observer, nullptr);
     }
 }
 
@@ -341,9 +341,9 @@ TEST_F(ApplicationSession, default_surface_is_first_surface)
     auto app_session = make_application_session_with_stubs();
 
     auto const params = mt::make_surface_spec(app_session->create_buffer_stream(properties));
-    auto surface1 = app_session->create_surface(nullptr, params, nullptr);
-    auto surface2 = app_session->create_surface(nullptr, params, nullptr);
-    auto surface3 = app_session->create_surface(nullptr, params, nullptr);
+    auto surface1 = app_session->create_surface(nullptr, {}, params, nullptr, nullptr);
+    auto surface2 = app_session->create_surface(nullptr, {}, params, nullptr, nullptr);
+    auto surface3 = app_session->create_surface(nullptr, {}, params, nullptr, nullptr);
 
     auto default_surf = app_session->default_surface();
     EXPECT_EQ(surface1, default_surf);
@@ -362,8 +362,8 @@ TEST_F(ApplicationSession, foreign_surface_has_no_successor)
 {
     auto session1 = make_application_session_with_stubs();
     auto const params = mt::make_surface_spec(session1->create_buffer_stream(properties));
-    auto surf1 = session1->create_surface(nullptr, params, nullptr);
-    auto surf2 = session1->create_surface(nullptr, params, nullptr);
+    auto surf1 = session1->create_surface(nullptr, {}, params, nullptr, nullptr);
+    auto surf2 = session1->create_surface(nullptr, {}, params, nullptr, nullptr);
 
     auto session2 = make_application_session_with_stubs();
 
@@ -378,7 +378,7 @@ TEST_F(ApplicationSession, surface_after_one_is_self)
 {
     auto session = make_application_session_with_stubs();
     auto const params = mt::make_surface_spec(session->create_buffer_stream(properties));
-    auto surf = session->create_surface(nullptr, params, nullptr);
+    auto surf = session->create_surface(nullptr, {}, params, nullptr, nullptr);
 
     EXPECT_EQ(surf, session->surface_after(surf));
 
@@ -396,7 +396,7 @@ TEST_F(ApplicationSession, surface_after_cycles_through_all)
 
     for (int i = 0; i < N; ++i)
     {
-        surf[i] = app_session->create_surface(nullptr, params, nullptr);
+        surf[i] = app_session->create_surface(nullptr, {}, params, nullptr, nullptr);
 
         if (i > 0)
         {
@@ -420,7 +420,7 @@ TEST_F(ApplicationSession, session_visbility_propagates_to_surfaces)
     auto mock_surface = make_mock_surface();
 
     NiceMock<MockSurfaceFactory> surface_factory;
-    ON_CALL(surface_factory, create_surface(_, _, _)).WillByDefault(Return(mock_surface));
+    ON_CALL(surface_factory, create_surface(_, _, _, _)).WillByDefault(Return(mock_surface));
     NiceMock<mtd::MockSurfaceStack> surface_stack;
     auto app_session = make_application_session(mt::fake_shared(surface_stack), mt::fake_shared(surface_factory));
 
@@ -431,7 +431,7 @@ TEST_F(ApplicationSession, session_visbility_propagates_to_surfaces)
     }
 
     auto const params = mt::make_surface_spec(app_session->create_buffer_stream(properties));
-    auto surf = app_session->create_surface(nullptr, params, surface_observer);
+    auto surf = app_session->create_surface(nullptr, {}, params, surface_observer, nullptr);
 
     app_session->hide();
     app_session->show();
@@ -464,7 +464,7 @@ TEST_F(ApplicationSession, can_destroy_surface_bstream)
     auto session = make_application_session_with_stubs();
     auto const stream = session->create_buffer_stream(properties);
     auto const params = mt::make_surface_spec(stream);
-    auto id = session->create_surface(nullptr, params, surface_observer);
+    auto id = session->create_surface(nullptr, {}, params, surface_observer, nullptr);
     session->destroy_buffer_stream(stream);
     EXPECT_FALSE(session->has_buffer_stream(stream));
     session->destroy_surface(id);
@@ -483,7 +483,7 @@ TEST_F(ApplicationSession, sets_and_looks_up_surface_streams)
     NiceMock<MockSurfaceFactory> mock_surface_factory;
 
     auto mock_surface = make_mock_surface();
-    EXPECT_CALL(mock_surface_factory, create_surface(_, _, _))
+    EXPECT_CALL(mock_surface_factory, create_surface(_, _, _, _))
         .WillOnce(Return(mock_surface));
     
     std::array<std::shared_ptr<mc::BufferStream>,3> streams {{
@@ -515,7 +515,7 @@ TEST_F(ApplicationSession, sets_and_looks_up_surface_streams)
         {streams[1], geom::Displacement{0,2}, {}}
     };
 
-    session->create_surface(nullptr, mt::make_surface_spec(stream0), surface_observer);
+    session->create_surface(nullptr, {}, mt::make_surface_spec(stream0), surface_observer, nullptr);
 
     EXPECT_CALL(*mock_surface, set_streams(Pointwise(StreamEq(), info)));
     session->configure_streams(*mock_surface, {
@@ -596,14 +596,14 @@ TEST_F(ApplicationSession, surface_uses_prexisting_buffer_stream_if_set)
 
     auto stream = session->create_buffer_stream(properties);
 
-    EXPECT_CALL(mock_surface_factory, create_surface(_, HasSingleStream(stream), _))
+    EXPECT_CALL(mock_surface_factory, create_surface(_, _, HasSingleStream(stream), _))
         .WillOnce(Return(make_mock_surface()));
 
     auto params = mt::make_surface_spec(stream);
     params.name = "Aardavks";
     params.type = mir_window_type_normal;
 
-    session->create_surface(nullptr, params, surface_observer);
+    session->create_surface(nullptr, {}, params, surface_observer, nullptr);
 }
 
 namespace
@@ -688,14 +688,14 @@ namespace
 class ObserverPreservingSurface : public mtd::MockSurface
 {
 public:
-    void add_observer(std::shared_ptr<mir::scene::SurfaceObserver> const &observer) override
+    void register_interest(std::weak_ptr<mir::scene::SurfaceObserver> const& observer) override
     {
-        return BasicSurface::add_observer(observer);
+        return BasicSurface::register_interest(observer);
     }
 
-    void remove_observer(std::weak_ptr<mir::scene::SurfaceObserver> const &observer) override
+    void unregister_interest(mir::scene::SurfaceObserver const& observer) override
     {
-        return BasicSurface::remove_observer(observer);
+        return BasicSurface::unregister_interest(observer);
     }
 };
 
@@ -704,6 +704,7 @@ class ObserverPreservingSurfaceFactory : public ms::SurfaceFactory
 public:
     std::shared_ptr<ms::Surface> create_surface(
         std::shared_ptr<ms::Session> const&,
+        mw::Weak<mf::WlSurface> const&,
         std::list<ms::StreamInfo> const&,
         mir::shell::SurfaceSpecification const& params) override
     {
