@@ -12,13 +12,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
 
 #include "src/server/scene/basic_surface.h"
-#include "src/server/scene/legacy_surface_change_notification.h"
+#include "src/server/scene/surface_change_notification.h"
 
 #include "mir/events/event_private.h"
 #include "mir/frontend/event_sink.h"
@@ -31,7 +29,9 @@
 #include "mir/test/doubles/mock_buffer_stream.h"
 #include "mir/test/doubles/stub_buffer.h"
 #include "mir/test/doubles/stub_session.h"
+#include "mir/test/doubles/explicit_executor.h"
 #include "mir/test/fake_shared.h"
+#include "mir/test/geometry_matchers.h"
 
 #include "src/server/report/null_report_factory.h"
 
@@ -42,6 +42,7 @@
 
 namespace mc = mir::compositor;
 namespace mf = mir::frontend;
+namespace mw = mir::wayland;
 namespace mi = mir::input;
 namespace mr = mir::report;
 namespace ms = mir::scene;
@@ -66,10 +67,11 @@ public:
     MOCK_METHOD3(attrib_changed, void(ms::Surface const*, MirWindowAttrib, int));
     MOCK_METHOD2(window_resized_to, void(ms::Surface const*, geom::Size const&));
     MOCK_METHOD2(content_resized_to, void(ms::Surface const*, geom::Size const&));
+    MOCK_METHOD3(frame_posted, void(ms::Surface const*, int, geom::Rectangle const&));
     MOCK_METHOD2(hidden_set_to, void(ms::Surface const*, bool));
-    MOCK_METHOD2(renamed, void(ms::Surface const*, char const*));
+    MOCK_METHOD2(renamed, void(ms::Surface const*, std::string const&));
     MOCK_METHOD1(client_surface_close_requested, void(ms::Surface const*));
-    MOCK_METHOD2(cursor_image_set_to, void(ms::Surface const*, mir::graphics::CursorImage const& image));
+    MOCK_METHOD2(cursor_image_set_to, void(ms::Surface const*, std::weak_ptr<mir::graphics::CursorImage> const& image));
     MOCK_METHOD1(cursor_image_removed, void(ms::Surface const*));
     MOCK_METHOD2(application_id_set_to, void(ms::Surface const*, std::string const&));
 };
@@ -86,12 +88,14 @@ struct BasicSurfaceTest : public testing::Test
         std::make_shared<testing::NiceMock<mtd::MockBufferStream>>();
     std::shared_ptr<ms::SceneReport> const report = mr::null_scene_report();
     void const* compositor_id{nullptr};
-    std::shared_ptr<ms::LegacySurfaceChangeNotification> observer =
-        std::make_shared<ms::LegacySurfaceChangeNotification>(mock_change_cb, [this](int){mock_change_cb();});
     std::list<ms::StreamInfo> streams { { mock_buffer_stream, {}, {} } };
+    std::shared_ptr<testing::NiceMock<MockSurfaceObserver>> mock_surface_observer =
+        std::make_shared<testing::NiceMock<MockSurfaceObserver>>();
+    mtd::ExplicitExecutor executor;
 
     ms::BasicSurface surface{
         nullptr /* session */,
+        {} /* wayland_surface */,
         name,
         rect,
         mir_pointer_unconfined,
@@ -99,12 +103,23 @@ struct BasicSurfaceTest : public testing::Test
         std::shared_ptr<mg::CursorImage>(),
         report};
 
+    std::shared_ptr<ms::SurfaceChangeNotification> observer =
+        std::make_shared<ms::SurfaceChangeNotification>(
+            &surface,
+            mock_change_cb,
+            [this](int, geom::Rectangle const&){mock_change_cb();});
+
     BasicSurfaceTest()
     {
         // use an opaque pixel format by default
         ON_CALL(*mock_buffer_stream, pixel_format())
             .WillByDefault(testing::Return(mir_pixel_format_xrgb_8888));
     }
+
+    void TearDown() override
+    {
+        executor.execute();
+    }
 };
 
 }
@@ -126,6 +141,7 @@ TEST_F(BasicSurfaceTest, can_be_created_with_session)
     auto const session = std::make_shared<mtd::StubSession>();
     ms::BasicSurface surface{
         session,
+        {} /* wayland_surface */,
         name,
         geom::Rectangle{{0,0}, {100,100}},
         mir_pointer_unconfined,
@@ -146,6 +162,7 @@ TEST_F(BasicSurfaceTest, buffer_stream_ids_always_unique)
     {
         surface = std::make_unique<ms::BasicSurface>(
                 nullptr /* session */,
+                mw::Weak<mf::WlSurface>{},
                 name,
                 rect,
                 mir_pointer_unconfined,
@@ -170,6 +187,7 @@ TEST_F(BasicSurfaceTest, id_never_invalid)
     {
         surface = std::make_unique<ms::BasicSurface>(
                 nullptr /* session */,
+                mw::Weak<mf::WlSurface>{},
                 name,
                 rect,
                 mir_pointer_unconfined,
@@ -187,7 +205,7 @@ TEST_F(BasicSurfaceTest, update_top_left)
     EXPECT_CALL(mock_callback, call())
         .Times(1);
 
-    surface.add_observer(observer);
+    surface.register_interest(observer, executor);
 
     EXPECT_EQ(rect.top_left, surface.top_left());
 
@@ -203,7 +221,7 @@ TEST_F(BasicSurfaceTest, update_size)
     EXPECT_CALL(mock_callback, call())
         .Times(1);
 
-    surface.add_observer(observer);
+    surface.register_interest(observer, executor);
 
     EXPECT_EQ(rect.size, surface.window_size());
     EXPECT_NE(new_size, surface.window_size());
@@ -225,14 +243,13 @@ TEST_F(BasicSurfaceTest, observer_notified_of_window_resize)
     using namespace testing;
 
     geom::Size const new_size{34, 56};
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
 
     ASSERT_THAT(new_size, Ne(surface.window_size())) << "Precondition failed";
 
-    EXPECT_CALL(mock_surface_observer, window_resized_to(_, new_size))
+    EXPECT_CALL(*mock_surface_observer, window_resized_to(_, new_size))
         .Times(1);
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
     surface.resize(new_size);
 }
 
@@ -241,14 +258,13 @@ TEST_F(BasicSurfaceTest, observer_notified_of_content_resize)
     using namespace testing;
 
     geom::Size const new_size{34, 56};
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
 
     ASSERT_THAT(new_size, Ne(surface.content_size())) << "Precondition failed";
 
-    EXPECT_CALL(mock_surface_observer, content_resized_to(_, new_size))
+    EXPECT_CALL(*mock_surface_observer, content_resized_to(_, new_size))
         .Times(1);
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
     surface.resize(new_size);
 }
 
@@ -257,18 +273,17 @@ TEST_F(BasicSurfaceTest, resize_notifications_only_sent_when_size_changed)
     using namespace testing;
 
     geom::Size const new_size{34, 56};
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
 
     ASSERT_THAT(rect.size, Eq(surface.window_size())) << "Precondition failed";
     ASSERT_THAT(rect.size, Eq(surface.content_size())) << "Precondition failed";
     ASSERT_THAT(new_size, Ne(surface.content_size())) << "Precondition failed";
 
-    EXPECT_CALL(mock_surface_observer, window_resized_to(_, _))
+    EXPECT_CALL(*mock_surface_observer, window_resized_to(_, _))
         .Times(1);
-    EXPECT_CALL(mock_surface_observer, content_resized_to(_, _))
+    EXPECT_CALL(*mock_surface_observer, content_resized_to(_, _))
         .Times(1);
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
     surface.resize(rect.size);
     surface.resize(new_size);
     surface.resize(new_size);
@@ -285,14 +300,13 @@ TEST_F(BasicSurfaceTest, only_content_is_notified_of_resize_when_frame_geometry_
     geom::Size const new_content_size{
         rect.size.width - left - right,
         rect.size.height - top - bottom};
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
 
-    EXPECT_CALL(mock_surface_observer, window_resized_to(_, _))
+    EXPECT_CALL(*mock_surface_observer, window_resized_to(_, _))
         .Times(0);
-    EXPECT_CALL(mock_surface_observer, content_resized_to(_, new_content_size))
+    EXPECT_CALL(*mock_surface_observer, content_resized_to(_, new_content_size))
         .Times(1);
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
     surface.set_window_margins(top, left, bottom, right);
 }
 
@@ -397,7 +411,7 @@ TEST_F(BasicSurfaceTest, test_surface_set_transformation_updates_transform)
     EXPECT_CALL(mock_callback, call())
         .Times(1);
 
-    surface.add_observer(observer);
+    surface.register_interest(observer, executor);
 
     auto renderables = surface.generate_renderables(compositor_id);
     ASSERT_THAT(renderables.size(), testing::Eq(1));
@@ -435,6 +449,7 @@ TEST_F(BasicSurfaceTest, test_surface_visibility)
     // Must be a fresh surface to guarantee no frames posted yet...
     ms::BasicSurface surface{
         nullptr /* session */,
+        {} /* wayland_surface */,
         name,
         rect,
         mir_pointer_unconfined,
@@ -462,7 +477,7 @@ TEST_F(BasicSurfaceTest, test_surface_hidden_notifies_changes)
     EXPECT_CALL(mock_callback, call())
         .Times(1);
 
-    surface.add_observer(observer);
+    surface.register_interest(observer, executor);
 
     surface.set_hidden(true);
 }
@@ -474,6 +489,7 @@ TEST_F(BasicSurfaceTest, default_region_is_surface_rectangle)
     geom::Size one_by_one{geom::Width{1}, geom::Height{1}};
     ms::BasicSurface surface{
         nullptr /* session */,
+        {} /* wayland_surface */,
         name,
         geom::Rectangle{pt, one_by_one},
         mir_pointer_unconfined,
@@ -481,7 +497,7 @@ TEST_F(BasicSurfaceTest, default_region_is_surface_rectangle)
         std::shared_ptr<mg::CursorImage>(),
         report};
 
-    surface.add_observer(observer);
+    surface.register_interest(observer, executor);
 
     std::vector<geom::Point> contained_pt
     {
@@ -510,6 +526,7 @@ TEST_F(BasicSurfaceTest, default_invisible_surface_doesnt_get_input)
 {
     ms::BasicSurface surface{
         nullptr /* session */,
+        {} /* wayland_surface */,
         name,
         geom::Rectangle{{0,0}, {100,100}},
         mir_pointer_unconfined,
@@ -529,6 +546,7 @@ TEST_F(BasicSurfaceTest, surface_doesnt_get_input_outside_clip_area)
 {
     ms::BasicSurface surface{
         nullptr /* session */,
+        {} /* wayland_surface */,
         name,
         geom::Rectangle{{0,0}, {100,100}},
         mir_pointer_unconfined,
@@ -536,12 +554,12 @@ TEST_F(BasicSurfaceTest, surface_doesnt_get_input_outside_clip_area)
         std::shared_ptr<mg::CursorImage>(),
         report};
 
-    surface.set_clip_area(std::experimental::optional<geom::Rectangle>({{0,0}, {50,50}}));
+    surface.set_clip_area(std::optional<geom::Rectangle>({{0,0}, {50,50}}));
 
     EXPECT_FALSE(surface.input_area_contains({75,75}));
     EXPECT_TRUE(surface.input_area_contains({25,25}));
 
-    surface.set_clip_area(std::experimental::optional<geom::Rectangle>());
+    surface.set_clip_area(std::optional<geom::Rectangle>());
 
     EXPECT_TRUE(surface.input_area_contains({75,75}));
 }
@@ -553,7 +571,7 @@ TEST_F(BasicSurfaceTest, set_input_region)
         {{geom::X{1}, geom::Y{1}}, {geom::Width{1}, geom::Height{1}}}  //region1
     };
 
-    surface.add_observer(observer);
+    surface.register_interest(observer, executor);
 
     surface.set_input_region(rectangles);
 
@@ -752,6 +770,7 @@ TEST_F(BasicSurfaceTest, stores_parent)
     auto parent = mt::fake_shared(surface);
     ms::BasicSurface child{
         nullptr /* session */,
+        {} /* wayland_surface */,
         name,
         geom::Rectangle{{0,0}, {100,100}},
         parent,
@@ -848,15 +867,13 @@ TEST_P(BasicSurfaceAttributeTest, notifies_about_attrib_changes)
     auto const& value1 = params.a_valid_value;
     auto const& value2 = params.default_value;
 
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
-
     InSequence s;
-    EXPECT_CALL(mock_surface_observer, attrib_changed(_, attribute, value1))
+    EXPECT_CALL(*mock_surface_observer, attrib_changed(_, attribute, value1))
         .Times(1);
-    EXPECT_CALL(mock_surface_observer, attrib_changed(_, attribute, value2))
+    EXPECT_CALL(*mock_surface_observer, attrib_changed(_, attribute, value2))
         .Times(1);
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
 
     surface.configure(attribute, value1);
     surface.configure(attribute, value2);
@@ -871,12 +888,10 @@ TEST_P(BasicSurfaceAttributeTest, does_not_notify_if_attrib_is_unchanged)
     auto const& default_value = params.default_value;
     auto const& another_value = params.a_valid_value;
 
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
-
-    EXPECT_CALL(mock_surface_observer, attrib_changed(_, attribute, another_value))
+    EXPECT_CALL(*mock_surface_observer, attrib_changed(_, attribute, another_value))
         .Times(1);
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
 
     surface.configure(attribute, default_value);
     surface.configure(attribute, another_value);
@@ -932,14 +947,12 @@ TEST_F(BasicSurfaceTest, notifies_about_focus_state_changes)
 {
     using namespace testing;
 
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
-
-    EXPECT_CALL(mock_surface_observer, attrib_changed(_, mir_window_attrib_focus, mir_window_focus_state_focused))
+    EXPECT_CALL(*mock_surface_observer, attrib_changed(_, mir_window_attrib_focus, mir_window_focus_state_focused))
         .Times(1);
-    EXPECT_CALL(mock_surface_observer, attrib_changed(_, mir_window_attrib_focus, mir_window_focus_state_unfocused))
+    EXPECT_CALL(*mock_surface_observer, attrib_changed(_, mir_window_attrib_focus, mir_window_focus_state_unfocused))
         .Times(1);
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
 
     surface.set_focus_state(mir_window_focus_state_focused);
     surface.set_focus_state(mir_window_focus_state_unfocused);
@@ -949,12 +962,10 @@ TEST_F(BasicSurfaceTest, does_not_notify_if_focus_state_is_unchanged)
 {
     using namespace testing;
 
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
-
-    EXPECT_CALL(mock_surface_observer, attrib_changed(_, mir_window_attrib_focus, mir_window_focus_state_focused))
+    EXPECT_CALL(*mock_surface_observer, attrib_changed(_, mir_window_attrib_focus, mir_window_focus_state_focused))
         .Times(1);
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
 
     surface.set_focus_state(mir_window_focus_state_unfocused); // will not notify, since it is default
     surface.set_focus_state(mir_window_focus_state_focused);
@@ -976,12 +987,10 @@ TEST_F(BasicSurfaceTest, notifies_about_cursor_image_change)
 {
     using namespace testing;
 
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
-
     auto cursor_image = std::make_shared<mtd::StubCursorImage>();
-    EXPECT_CALL(mock_surface_observer, cursor_image_set_to(_, _));
+    EXPECT_CALL(*mock_surface_observer, cursor_image_set_to(_, _));
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
     surface.set_cursor_image(cursor_image);
 }
 
@@ -989,107 +998,107 @@ TEST_F(BasicSurfaceTest, notifies_about_cursor_image_removal)
 {
     using namespace testing;
 
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
+    EXPECT_CALL(*mock_surface_observer, cursor_image_set_to(_, _)).Times(0);
+    EXPECT_CALL(*mock_surface_observer, cursor_image_removed(_));
 
-    EXPECT_CALL(mock_surface_observer, cursor_image_set_to(_, _)).Times(0);
-    EXPECT_CALL(mock_surface_observer, cursor_image_removed(_));
-
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
     surface.set_cursor_image({});
 }
 
-TEST_F(BasicSurfaceTest, notifies_when_cursor_stream_set)
+TEST_F(BasicSurfaceTest, when_frame_is_posted_an_observer_is_notified_of_frame_with_correct_size)
 {
     using namespace testing;
 
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
-    auto buffer_stream = std::make_shared<NiceMock<mtd::MockBufferStream>>();
-    auto stub_buffer = std::make_shared<mtd::StubBuffer>();
-
-    ON_CALL(*buffer_stream, lock_compositor_buffer(_))
-        .WillByDefault(Return(stub_buffer));
-    EXPECT_CALL(mock_surface_observer, cursor_image_set_to(_, _));
-
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
-    surface.set_cursor_stream(buffer_stream, {});
-}
-
-TEST_F(BasicSurfaceTest, notifies_about_cursor_removal_when_empty_stream_set)
-{
-    using namespace testing;
-
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
     auto buffer_stream = std::make_shared<NiceMock<mtd::MockBufferStream>>();
 
-    ON_CALL(*buffer_stream, has_submitted_buffer())
-        .WillByDefault(Return(false));
-    EXPECT_CALL(mock_surface_observer, cursor_image_set_to(_, _)).Times(0);
-    EXPECT_CALL(mock_surface_observer, cursor_image_removed(_));
+    surface.resize({100, 150}); // should not affect frame_posted notification
+    surface.register_interest(mock_surface_observer, executor);
+    surface.set_streams({ms::StreamInfo{buffer_stream, {}, {}}});
+    ON_CALL(*buffer_stream, stream_size())
+        .WillByDefault(Return(rect.size));
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
-    surface.set_cursor_stream(buffer_stream, {});
+    EXPECT_CALL(*mock_surface_observer, frame_posted(_, _, mt::RectSizeEq(rect.size)));
+    buffer_stream->frame_posted_callback(rect.size);
 }
 
-TEST_F(BasicSurfaceTest, cursor_can_be_set_from_stream_that_started_empty)
+TEST_F(BasicSurfaceTest, when_stream_size_differs_from_buffer_size_an_observer_is_notified_of_frame_with_stream_size)
 {
     using namespace testing;
+    geom::Size const stream_size{rect.size * 1.5};
 
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
     auto buffer_stream = std::make_shared<NiceMock<mtd::MockBufferStream>>();
-    std::shared_ptr<mtd::StubBuffer> stub_buffer;
-    // Must be a shared pointer, because it is set by CursorStreamImageAdapter::reset() in the destructor
-    auto frame_posted_callback = std::make_shared<std::function<void(mir::geometry::Size const&)>>([](auto)
-        {
-            FAIL() << "frame_posted_callback should have been set by the surface";
-        });
+    std::function<void(geom::Size const&)> frame_posted_callback;
+    ON_CALL(*buffer_stream, stream_size())
+        .WillByDefault(Return(stream_size));
 
-    ON_CALL(*buffer_stream, has_submitted_buffer())
-        .WillByDefault(Invoke([&]
-            {
-                return stub_buffer != nullptr;
-            }));
-    ON_CALL(*buffer_stream, lock_compositor_buffer(_))
-        .WillByDefault(Invoke([&](auto)
-            {
-                return stub_buffer;
-            }));
-    ON_CALL(*buffer_stream, set_frame_posted_callback(_))
-        .WillByDefault(Invoke([=](auto const& callback)
-            {
-                *frame_posted_callback = callback;
-            }));
-    EXPECT_CALL(mock_surface_observer, cursor_image_removed(_)).Times(1);
-    EXPECT_CALL(mock_surface_observer, cursor_image_set_to(_, _)).Times(1);
+    surface.register_interest(mock_surface_observer, executor);
+    surface.set_streams({ms::StreamInfo{buffer_stream, {}, {}}});
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
-    surface.set_cursor_stream(buffer_stream, {});
-    stub_buffer = std::make_shared<mtd::StubBuffer>();
-    (*frame_posted_callback)({});
+    EXPECT_CALL(*mock_surface_observer, frame_posted(_, _, mt::RectSizeEq(stream_size)));
+    buffer_stream->frame_posted_callback(stream_size * 2);
 }
 
-TEST_F(BasicSurfaceTest, observer_can_trigger_state_change_within_notification)
+TEST_F(BasicSurfaceTest, when_stream_info_has_explicit_size_an_observer_is_notified_of_frame_with_stream_info_size)
+{
+    using namespace testing;
+    geom::Size const stream_info_size{rect.size * 1.5};
+    geom::Size const stream_size{stream_info_size * 2};
+
+    auto buffer_stream = std::make_shared<NiceMock<mtd::MockBufferStream>>();
+    std::function<void(geom::Size const&)> frame_posted_callback;
+    ON_CALL(*buffer_stream, stream_size())
+        .WillByDefault(Return(stream_size));
+
+    surface.register_interest(mock_surface_observer, executor);
+    surface.set_streams({ms::StreamInfo{buffer_stream, {}, stream_info_size}});
+
+    EXPECT_CALL(*mock_surface_observer, frame_posted(_, _, mt::RectSizeEq(stream_info_size)));
+    buffer_stream->frame_posted_callback(stream_size);
+}
+
+TEST_F(BasicSurfaceTest, when_frame_is_posted_an_observer_is_notified_of_frame_at_origin)
 {
     using namespace testing;
 
-    auto const state_changer = [&]{
-       surface.set_hidden(false);
-    };
+    auto buffer_stream = std::make_shared<NiceMock<mtd::MockBufferStream>>();
+    surface.register_interest(mock_surface_observer, executor);
+    surface.set_streams({ms::StreamInfo{buffer_stream, {}, {}}});
 
-    //Make sure another thread can also change state
-    auto const async_state_changer = [&]{
-        std::async(std::launch::async, state_changer).wait();
-    };
-
-    EXPECT_CALL(mock_callback, call()).Times(3)
-        .WillOnce(InvokeWithoutArgs(state_changer))
-        .WillOnce(InvokeWithoutArgs(async_state_changer))
-        .WillOnce(Return());
-
-    surface.add_observer(observer);
-
-    surface.set_hidden(true);
+    EXPECT_CALL(*mock_surface_observer, frame_posted(_, _, mt::RectTopLeftEq(geom::Point{})));
+    buffer_stream->frame_posted_callback(rect.size);
 }
 
+TEST_F(BasicSurfaceTest, when_stream_info_has_offset_an_observer_is_notified_of_frame_with_correct_offset)
+{
+    using namespace testing;
+    geom::Displacement const stream_info_offset{7, 10};
+
+    auto buffer_stream = std::make_shared<NiceMock<mtd::MockBufferStream>>();
+    std::function<void(geom::Size const&)> frame_posted_callback;
+
+    surface.register_interest(mock_surface_observer, executor);
+    surface.set_streams({ms::StreamInfo{buffer_stream, stream_info_offset, {}}});
+
+    EXPECT_CALL(*mock_surface_observer, frame_posted(_, _, mt::RectTopLeftEq(geom::Point{} + stream_info_offset)));
+    buffer_stream->frame_posted_callback(rect.size);
+}
+
+TEST_F(BasicSurfaceTest, when_surface_has_margins_an_observer_is_notified_of_frame_with_correct_offset)
+{
+    using namespace testing;
+    geom::DeltaY const margin_top{4}, margin_bottom{6};
+    geom::DeltaX const margin_left{3}, margin_right{5};
+
+    auto buffer_stream = std::make_shared<NiceMock<mtd::MockBufferStream>>();
+    std::function<void(geom::Size const&)> frame_posted_callback;
+
+    surface.register_interest(mock_surface_observer, executor);
+    surface.set_streams({ms::StreamInfo{buffer_stream, {}, {}}});
+
+    EXPECT_CALL(*mock_surface_observer, frame_posted(_, _, mt::RectTopLeftEq(geom::Point{} + margin_top + margin_left)));
+    surface.set_window_margins(margin_top, margin_left, margin_bottom, margin_right);
+    buffer_stream->frame_posted_callback({20, 30});
+}
 
 TEST_F(BasicSurfaceTest, default_application_id)
 {
@@ -1108,12 +1117,11 @@ TEST_F(BasicSurfaceTest, notifies_about_application_id_changes)
     using namespace testing;
 
     std::string const id{"test.id"};
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
 
-    EXPECT_CALL(mock_surface_observer, application_id_set_to(_, id))
+    EXPECT_CALL(*mock_surface_observer, application_id_set_to(_, id))
         .Times(1);
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
 
     surface.set_application_id(id);
 }
@@ -1123,54 +1131,24 @@ TEST_F(BasicSurfaceTest, does_not_notify_if_application_id_is_unchanged)
     using namespace testing;
 
     std::string const id{"test.id"};
-    NiceMock<MockSurfaceObserver> mock_surface_observer;
 
-    EXPECT_CALL(mock_surface_observer, application_id_set_to(_, id))
+    EXPECT_CALL(*mock_surface_observer, application_id_set_to(_, id))
         .Times(1);
 
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
 
     surface.set_application_id("");
     surface.set_application_id(id);
     surface.set_application_id(id);
 }
 
-TEST_F(BasicSurfaceTest, observer_can_remove_itself_within_notification)
-{
-    using namespace testing;
-    MockSurfaceObserver observer1;
-    MockSurfaceObserver observer2;
-    MockSurfaceObserver observer3;
-
-    //Both of these observers should still get their notifications
-    //regardless of the unregistration of observer2
-    EXPECT_CALL(observer1, hidden_set_to(_, true)).Times(2);
-    EXPECT_CALL(observer3, hidden_set_to(_, true)).Times(2);
-
-    auto const remove_observer = [&]{
-        surface.remove_observer(mt::fake_shared(observer2));
-    };
-
-    EXPECT_CALL(observer2, hidden_set_to(_, true)).Times(1)
-        .WillOnce(InvokeWithoutArgs(remove_observer));
-
-    surface.add_observer(mt::fake_shared(observer1));
-    surface.add_observer(mt::fake_shared(observer2));
-    surface.add_observer(mt::fake_shared(observer3));
-
-    surface.set_hidden(true);
-    surface.set_hidden(true);
-}
-
 TEST_F(BasicSurfaceTest, notifies_of_client_close_request)
 {
     using namespace testing;
 
-    MockSurfaceObserver mock_surface_observer;
+    EXPECT_CALL(*mock_surface_observer, client_surface_close_requested(_)).Times(1);
 
-    EXPECT_CALL(mock_surface_observer, client_surface_close_requested(_)).Times(1);
-
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
 
     surface.request_client_surface_close();
 }
@@ -1179,10 +1157,9 @@ TEST_F(BasicSurfaceTest, notifies_of_rename)
 {
     using namespace testing;
 
-    MockSurfaceObserver mock_surface_observer;
-    surface.add_observer(mt::fake_shared(mock_surface_observer));
+    surface.register_interest(mock_surface_observer, executor);
 
-    EXPECT_CALL(mock_surface_observer, renamed(_, StrEq("Steve")));
+    EXPECT_CALL(*mock_surface_observer, renamed(_, StrEq("Steve")));
 
     surface.rename("Steve");
 }
@@ -1296,12 +1273,12 @@ TEST_F(BasicSurfaceTest, does_not_render_if_outside_of_clip_area)
         { buffer_stream2, d2, {} }
     };
     surface.set_streams(streams);
-    surface.set_clip_area(std::experimental::optional<geom::Rectangle>({{200,0},{100,100}}));
+    surface.set_clip_area(std::optional<geom::Rectangle>({{200,0},{100,100}}));
 
     auto renderables = surface.generate_renderables(this);
     ASSERT_THAT(renderables.size(), Eq(0));
 
-    surface.set_clip_area(std::experimental::optional<geom::Rectangle>({{0,0},{100,100}}));
+    surface.set_clip_area(std::optional<geom::Rectangle>({{0,0},{100,100}}));
 
     renderables = surface.generate_renderables(this);
     ASSERT_THAT(renderables.size(), Eq(4));
@@ -1326,6 +1303,7 @@ TEST_F(BasicSurfaceTest, registers_frame_callbacks_on_construction)
 
     ms::BasicSurface child{
         nullptr /* session */,
+        {} /* wayland_surface */,
         name,
         geom::Rectangle{{0,0}, {100,100}},
         std::weak_ptr<ms::Surface>{},
@@ -1577,12 +1555,14 @@ TEST_F(BasicSurfaceTest, notifies_when_first_visible)
 {
     using namespace testing;
     auto observer = std::make_shared<VisibilityObserver>();
-    surface.add_observer(observer);
+    surface.register_interest(observer, executor);
 
     EXPECT_THAT(observer->exposes(), Eq(0));
     EXPECT_THAT(observer->hides(), Eq(0));
     surface.configure(mir_window_attrib_visibility, mir_window_visibility_exposed);
 
+    executor.execute();
+
     EXPECT_THAT(observer->exposes(), Eq(1));
     EXPECT_THAT(observer->hides(), Eq(0));
 }
@@ -1601,6 +1581,7 @@ TEST_F(BasicSurfaceTest, buffer_can_be_submitted_to_original_stream_after_surfac
 
     auto surface = std::make_unique<ms::BasicSurface>(
         nullptr, // session
+        mw::Weak<mf::WlSurface>{},
         name,
         rect,
         mir_pointer_unconfined,
@@ -1626,6 +1607,7 @@ TEST_F(BasicSurfaceTest, buffer_can_be_submitted_to_set_stream_after_surface_des
 
     auto surface = std::make_unique<ms::BasicSurface>(
         nullptr, // session
+        mw::Weak<mf::WlSurface>{},
         name,
         rect,
         mir_pointer_unconfined,
