@@ -12,8 +12,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authored by: Kevin DuBois <kevin.dubois@canonical.com>
  */
 
 #include "src/server/scene/mediating_display_changer.h"
@@ -21,6 +19,7 @@
 #include "mir/graphics/display_configuration_policy.h"
 #include "src/server/scene/broadcasting_session_event_sink.h"
 #include "mir/server_action_queue.h"
+#include "mir/wayland/wayland_base.h"
 
 #include "mir/test/doubles/mock_display.h"
 #include "mir/test/doubles/mock_compositor.h"
